# Script for "Mixed origin of juvenile Atlantic cod (Gadus morhua) on the Swedish west coast"
# Script by: Simon Henriksson, Tjrn marine laboratory, University of Gothenburg
# e-mail: simon.henriksson@gu.se

#Written for R v4.1.2, RStudio v2021.9.1.372

# OBS! Load env, packages, RData ####
# clear env 
rm(list=ls())

# Load packages
lapply(c("base", "adegenet", "radiator", "assignPOP","tidyverse",
         "graphics","ggplot2","hierfstat","pegas","LEA",
         "mapplots","shapefiles","scales","ggpubr","svglite",
         "strataG","dartR","broom","car","AICcmodavg",
         "MASS","lmtest","rJava","inveRsion","OutFLANK",
         "pheatmap","RColorBrewer","graph4lg","wesanderson","viridis"), require, character.only = TRUE)

#write command for filtering
`%notin%` <- Negate(`%in%`) # Creating a %notin% operator

#set wd
setwd("...") #paste path to your folder here

#_______________####
# Quality check ####
# import data ####
# Import genepop file
comb_prel <- read.genepop("genotypes_65loci.gen", ncode = 2L) #automatically removes 0000 loci and 1 ind w/o genotypes

#ind metadata
metadata1 <- readxl::read_xlsx("metadata_all_inds.xlsx") #inds
metadata2 <- metadata1[metadata1$New_ID!="KT20_800",] # removes KT20_800 (failed genotyping)
unique(indNames(comb_prel) == metadata2$New_ID) #inds all the same

#locus metadata
loci1 <- readxl::read_xlsx("65snps_ordered_AZ.xlsx") #loci
loci2 <- filter(loci1,SNP_R %in% locNames(comb_prel))
unique(loci2$SNP_R == locNames(comb_prel)) #loci all the same

#change ind and pop names
pop(comb_prel) <- metadata2$Survey_year

# Filter out all but the ecotype-diagnostic loci (26loci, fjordNS)
ecodiag_prel <- filter(loci2,Group %in% c("26loci","fjordNS"))$SNP_R

comb_sub_prel <- comb_prel[loc=ecodiag_prel]

# PCA on ecotype-diagnostic set (35 loci) ####
x.comb_sub_prel <- tab(comb_sub_prel,freq=TRUE,NA.method="mean") 
pca.comb_sub_prel <- dudi.pca(x.comb_sub_prel,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <- pca.comb_sub_prel$eig/sum(pca.comb_sub_prel$eig)*100

s.class(pca.comb_sub_prel$li, fac=as.factor(pop(comb_sub_prel)), 
        col=funky(23),
        axesel=TRUE, cstar=1, cpoint=2, clabel = 1, xax=1,yax=2)
add.scatter.eig(pca.comb_sub_prel$eig,3,1,2, ratio=.2,sub="PC eigenvalues")

#Histogram of coordinates along PC1
hist(pca.comb_sub_prel$li$Axis1, breaks=50,main="Histogram of PC1 coordinates",xlab=paste("PC1 (",round(eig.perc[1],1),"%)",sep=""),col="gray")

# prel. k-means clustering (k=2) ####
grp_prel<-find.clusters(comb_sub_prel,n.pca=50,n.clust=2,max.n=20,scale=FALSE)
s.class(pca.comb_sub_prel$li, fac=grp_prel$grp,col=funky(2),axesel=TRUE, cstar=1, cpoint=2, clabel = 1, xax=1,yax=2)

comb_grp_prel <- comb_sub_prel
pop(comb_grp_prel) <- grp_prel$grp

# LD and HW per group (k=2) ####

# LD
x1 <- gl.report.ld(gi2gl(comb_grp_prel[pop=1])) %>% data.frame()
x1$"Group" <- cbind(rep(1, length(x1$loc1)))
x2 <- gl.report.ld(gi2gl(comb_grp_prel[pop=2])) %>% data.frame()
x2$"Group" <- cbind(rep(2, length(x2$loc1)))
x3 <- rbind(x1,x2)
comb_sub_prel_LD_2groups <- x3[, c(10,1:9)]
filter(comb_sub_prel_LD_2groups,R2>0.1) #any loci w R2 > 0.1?
  # NO LOCI W R2 > 0.1 IN ANY ECOTYPE!

# HW 2 groups
y1 <- hw.test(comb_grp_prel[pop=1]) %>% data.frame()
y1$"Group" <- rep(1, length(y1$"chi.2"))
y2 <- hw.test(comb_grp_prel[pop=2]) %>% data.frame()
y2$"Group" <- rep(2, length(y2$"chi.2"))
y3 <- rbind(y1,y2)
comb_sub_prel_HW_2groups <- y3[, c(5,1,2,3,4)]
comb_sub_prel_HW_2groups$p.adj <- p.adjust(comb_sub_prel_HW_2groups$Pr.chi.2...,method="fdr")
filter(comb_sub_prel_HW_2groups,p.adj<0.05) #any loci w p.adj < 0.05 in both ecotypes?
  # Gdist164810_155 (locus 2) & Gdist205713_12614 (locus 5) OUT OF HW PROP (P.ADJ < 0.05) IN BOTH ECOTYPES
  # They are also the two loci with the lowest genotyping success in both round 1 and 2, due to poor clustering and notable amounts of inds clustering btw hetero and homo
  # REMOVE Gdist164810_155 (locus 2) & Gdist205713_12614 (locus 5)

# genotyping success ####
# Inds w low (< 80 %) genotyping success for the 33 diagnostic SNPs
comb_prel[metadata2$Genot_success_33diag < 0.8] 
  # 14 inds need to be removed

#_______________####

# Filtered dataset ####
# Edit data ####
#Remove inds w genotyping success for diagnostic loci < 0.8
comb <- comb_prel[metadata2$Genot_success_33diag > 0.8] #from genind
metadata3 <- metadata2[metadata2$Genot_success_33diag > 0.8,] #from metadata

#add new metadata (updated with age readings, coords etc. OBS! Only available for the 987 filtered indviduals)
metadata4 <- readxl::read_xlsx("metadata_filtered_inds.xlsx")
metadata4_sorted <- metadata4[order(metadata4$order_NS_19.20_0.1.ad_ind_REVISED),]

# Fig. S1: Length distribution ####
# length vs otolith age
ggplot()+
  geom_density(data=filter(metadata4,Sample_type=="Juvenile"), aes(x=as.numeric(paste(Length_mm)),fill=Age_otolith), alpha=0.6, col=NA)+
  geom_point(data= filter(metadata4,Sample_type=="Juvenile",Age_otolith=="0"), aes(x=as.numeric(paste(Length_mm)),y=rep(-0.0007,length(Length_mm))), col="red",alpha=0.4,size=0.8)+
  geom_point(data= filter(metadata4,Sample_type=="Juvenile",Age_otolith=="1"), aes(x=as.numeric(paste(Length_mm)),y=rep(-0.0014,length(Length_mm))), col="blue",alpha=0.4,size=0.8)+
  geom_point(data= filter(metadata4,Sample_type=="Juvenile",Age_otolith=="NA"), aes(x=as.numeric(paste(Length_mm)),y=rep(-0.0021,length(Length_mm))), col="black",alpha=0.4,size=0.8)+
  ggtitle("Length vs age (otolith)")+
  scale_fill_manual(values=c("red","blue","black"),
                    name = "Age (otolith)",
                    labels = c("0-group","1-group","NA"))+
  xlab("Length [mm]")+ylab("Density")+
  xlim(c(0,350))+#ylim(c(-0.002,0.1))+
  geom_vline(xintercept=150,linetype=2,size=1,col="blue2")+
  scale_y_continuous(labels = scales::number_format(accuracy = 0.001))+
  theme_classic() 

# Filter to create subsets of data, w only successful snps ####

#filter out loci deviating from HW props, and monomorphic loci  
HWdev <- c(4,7) #deviate from HW prop
mono <- c(15,43,45,49) #monomorphic
comb <- comb[loc=-c(HWdev,mono)] #remove from genind object
loci3 <- loci2[-c(HWdev,mono),] #remove from locus metadata

#create genind objects with only specific loci
comb_sub <- comb[loc=loci3$Group %in% c("26loci","fjordNS")] #ecotype-diagnostic
comb_LG11 <- comb[loc=loci3$Group=="gender"] #sex assignment
comb_INV01 <- comb[loc=loci3$Group=="INV" & loci3$LG=="LG01"] #INV01
comb_INV02 <- comb[loc=loci3$Group=="INV" & loci3$LG=="LG02"] #INV02
comb_INV07 <- comb[loc=loci3$Group=="INV" & loci3$LG=="LG07"] #INV07
comb_INV12 <- comb[loc=loci3$Group=="INV" & loci3$LG=="LG12"] #INV12
comb_Hb <- comb[loc=loci3$Group=="hemo"] #Hb genes

# PCA ####
x.comb_sub <- tab(comb_sub,freq=TRUE,NA.method="mean") 
pca.comb_sub <- dudi.pca(x.comb_sub,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <- pca.comb_sub$eig/sum(pca.comb_sub$eig)*100

s.class(pca.comb_sub$li, fac=as.factor(metadata4$Survey_year), 
        col=funky(21),
        axesel=TRUE, cstar=1, cpoint=1, clabel = 1, xax=1,yax=2)
add.scatter.eig(pca.comb_sub$eig[1:33],3,1,2, ratio=.2,sub="PC eigenvalues")

#Histogram of coordinates along PC1
hist(pca.comb_sub$li$Axis1, breaks=50,main="Histogram of PC1 coordinates",xlab=paste("PC1 (",round(eig.perc[1],1),"%)",sep=""),col="gray")

# Ecotype assignment ####
## k-means clustering ####
# A priori - assuming two groups:
grp<-find.clusters(comb_sub,n.pca=50,n.clust=2,scale=FALSE) #assuming k=2
comb_grp <- comb_sub
pop(comb_grp) <- grp$grp

#create vector of individual ecotype assignment
eco <- replace(as.character(grp$grp),grp$grp=="1","Offshore") #this works as long as GM-NOT inds are assigned to "group 1"
eco <- as.factor(replace(eco,eco=="2","Coastal")) #this works as long as KA13 and OL20 inds are assigned to "group 2"

## Fig. S4: Sequential K-means clustering ####
find.clusters(comb_sub,n.pca=50,max.n=20,scale=FALSE) #assuming k=2

## DAPC ####
dapc<-dapc(comb_sub, pop=grp$grp, n.pca=50, n.da=1, var.loadings=TRUE)

#nice density plot of DAPC coords
ggplot()+
  geom_density(data=dapc$ind.coord %>% data.frame, aes(x=LD1,fill=grp$grp),alpha=0.7,color=NA) +
  #geom_point(data=dapc$ind.coord %>% data.frame, aes(x=LD1,y=rep(0,349)),shape=16,alpha=0.2,size=3,colour="grey1")+
  xlab("Discriminant function 1")+ylab("Density")+
  scale_x_continuous(limits = c(-5.6,5.6),labels = scales::number_format(accuracy = 0.1))+
  theme_classic()+
  scale_color_manual(values=c("dodgerblue2","orange2"))+ 
  scale_fill_manual(values=c("dodgerblue2","orange2"),
                    name = "Ecotype", 
                    labels = c("Offshore","Coastal"))+
  ylim(0,0.41) -> dens_dapc

## PCA ####
# PCA score plot
#label <- expression('F[ST] == 0.12~(0.07-0.18)')
eig.perc <- dapc$pca.eig/sum(dapc$pca.eig)*100

ggplot() +
  geom_point(data = dapc$tab,
             mapping = aes(x = `PCA-pc.1`, y = `PCA-pc.2`,
                           colour = grp$grp), size=3, alpha=0.7) +
  xlab("PC1 (16.0%)")+ ylab("PC2 (4.3%)")+
  theme_classic() +
  scale_colour_manual(values=c("dodgerblue2","orange2"),
                      name = "Ecotype", 
                      labels = c("Offshore","Coastal"))+
  coord_fixed(ratio=pca.comb_sub$eig[2]/pca.comb_sub$eig[1])+
  scale_x_continuous(limits=c(-2.3,2.3),labels = scales::number_format(accuracy = 0.1))+
  scale_y_continuous(limits=c(-2,2),labels = scales::number_format(accuracy = 0.1)) -> pca_grp

## Fst BTW ECOTYPES ####
#strataG:
pairwiseTest(genind2gtypes(comb_grp),nrep=10000)
  # wcFst: 1.368198e-01 p: 0.0001

## OBS! ANCESTRY ANALYSIS (LEA) ####
#file conversions
# comb_sub_dat <- genind2hierfstat(comb_sub) # convert genind to dat
# write.struct(comb_sub_dat, ilab=indNames(comb_sub), pop = comb_sub$pop, fname = "Comb_sub.str") # convert dat to structure
# struct2geno(input.file = "Comb_sub.str", ploidy = 2, FORMAT = 2, extra.column = 2, extra.row = 0) #convert structure to geno. if you use str file from PGDspider, remove first row (loci names)

#add path to file
genofile <- "Comb_sub.str.geno" # add path of geno file to object called

#run the sNMF for different numbers of groups (K)
project <- snmf(genofile, K=1:10, entropy = TRUE,
              repetitions = 50,
              project = "new")
plot(project, type="b") #choose K based on plot

#calculate the ancestry of each individuals for K=2
cic.snmf <- snmf(genofile, K=2, project="new")
#extract the ancestry probability matrix for K=2
qmatrix <- Q(cic.snmf, K=2)
?`plot,snmfProject-method`
### Fig. S5: Plot project ####
plot(project, type="b",col = "steelblue4", pch = 19,cex=1.5) #choose K based on plot

## assignPOP (NS vs KAOL) ####

#read reference pop and juvenile genepop files
adults_NS_KAOL<- read.Genepop("genotypes_AP_adults_NS_KAOL.txt")
all <- read.Genepop("genotypes_AP_all.txt")

#check if inds are the same and in the same order as comb_sub
adults_NS_KAOL$SampleID==filter(metadata4,Sample_type=="Adult" & Subdiv != "20")$New_ID
all$SampleID==indNames(comb_sub)

adults_NS_KAOL$DataMatrix$popNames_vector <- c(rep("North Sea",11),rep("Kattegat/resund",30))
all$DataMatrix$popNames_vector <- pop(comb_sub)

#assign all individuals (juveniles AND adults)
assign.POP_NS_KAOL <- assign.X(adults_NS_KAOL,all,dir="NS_KAOL/",mplot=TRUE)

#inspect plots
assign.POP_NS_KAOL$data

#Create df:s that are easier to examine
NS_KAOL <- data.frame(pop(comb_sub),assign.POP_NS_KAOL$data[1:987,],assign.POP_NS_KAOL$data[988:1974,])[,c(1,2,5,9,3)]
colnames(NS_KAOL) <- c("Pop_ID","Ind_ID","Prob_NS","Prob_KAOL","Pred.pop")

#all
barplot(t(as.matrix(NS_KAOL[,c(3,4)])), col = c("dodgerblue2","orange2","forestgreen","darkred"),
        border=NA, space=0, xlab="", ylab = "Ancestry",main="All",axisnames = FALSE)

#VERY SIMILAR RESULTS TO LEA

## Table S6: Compare ecotype assignments ####
#create df with alternative assignment methods(kmeans,dapc,sNMF,assignPOP))
assignments <- data.frame(grp$grp, dapc$posterior,qmatrix[,c(2,1)],NS_KAOL[,c("Prob_NS","Prob_KAOL")])
colnames(assignments) <- c("Eco","Post_prob_1","Post_prob_2","Q1","Q2","Prob_NS","Prob_KAOL")
assignments

## Figure S3: Compare ecotype assignments ####
# DAPC vs kmeans
ggplot(assignments,mapping=aes(Post_prob_2,fill=Eco)) +
  geom_histogram(stat = "bin",position = "stack")+
  scale_fill_manual(values=c("dodgerblue2","orange2"),
                    name = "Ecotype", 
                    labels = c("Offshore","Coastal"))+
  labs(x="Posterior probability (coastal ecotype)",y="Count")+
  theme_classic() -> bar_post

# sNMF vs k-means
ggplot(assignments,mapping=aes(Q1,fill=Eco)) +
  geom_histogram(stat = "bin",position = "stack")+
  scale_fill_manual(values=c("dodgerblue2","orange2"),
                    name = "Ecotype", 
                    labels = c("Offshore","Coastal"))+
  labs(x="Ancestry coefficient (coastal ecotype)",y="Count")+
  theme_classic() -> bar_vs

# assignPOP vs kmeans
ggplot(assignments,mapping=aes(Prob_KAOL,fill=Eco)) +
  geom_histogram(stat = "bin",position = "stack")+
  scale_fill_manual(values=c("dodgerblue2","orange2"),name = "Ecotype",labels = c("Offshore","Coastal"))+
  labs(x="Assignment probability (Kattegat/resund)",y="Count")+
  theme_classic() -> bar_vs2

# all these plots together
ggarrange(bar_post,bar_vs,bar_vs2,nrow=3,ncol=1,labels="AUTO",common.legend = T,legend="right")

# prop of corresponding assignments
nrow(filter(assignments,Eco=="1",Post_prob_1>0.5))/nrow(filter(assignments,Eco=="1"))# 99.2 %
nrow(filter(assignments,Eco=="2",Post_prob_2>0.5))/nrow(filter(assignments,Eco=="2"))# 99.4 %

nrow(filter(assignments,Eco=="1",Q2>0.5))/nrow(filter(assignments,Eco=="1")) # 99.0 %
nrow(filter(assignments,Eco=="2",Q1>0.5))/nrow(filter(assignments,Eco=="2")) # 95.8 %

nrow(filter(assignments[metadata4$Sample_type=="Juvenile",],Eco=="1",Prob_NS>0.5))/nrow(filter(assignments[metadata4$Sample_type=="Juvenile",],Eco=="1")) # 90.8 %
nrow(filter(assignments[metadata4$Sample_type=="Juvenile",],Eco=="2",Prob_KAOL>0.5))/nrow(filter(assignments[metadata4$Sample_type=="Juvenile",],Eco=="2")) # 99.6 %

## Maps (Fig. 4A-C), ecotype distr ####

### data preparation ####
#for mapping purposes, transform popNames from chr to num
comb_map <- comb_sub
pop(comb_map) <- metadata4$Station_ID_Year
popNames(comb_map) <- 1:162

#load shapefiles
shape_LR <- read.shapefile("shapefiles/europa1")
shape_HR <- read.shapefile("shapefiles/NSOre_HR")

#colour, legend, label for plotting
col <- c("dodgerblue2","orange2")
leg <- c("Offshore", "Coastal")
lab <- "Ecotype"

#load coordinates
latlong <- cbind(pop(comb_map),metadata4[,c("Station_ID_Year","Lat_dec","Lon_dec")]) %>% data.frame
colnames(latlong) <- c("Pop_name","Station_ID","Lat","Lon")

#write functions for easily making maps
full_map <- function(xyz,col,leg,text.xy,lab,txtw,rad){
  basemap(xlim=c(6,13),ylim=c(55.6,59.2),bg="white")
  map<-draw.shape(shape_HR, col="grey85")
  draw.pie(xyz$x, xyz$y, xyz$z, radius=rad, scale=TRUE,
           col=col)
  legend("bottomleft", title=" ",legend=leg, fill=col,cex=0.9,box.col = "black", ncol=1,text.width = txtw)
  text(text.xy[1],text.xy[2],labels=lab,col="black",font=2,cex=1.1) }
fjord_map <- function(xyz,col,leg,text.xy,lab,txtw,rad){
  basemap(xlim=c(11.2,11.9),ylim=c(57.9,58.48),bg="white")
  map<-draw.shape(shape_HR, col="grey85")
  draw.pie(xyz$x, xyz$y, xyz$z, radius=rad,
           col=col)
  legend("bottomleft", title=" ",legend=leg, fill=col,cex=0.9,box.col = "black", ncol=1,text.width=txtw)
  text(text.xy[1],text.xy[2],labels=lab,col="black",font=2,cex=1.1) }

# for visualisation purposes, we pool individuals from multiple adjacent stations
# these pools are used for full maps
# original stations are shown in inset/fjord maps

#merge coordinates
latlong_group <- data.frame(Station_ID_New=metadata4$Station_ID_New,Lat=metadata4$Lat_dec,Lon=metadata4$Lon_dec)
stations <- unique(latlong_group$Station_ID_New[order(latlong_group$Station_ID_New)])

#create new station, lat and lon columns for grouped coords
latlong_group$Station_group <- latlong_group$Station_ID_New # column for station group name
latlong_group$Lat_group <- latlong_group$Lat # column for new latitude
latlong_group$Lon_group <- latlong_group$Lon # column for new longitude

# add values in these new columns
for(i in 1:nrow(latlong_group)){
  if(latlong_group$Station_ID_New[i] %in% stations[c(18:23,41,87)])#bf
  {latlong_group$Station_group[i] <- "BF"
  latlong_group$Lat_group[i] <- 58.3
  latlong_group$Lon_group[i] <- 11.83}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(13,39)]) #hal,ask
  {latlong_group$Station_group[i] <- "HA"
  latlong_group$Lat_group[i] <- 58.12
  latlong_group$Lon_group[i] <- 11.83}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(37:38)])#hak
  {latlong_group$Lat_group[i] <- 58
  latlong_group$Lon_group[i] <- 11.78}
  
  #if(latlong_group$Station_ID_New[i] %in% stations[c(45)])#hh
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(24,25)])#ell
  {latlong_group$Station_group[i] <- "ELL"
  latlong_group$Lat_group[i] <- 58.19
  latlong_group$Lon_group[i] <- 11.45}
  
  if(latlong_group$Station_ID_New[i] %in%stations[c(47)])#kol
  {latlong_group$Lat_group[i] <- 58.22
  latlong_group$Lon_group[i] <- 11.62}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(26,34,85,86,93)])#MG
  {latlong_group$Station_group[i] <- "MG"
  latlong_group$Lat_group[i] <- 58.3
  latlong_group$Lon_group[i] <- 11.53}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(81)])#sal
  {latlong_group$Lat_group[i] <- 58.44
  latlong_group$Lon_group[i] <- 11.71}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(32)])#fr
  {latlong_group$Lat_group[i] <- 58.47
  latlong_group$Lon_group[i] <- 11.57}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(15:17,94,102:104)])#B
  {latlong_group$Station_group[i] <- "B"
  latlong_group$Lat_group[i] <- 58.4
  latlong_group$Lon_group[i] <- 11.4}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(35:36,40,62)])#ugb
  {latlong_group$Station_group[i] <- "UGB"
  latlong_group$Lat_group[i] <- 58.28
  latlong_group$Lon_group[i] <- 11.34}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(30,42:44,72,80)])#NHV
  {latlong_group$Station_group[i] <- "NHV"
  latlong_group$Lat_group[i] <- 55.95
  latlong_group$Lon_group[i] <- 12.67}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(45,56,57)])#KH
  {latlong_group$Station_group[i] <- "KH"
  latlong_group$Lat_group[i] <- 57.93
  latlong_group$Lon_group[i] <- 11.7}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(27,65,66)])#FJ
  {latlong_group$Station_group[i] <- "FJ"
  latlong_group$Lat_group[i] <- 58.64
  latlong_group$Lon_group[i] <- 11.24}
  
  if(latlong_group$Station_ID_New[i] %in% stations[c(105)])#s, flytt
  {latlong_group$Lat_group[i] <- 58.48
  latlong_group$Lon_group[i] <- 11.25}
  
}
latlong_group

### create xyz objects for mapping ####
#### Large maps ####
# 0-group 2019
data2<-data.frame(latlong_group[,c(4:6)][metadata4$Age_comb=="0" & metadata4$Year=="2019",],grp$grp[metadata4$Age_comb=="0" & metadata4$Year=="2019"])
colnames(data2) <- c("Pop_name","Lat","Lon","grp.grp")
Count<-data.frame(data2 %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
xyz_019_g <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp)

# 0-group 2020
data_020<-data.frame(latlong_group[,c(4:6)][metadata4$Age_comb=="0" & metadata4$Year=="2020",],grp$grp[metadata4$Age_comb=="0" & metadata4$Year=="2020"])
colnames(data_020) <- c("Pop_name","Lat","Lon","grp.grp")
Count<-data.frame(data_020 %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
xyz_020_g <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp)

# 1-group 2020
data_120<-data.frame(latlong_group[,c(4:6)][metadata4$Age_comb=="1" & metadata4$Year=="2020",],grp$grp[metadata4$Age_comb=="1" & metadata4$Year=="2020"])
colnames(data_120) <- c("Pop_name","Lat","Lon","grp.grp")
Count<-data.frame(data_120 %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
xyz_120_g <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp)

#which cohort has the highest N per station pool?
max_019_g <- max(rowSums(xyz_019_g$z)) #38 inds
max_020_g <- max(rowSums(xyz_020_g$z)) #52 inds, highest
max_120_g <- max(rowSums(xyz_120_g$z)) #15 inds

# max_020_g is the highest, meaning we will scale pie size against this value

# dummy xyz object for size scale
xyz_dummy <- make.xyz(rep(12.8,4),c(58.6,58.8,59,59.2),c(1,10,30,50),c(3,3,3,3))

#### Inset maps ####
# 0-group 2019
data2<-data.frame(cbind(latlong[metadata4$Age_comb=="0" & metadata4$Year=="2019",],grp$grp[metadata4$Age_comb=="0" & metadata4$Year=="2019"]))
colnames(data2) <- c("Pop_name","Station_ID","Lat","Lon","grp.grp")
Count<-data.frame(data2 %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
xyz_019 <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp)

# 0-group 2020
data_020f<-data.frame(cbind(latlong[metadata4$Age_comb=="0" & metadata4$Year=="2020",],grp$grp[metadata4$Age_comb=="0" & metadata4$Year=="2020"]))
colnames(data_020f) <- c("Pop_name","Station_ID","Lat","Lon","grp.grp")
Count<-data.frame(data_020f %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
xyz_020 <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp)

# 1-group 2020
data_120f<-data.frame(cbind(latlong[metadata4$Age_comb=="1" & metadata4$Year=="2020",],grp$grp[metadata4$Age_comb=="1" & metadata4$Year=="2020"]))
colnames(data_120f) <- c("Pop_name","Station_ID","Lat","Lon","grp.grp")
Count<-data.frame(data_120f %>% group_by(Pop_name,Lat,Lon,grp.grp) %>% summarise(n=n()))
  #add a dummy point, to add one row in legend for "x"
  levels(Count$Pop_name) <- c(1:163) # add one Pop_name level (163)
  levels(Count$grp.grp) <- c(1,2,3) # add one grp.grp level (3)
  Count[62,] <- c(163,0,0,3,1) # add row in Count
  col2 <- c(col,"white") # new colour scale
  leg2 <- c(leg,"Zero catch") # new legend
xyz_120 <- make.xyz(Count$Lon,Count$Lat,Count$n,Count$grp.grp) #create xyz object

#which cohort has the highest N per station?
max_019 <- max(rowSums(xyz_019$z)) #14 inds, highest
max_020 <- max(rowSums(xyz_020$z)) #10 inds
max_120 <- max(rowSums(xyz_120$z)) #12 inds

# max_019 is the highest, meaning we will scale pie size against this value

# dummy xyz object for size scale
xyz_dummy_fj <- make.xyz(rep(12.06,4),c(58.379,58.411,58.443,58.475),c(1,5,10,15),c(3,3,3,3))

# 

### Fig. 4A: 0-group 2019 ####
#### Large map ####
full_map(xyz_019_g,col,leg,text.xy=c(5.97,55.77),lab,txtw=0.7,rad=0.08*sqrt(max_019_g/max_020_g)) #normalised against biggest pie in 2020 0grp
legend("topleft", title=" ",legend=" ",cex=0.9,box.col = "black", ncol=1,text.width = 1.7) #add legend
text(5.67,59.2,labels="A.",col="black",font=2,cex=1.5) # text box, label
text(6.61,59.18,labels="0-group 2019",col="black",font=1,cex=1.1) #add text
draw.pie(xyz_dummy$x,xyz_dummy$y,xyz_dummy$z,radius=0.08*sqrt(max(xyz_dummy$z)/max_020_g)) #dummy xyz for size legend
text(x=rep(13.1,4),y=c(58.6,58.8,59,59.2),c("n=1","n=10","n=30","n=50"),cex=0.8,adj=0) #text for size legend

#### Inset map ####
fjord_map(xyz_019,col,leg=NULL,text.xy=c(10.97,57.925),lab,txtw=0.12,rad=0.015)
draw.pie(xyz_dummy_fj$x,xyz_dummy_fj$y,xyz_dummy_fj$z,radius=0.015*sqrt(max(xyz_dummy_fj$z)/max(rowSums(xyz_019$z))))
text(x=rep(12.1,4),y=c(58.379,58.411,58.443,58.475),c("n=1","n=5","n=10","n=15"),cex=1.3,adj=0)

### Fig. 4B: 0-group 2020 ####
#### Large map ####
full_map(xyz_020_g,col,leg,text.xy=c(5.97,55.77),lab,txtw=0.7,rad=0.08)
legend("topleft", title=" ",legend=" ",cex=0.9,box.col = "black", ncol=1,text.width = 1.7)
text(5.67,59.2,labels="B.",col="black",font=2,cex=1.5)
text(6.61,59.18,labels="0-group 2020",col="black",font=1,cex=1.1)
draw.pie(xyz_dummy$x,xyz_dummy$y,xyz_dummy$z,radius=0.08*sqrt(max(xyz_dummy$z)/max(rowSums(xyz_020_g$z))))
text(x=rep(13.1,4),y=c(58.6,58.8,59,59.2),c("n=1","n=10","n=30","n=50"),cex=0.8,adj=0)
#### Inset map ####
fjord_map(xyz_020,col,leg=NULL,text.xy=c(10.97,57.925),lab,txtw=0.12,rad=0.015*sqrt(max_020/max_019))
draw.pie(xyz_dummy_fj$x,xyz_dummy_fj$y,xyz_dummy_fj$z,radius=0.015*sqrt(max(xyz_dummy_fj$z)/max(rowSums(xyz_019$z))))
text(x=rep(12.1,4),y=c(58.379,58.411,58.443,58.475),c("n=1","n=5","n=10","n=15"),cex=1.3,adj=0)

### Fig. 4C: grouped map 1-group 2020 ####
#### Large map ####
full_map(xyz_120_g,col,leg,text.xy=c(5.97,55.77),lab,txtw=0.9,rad=0.08*sqrt(max_120_g/max_020_g))
legend("topleft", title=" ",legend=" ",cex=0.9,box.col = "black", ncol=1,text.width = 1.7)
text(5.67,59.2,labels="C.",col="black",font=2,cex=1.5)
text(6.61,59.18,labels="1-group 2020",col="black",font=1,cex=1.1)
draw.pie(xyz_dummy$x,xyz_dummy$y,xyz_dummy$z,
         radius=0.08*sqrt(max(xyz_dummy$z)/max(rowSums(xyz_020_g$z)))) #scaled against x_020 bco scaling previously
text(x=rep(13.1,4),y=c(58.6,58.8,59,59.2),c("n=1","n=10","n=30","n=50"),cex=0.8,adj=0)
#add "X" at stations sampled in 2020 with no 1-group inds 
zero_catch <- filter(data_020,Pop_name %notin% data_120$Pop_name) # sampled stations in 2020 with no 1-group cod
draw.xy(as.numeric(zero_catch$Lon), as.numeric(zero_catch$Lat), as.numeric(zero_catch$Lon), as.numeric(zero_catch$Lat), width=0,height=0, bg = NA,border =NA, type = "p", pch=4,cex=1, col = "red3",lwd=1.2, silent = TRUE) #draw X:es

#### Inset map ####
fjord_map(xyz_120,col2,leg2,text.xy=c(10.97,57.945),lab,txtw=0.15,rad=0.015*sqrt(max_120/max_019))
draw.pie(xyz_dummy_fj$x,xyz_dummy_fj$y,xyz_dummy_fj$z,radius=0.015*sqrt(max(xyz_dummy_fj$z)/max(rowSums(xyz_019$z))))
text(x=rep(12.1,4),y=c(58.379,58.411,58.443,58.475),c("n=1","n=5","n=10","n=15"),cex=1.3,adj=0)
#add "X" at stations sampled in 2020 with no 1-group inds 
zero_catchf <- filter(data_020f,Pop_name %notin% data_120f$Pop_name) # sampled stations in 2020 with no 1-group cod
draw.xy(as.numeric(zero_catchf$Lon), as.numeric(zero_catchf$Lat), as.numeric(zero_catchf$Lon), as.numeric(zero_catchf$Lat), width=0,height=0, bg = NA,border =NA, type = "p", pch=4,cex=1, col = "red3",lwd=1.2, silent = TRUE) #draw X:es

#reorder pies and x:s in inkScape







# Sex assignment ####
# PCA
x.comb_LG11 <- tab(comb_LG11,freq=TRUE,NA.method="mean") 
pca.comb_LG11 <- dudi.pca(x.comb_LG11,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
s.class(pca.comb_LG11$li, fac=as.factor(pop(comb_LG11)), col=transp(inferno(70),.8),
        axesel=FALSE, cstar=0, cpoint=3, clabel = 0, xax=1,yax=2)
add.scatter.eig(pca.comb_LG11$eig,3,1,2, ratio=.3,sub="PC eigenvalues")

hist(pca.comb_LG11$li$Axis1, breaks=20,main="Histogram of PC1 coordinates") 
# The genotypes are bimodal along PC1, but there are a few intermediate individuals that are unclear
# for these loci, we expect females to be homozygous and males to be heterozygous (Star et al., 2016)
# therefore, we need to manually inspect the genotypes of individuals with intermediate PC1 coordinates to find cut-off

lg11_geno_pc1 <- data.frame(x.comb_LG11,PC1_coord=pca.comb_LG11$li$Axis1)
filter(lg11_geno_pc1,PC1_coord>0) %>% view # all inds with PC1_coord>0 are females
filter(lg11_geno_pc1,PC1_coord>0) %>% view # all inds with PC1_coord<0 are males

# assign inds to sex using 0 as a cut-off value
list_LG11 <- integer()
for(i in 1:987){
  if(pca.comb_LG11$li$Axis1[i] > 0){list_LG11[i] <- 1} # females=1
  if(pca.comb_LG11$li$Axis1[i] < 0){list_LG11[i] <- 2}} # males = 2 

#the genetic sex assignation is consistent with all adult samples that have been sexed previously!

#plot histogram
col=c("lightsalmon","lightskyblue2")
leg=c("Female","Male")

x <- data.frame(id=indNames(comb_sub),Sex=as.factor(list_LG11),PC1=pca.comb_LG11$li$Axis1) #data for plot
lg11_ass <- ggplot(x)+geom_histogram(mapping=aes(x=-PC1,fill=Sex))+theme_classic()+
  xlab(paste("PC1 (",round(pca.comb_LG11$eig[1]/sum(pca.comb_LG11$eig)*100,2)," %)",sep=""))+
  scale_fill_manual(labels=leg,values=col)+
  ylab("Count")
lg11_ass

# INV01 assignment ####
x.comb_INV01 <- tab(comb_INV01,freq=TRUE,NA.method="mean") 
pca.comb_INV01 <- dudi.pca(x.comb_INV01,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
hist(pca.comb_INV01$li$Axis1, breaks=2,)

# clearly binomial distr along PC1
# for inversions we expect clusters representing two homozygotes and one, intermediate, heterozygote 
# what do the bars represent?

comb_INV01$tab[pca.comb_INV01$li$Axis1 < (-0.5),] # mixed, one heterozygous (Gdist114351_4596) and one homozygous locus (Gdist114493_3343)
comb_INV01$tab[pca.comb_INV01$li$Axis1 > (-0.5),] # homozygote

# assign inversion state based on this information
list_INV01 <- integer()
for(i in 1:987){
  if(pca.comb_INV01$li$Axis1[i] < -0.5){list_INV01[i] <- 1} #mixed 
  if(pca.comb_INV01$li$Axis1[i] > -0.5 ){list_INV01[i] <- 2}} #homo

#plot histogram
x <- data.frame(id=indNames(comb_sub),INV01=as.factor(list_INV01),PC1=pca.comb_INV01$li$Axis1)
i1_ass <- ggplot(x)+geom_histogram(mapping=aes(x=PC1,fill=INV01))+theme_classic()+
  xlab(paste("PC1 (",round(pca.comb_INV01$eig[1]/sum(pca.comb_INV01$eig)*100,2)," %)",sep=""))+
  ylab("Count")+scale_fill_manual(name="Chr 1 inversion state",
                                  labels=c("Mixed","Ancestral"),
                                  values=c("dodgerblue","dodgerblue4"))
i1_ass

# INV02 assignment ####
x.comb_INV02 <- tab(comb_INV02,freq=TRUE,NA.method="mean") 
pca.comb_INV02 <- dudi.pca(x.comb_INV02,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)

s.class(pca.comb_INV02$li, fac=as.factor(pop(comb_INV02)), col=funky(length(popNames(comb_INV02))),
        axesel=FALSE, cstar=0, cpoint=3, clabel = 1, xax=1,yax=2)
add.scatter.eig(pca.comb_INV02$eig,3,1,2, ratio=.3,sub="PC eigenvalues")
hist(pca.comb_INV02$li$Axis1,breaks=100)

# looks more trimodal, but what do the intermediate inds represent?
inv02_geno_pc1 <- data.frame(x.comb_INV02,PC1_coord=pca.comb_INV02$li$Axis1)
filter(inv02_geno_pc1,PC1_coord < (-1.5)) # homozygotes
filter(inv02_geno_pc1,PC1_coord > -1.5,PC1_coord < -1) # mixed
filter(inv02_geno_pc1,PC1_coord > -1,PC1_coord < -0.5) # heterozygotes
filter(inv02_geno_pc1,PC1_coord > -0.5,PC1_coord < -0.35) # one heterozygous locus, and one locus with failed genotyping - will be treated as heterozygotes
filter(inv02_geno_pc1,PC1_coord > -0.35,PC1_coord < 0) # mixed
filter(inv02_geno_pc1,PC1_coord > 0) # homozygotes

# Assign inversion state based on this info
list_INV02 <- integer()
for(i in 1:987){
  if(pca.comb_INV02$li$Axis1[i] < -1.5){list_INV02[i] <- 1} #homo1
  if(pca.comb_INV02$li$Axis1[i] > -1.5){list_INV02[i] <- 3} #het
  if(pca.comb_INV02$li$Axis1[i] > 0){list_INV02[i] <- 5} #homo2
  if(-1.4 < pca.comb_INV02$li$Axis1[i] & pca.comb_INV02$li$Axis1[i] < -1.2){list_INV02[i] <- 2} #mixed 1
  if(-0.35 < pca.comb_INV02$li$Axis1[i] & pca.comb_INV02$li$Axis1[i] < -0.2){list_INV02[i] <- 4}} #mixed 2

#plot histogram
col <- c("yellow2","yellow4","green3","dodgerblue","dodgerblue4") 
leg <- c("Derived","Mixed 1","Heterozygote","Mixed 2","Ancestral")#note "-" before list_INV02 

x <- data.frame(id=indNames(comb_sub),INV02=as.factor(-list_INV02),PC1=pca.comb_INV02$li$Axis1)

i2_ass <- ggplot(x)+geom_histogram(mapping=aes(x=-PC1,fill=INV02))+theme_classic()+
  xlab(paste("PC1 (",round(pca.comb_INV02$eig[1]/sum(pca.comb_INV02$eig)*100,2)," %)",sep=""))+
  ylab("Count")+scale_fill_manual(name="Chr 2 inversion state",
                                  labels=leg,values=col)
i2_ass

# INV07 assignment ####
x.comb_INV07 <- tab(comb_INV07,freq=TRUE,NA.method="mean") 
pca.comb_INV07 <- dudi.pca(x.comb_INV07,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
s.class(pca.comb_INV07$li, fac=as.factor(pop(comb_INV07)), col=funky(length(popNames(comb_INV07))),
        axesel=FALSE, cstar=0, cpoint=3, clabel = 0, xax=1,yax=2)
add.scatter.eig(pca.comb_INV07$eig,3,1,2, ratio=.3,sub="PC eigenvalues")
hist(pca.comb_INV07$li$Axis1,breaks=100)

# clearly trimodal, but check the intermediate inds as before
inv07_geno_pc1 <- data.frame(x.comb_INV07,PC1_coord=pca.comb_INV07$li$Axis1)
filter(inv07_geno_pc1,PC1_coord < (-1.5)) # homozygotes
filter(inv07_geno_pc1,PC1_coord > -1.5,PC1_coord < -1) # two homozygous loci, one locus with failed genotyping - will be treated as homozygotes
filter(inv07_geno_pc1,PC1_coord > -1,PC1_coord < -0.5) # one homozygous locus, two loci with failed genotyping - will be treated as homozygotes
filter(inv07_geno_pc1,PC1_coord > -0.5,PC1_coord < -0.35) # heterozygotes
filter(inv07_geno_pc1,PC1_coord > -0.35,PC1_coord < -0.2) # two heterozygous loci, and one locus with failed genotyping - will be treated as heterozygotes
filter(inv07_geno_pc1,PC1_coord > -0.2,PC1_coord < 0.5) # one homozygous locus, two loci with failed genotyping - will be treated as homozygote
filter(inv07_geno_pc1,PC1_coord > 0.5) # homozygotes

# assign inversion state based on this information
list_INV07 <- integer()
for(i in 1:987){
  if(pca.comb_INV07$li$Axis1[i] < -1.0){list_INV07[i] <- 1} #homo1
  if(pca.comb_INV07$li$Axis1[i] > -1.0){list_INV07[i] <- 2} #het
  if(pca.comb_INV07$li$Axis1[i] > 0){list_INV07[i] <- 3} } #homo2

#plot histogram
col <- c("yellow2","green3","dodgerblue4")
leg <- c("Derived","Heterozygote","Ancestral")

x <- data.frame(id=indNames(comb_sub),INV07=as.factor(list_INV07),PC1=pca.comb_INV07$li$Axis1)
i7_ass <- ggplot(x)+geom_histogram(mapping=aes(x=PC1,fill=INV07))+theme_classic()+
  xlab(paste("PC1 (",round(pca.comb_INV07$eig[1]/sum(pca.comb_INV07$eig)*100,2)," %)",sep=""))+
  ylab("Count")+scale_fill_manual(name="Chr 7 inversion state",
                                  labels=leg,values=col)
i7_ass

# INV12 assignment ####
x.comb_INV12 <- tab(comb_INV12,freq=TRUE,NA.method="mean") 
pca.comb_INV12 <- dudi.pca(x.comb_INV12,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
s.class(pca.comb_INV12$li, fac=as.factor(pop(comb_INV12)), col=funky(levels(popNames(comb_INV12))),
        axesel=FALSE, cstar=0, cpoint=3, clabel = 1, xax=1,yax=2)
hist(pca.comb_INV12$li$Axis1,breaks=100)

# trimodal, but many intermediate points. check as before
inv12_geno_pc1 <- data.frame(x.comb_INV12,PC1_coord=pca.comb_INV12$li$Axis1)
filter(inv12_geno_pc1,PC1_coord < (-1.5)) # homozygotes 011001
filter(inv12_geno_pc1,PC1_coord > -1.5,PC1_coord < -1.2) # two homozygous loci, and one heterozygous locus - will be treated as mixed
filter(inv12_geno_pc1,PC1_coord > -1.2,PC1_coord < -1) # two homozygous loci, one locus with failed genotyping - will be treated as homozygous
filter(inv12_geno_pc1,PC1_coord > -1,PC1_coord < -0.5) # one homozygous locus, two loci with failed genotyping - will be treated as homozygous
filter(inv12_geno_pc1,PC1_coord > -0.5,PC1_coord < -0.405) # one heterozygous locus, one homozygous locus, one alternate homozygous locus - treated as NA
filter(inv12_geno_pc1,PC1_coord > -0.405,PC1_coord < -0.3) # heterozygous
filter(inv12_geno_pc1,PC1_coord > -0.3,PC1_coord < -0.2) # two heterozygous loci, one locus with failed genotyping - treated as heterozygous
filter(inv12_geno_pc1,PC1_coord > -0.2,PC1_coord < -0.1) # one heterozygous loci, two locus with failed genotyping - treated as heterozygous
filter(inv12_geno_pc1,PC1_coord > -0.1,PC1_coord < 0.1) # two heterozygous loci, one homozygous locus - treated as mixed 
filter(inv12_geno_pc1,PC1_coord > 0.1,PC1_coord < 0.5) # two homozygous loci, one heterozygous locus - treated as mixed
filter(inv12_geno_pc1,PC1_coord > 0.5,PC1_coord < 0.7) # two homozygous loci, one failed locus - treated as homozygous
filter(inv12_geno_pc1,PC1_coord > 0.7,PC1_coord < 1) # homozygotes 

x <- data.frame(list_INV12,inv12_geno_pc1)
filter(x,is.na(list_INV12))

# assign inversion state according to this information
list_INV12 <- integer()
for(i in 1:987){
  if(pca.comb_INV12$li$Axis1[i] < -0.5){list_INV12[i] <- 1} #homo1
  if(pca.comb_INV12$li$Axis1[i] > -0.405){list_INV12[i] <- 3} #het
  if(pca.comb_INV12$li$Axis1[i] > 0.5){list_INV12[i] <- 5} #homo2
  if(-1.3 < pca.comb_INV12$li$Axis1[i] & pca.comb_INV12$li$Axis1[i] < -1){list_INV12[i] <- 2} #mixed 1
  if(0 < pca.comb_INV12$li$Axis1[i] & pca.comb_INV12$li$Axis1[i] < 0.41){list_INV12[i] <- 4}} #mixed 2

#plot hist
col <- c("yellow2","yellow4","green3","dodgerblue","dodgerblue4")
leg <- c("Derived","Mixed 1","Heterozygote","Mixed 2","Ancestral")#note "-" before list_INV12 

x <- na.omit(data.frame(id=indNames(comb_sub),INV12=as.factor(-list_INV12),PC1=pca.comb_INV12$li$Axis1))

i12_ass <- ggplot(x)+geom_histogram(mapping=aes(x=-PC1,fill=INV12))+theme_classic()+
  xlab(paste("PC1 (",round(pca.comb_INV12$eig[1]/sum(pca.comb_INV12$eig)*100,2)," %)",sep=""))+
  ylab("Count")+scale_fill_manual(name="Chr 12 inversion state",
                                  labels=leg,values=col)
i12_ass

# Fig. S2: INV, sex assignment ####
i_dummy2 <- i12_ass+scale_fill_manual(name="Inversion state",
                                      labels=leg,values=col)
i_empty <- ggplot()+geom_histogram()
i_all <- ggarrange(i1_ass+ggtitle("Chr 1 inversion"),i2_ass+ggtitle("Chr 2 inversion"),
                       i7_ass+ggtitle("Chr 7 inversion"),i12_ass+ggtitle("Chr 12 inversion"),ncol=2,nrow=2,labels="AUTO",
                       common.legend = T,legend.grob = get_legend(i_dummy2),legend="right")

lg11_empty <- ggarrange(lg11_ass+ggtitle("Sex"),i_empty,i_empty,i_empty,nrow=2,ncol=2,
                        labels=c("E","F","G","H"),
                        common.legend = T,legend="right")

ggarrange(i_all,lg11_empty,nrow=2)

# Hb assignment ####
# genotypes at each Hb locus will be analysed separately
# however, they can be assigned using tab(comb_Hb) (0=hom1, 0.5=het, 1=hom2)
# intermittent points are an effect of NA.method="mean" - we treat these as NA
x.comb_Hb <- tab(comb_Hb,freq=TRUE,NA.method="mean") 

#Hba1
hist(x.comb_Hb[,1])
list_Hba1 <- integer()
for(i in 1:987){
  if(x.comb_Hb[i,1] == 0.0){list_Hba1[i] <- 1} # homozygote 1
  if(x.comb_Hb[i,1] == 0.5){list_Hba1[i] <- 2} # heterozygote
  if(x.comb_Hb[i,1] == 1.0){list_Hba1[i] <- 3} } # homozygote 2

#Hba4
hist(x.comb_Hb[,2])
list_Hba4 <- integer()
for(i in 1:987){
  if(x.comb_Hb[i,3] == 0.0){list_Hba4[i] <- 1}
  if(x.comb_Hb[i,3] == 0.5){list_Hba4[i] <- 2}
  if(x.comb_Hb[i,3] == 1.0){list_Hba4[i] <- 3} }

#Hbb1
hist(x.comb_Hb[,3])
list_Hbb1 <- integer()
for(i in 1:987){
  if(x.comb_Hb[i,5] == 0.0){list_Hbb1[i] <- 1}
  if(x.comb_Hb[i,5] == 0.5){list_Hbb1[i] <- 2}
  if(x.comb_Hb[i,5] == 1.0){list_Hbb1[i] <- 3} }

#Hbb5
hist(x.comb_Hb[,4])
list_Hbb5 <- integer()
for(i in 1:987){
  if(x.comb_Hb[i,7] == 1.0){list_Hbb5[i] <- 1}
  if(x.comb_Hb[i,7] == 0.5){list_Hbb5[i] <- 2}
  if(x.comb_Hb[i,7] == 0.0){list_Hbb5[i] <- 3} }

# add assignments to metadata4 ####
metadata5 <- data.frame(metadata4,grp$grp,eco,list_Hba1,list_Hba4,list_Hbb1,list_Hbb5,list_INV01,list_INV02,list_INV07,list_INV12,list_LG11)

# DIFFERENCES BETWEEN ECOTYPES, BARPLOTS ####  

## SEX ----

comb_grp_LG11_dat <-data.frame(indNames(comb_sub),pop(comb_LG11),eco,list_LG11)
colnames(comb_grp_LG11_dat)<-c("Ind","Pop_name","Eco","Sex")
Count_grp_LG11<-data.frame(comb_grp_LG11_dat[,] %>% group_by(Eco,Sex) %>% summarise(n=n()))

#stacked barplot
ggplot(Count_grp_LG11, aes(x=Eco,fill=as.factor(Sex),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("lightsalmon","lightskyblue2"),
                    name = "Sex",labels = c("Female", "Male"))+
  labs(title="Sex",x="Ecotype",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> lg11

## INVs ----
comb_grp_INV_dat <-data.frame(indNames(comb_sub),pop(comb_sub),eco,list_INV01,list_INV02,list_INV07,list_INV12)
colnames(comb_grp_INV_dat)<-c("Ind","Pop_name","Eco","INV01","INV02","INV07","INV12")
Count_grp_INV01<-data.frame(comb_grp_INV_dat %>% group_by(Eco,INV01) %>% summarise(n=n())) %>% data.frame() %>%  filter(INV01==2)
Count_grp_INV02<-data.frame(comb_grp_INV_dat %>% group_by(Eco,INV02) %>% summarise(n=n())) %>% data.frame() %>%  filter(INV02 %in% c(1,3,5))
Count_grp_INV07<-data.frame(comb_grp_INV_dat %>% group_by(Eco,INV07) %>% summarise(n=n()))
Count_grp_INV12<-data.frame(comb_grp_INV_dat %>% group_by(Eco,INV12) %>% summarise(n=n())) %>% data.frame() %>%  filter(INV12 %in% c(1,3,5))

# Stacked + percent
ggplot(Count_grp_INV01, aes(x=Eco,fill=as.factor(INV01),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("dodgerblue4"),
                    name = "LG1 inversion state", 
                    labels = c("Ancestral"))+
  labs(title="LG1 inversion",x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> i1

ggplot(Count_grp_INV02, aes(x=Eco,fill=as.factor(-INV02),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("yellow2","green3","dodgerblue4"),
                    name = "LG2 inversion state", 
                    labels = c("Derived", "Heterozygote", "Ancestral"))+
  labs(title="LG2 inversion",x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> i2

ggplot(Count_grp_INV07, aes(x=Eco,fill=as.factor(INV07),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("yellow2","green3","dodgerblue4"),
                    name = "LG7 inversion state", 
                    labels = c("Derived", "Heterozygote", "Ancestral"))+
  labs(title="LG7 inversion",x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() ->i7

ggplot(Count_grp_INV12, aes(x=Eco,fill=as.factor(-INV12),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("yellow2","green3","dodgerblue4"),
                    name = "LG12 inversion state", 
                    labels = c("Derived", "Heterozygote", "Ancestral"))+
  labs(title="LG12 inversion",x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> i12

i_dummy <- i12+scale_fill_manual(values=c("yellow2","green3","dodgerblue4"),name = "Inversion state",labels = c("Derived", "Heterozygote", "Ancestral"))


## Hb ####
comb_grp_Hb_dat <-data.frame(indNames(comb_sub),pop(comb_sub) %>% as.character,eco,list_Hba1,list_Hba4,list_Hbb1,list_Hbb5)
colnames(comb_grp_Hb_dat)<-c("Ind","Pop_name","Eco","Hb_alpha1","Hb_alpha4","Hb_beta1","Hb_beta5")
Count_grp_Hba1<-data.frame(comb_grp_Hb_dat %>% group_by(Eco,Hb_alpha1) %>% summarise(n=n()))
Count_grp_Hba4<-data.frame(comb_grp_Hb_dat %>% group_by(Eco,Hb_alpha4) %>% summarise(n=n()))
Count_grp_Hbb1<-data.frame(comb_grp_Hb_dat %>% group_by(Eco,Hb_beta1) %>% summarise(n=n()))
Count_grp_Hbb5<-data.frame(comb_grp_Hb_dat %>% group_by(Eco,Hb_beta5) %>% summarise(n=n()))

# Stacked + percent
ggplot(Count_grp_Hba1, aes(x=Eco,fill=as.factor(Hb_alpha1),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("pink","red","red4"),
                    name = expression("Hb-"*alpha*1~genotype), 
                    labels = c("Homozygote 1", "Heterozygote", "Homozygote 2"))+
  labs(title=expression("Hb-"*alpha*1),x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> hba1

ggplot(na.omit(Count_grp_Hba4), aes(x=Eco,fill=as.factor(Hb_alpha4),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("pink","red","red4"),
                    name = expression("Hb-"*alpha*4~genotype), 
                    labels = c("Homozygote 1", "Heterozygote", "Homozygote 2"))+
  labs(title=expression("Hb-"*alpha*4),x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> hba4

ggplot(na.omit(Count_grp_Hbb1), aes(x=Eco,fill=as.factor(Hb_beta1),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("pink","red","red4"),
                    name = expression("Hb-"*beta*1~genotype), 
                    labels = c("Homozygote 1", "Heterozygote", "Homozygote 2"))+
  labs(title=expression("Hb-"*beta*1),x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> hbb1

ggplot(na.omit(Count_grp_Hbb5), aes(x=Eco,fill=as.factor(Hb_beta5),y=n)) +
  geom_bar(position="fill", stat="identity",width=0.6) +
  scale_fill_manual(values=c("pink","red","red4"),
                    name = expression("Hb-"*beta*5~genotype), 
                    labels = c("Homozygote 1", "Heterozygote", "Homozygote 2"))+
  labs(title=expression("Hb-"*beta*5),x=" ",y="Proportion")+
  scale_y_continuous(labels = percent)+
  scale_x_discrete(limits=c("Offshore","Coastal"))+
  theme_classic() -> hbb5

hb_dummy <- hbb5+
  scale_fill_manual(values=c("pink","red","red4"),name = "Hb genotype",labels = c("Homozygote 1", "Heterozygote", "Homozygote 2"))

ggarrange(hba1 + rremove("x.text"),hba4+ rremove("x.text"),hbb1,hbb5,labels = "AUTO",ncol = 2, nrow = 2)


## Fig. 5: ALL BARS IN ONE PLOT ####
#row 1
abc <- ggarrange(i1,i2,i7,labels = "AUTO",ncol = 3, nrow = 1, align="v",legend="right",common.legend = TRUE,
                  legend.grob = get_legend(i_dummy,position="right"))
#row 2
def <- ggarrange(i12,hba1,hba4,labels = c("D","E","F"),ncol = 3, nrow = 1, align="v",legend="right",common.legend = TRUE,
                  legend.grob = get_legend(hb_dummy,position="right"))
#row 3
ghi <- ggarrange(hbb1,hbb5,lg11,labels = c("G","H","I"),ncol = 3, nrow = 1, align="v",legend="right",common.legend = TRUE,
                  legend.grob = get_legend(lg11,position="right"))
#combined
ggarrange(abc,def,ghi,nrow=3)
#ggsave("Figures/bar_all_wide.svg",scale=1,dpi=300)

# TEST FOR DIFFERENCES BTW ECOTYPES ####

## Sex (Chi2 test) ####
# create xtabs object
x <- xtabs(~list_LG11+grp.grp,metadata5) %>% data.frame

# create matrix
chi2_mat <- matrix(nrow=2,ncol=2,data=c(x$Freq[1],x$Freq[3],x$Freq[2],x$Freq[4]),
                   dimnames=list(c("Offshore","Coastal"),c("Female","Male")))

#perform Pearson's Chi-squared test with Yates' continuity correction
chi2_test <- chisq.test(chi2_mat)
## INV, Hb (StrataG) ----

# first, make genepop files with "superlocus genotypes"
# we do this by exporting a txt file
write.table(data.frame(indNames(comb),list_INV01,list_INV02,list_INV07,list_INV12),"GenePop/table_for_supergenotypes.txt")
# then recode assigned inversion state/sex manually to write genepop files (.gen) for INV

# read superlocus genotypes
comb_grp_INV_super <- read.genepop("genotypes_inv_superlocus.gen")
pop(comb_grp_INV_super) <- grp$grp

# create separate genind objects by removing "mixed inversion" inds
# INV01 will be excluded as there is no genetic variation after we remove "mixed" inds
comb_grp_INV02_super <- comb_grp_INV_super[list_INV02 %in% c(1,3,5)]
comb_grp_INV07_super <- comb_grp_INV_super
comb_grp_INV12_super <- comb_grp_INV_super[list_INV12 %in% c(1,3,5)]

# Hb genind object with ecotype as pop
comb_grp_Hb <- comb_Hb
pop(comb_grp_Hb) <- grp$grp

# convert genind -> gtypes
g_INV02 <- genind2gtypes(comb_grp_INV02_super)
g_INV07 <- genind2gtypes(comb_grp_INV07_super)
g_INV12 <- genind2gtypes(comb_grp_INV12_super)
g_Hb <- genind2gtypes(comb_grp_Hb)

# create input and output list for strataG
input <- c(g_INV02,g_INV07,g_INV12,g_Hb)
output <- list()
  
for(i in 1:length(input)){
  output[[i]] <- overallTest(
    input[[i]],
    nrep = 10000,
    stats = "all",
    keep.null = TRUE,
    by.locus = TRUE,
    quietly = FALSE,
    max.cores = 1)
}
output[[1]]

# extract Fst
Fst <- c(output[[1]]$result[3,16,1], #INV02
         output[[2]]$result[4,16,1], #INV07
         output[[3]]$result[5,16,1], #INV12
         output[[4]]$result[2,16,1], #Hba1
         output[[4]]$result[3,16,1], #Hba4
         output[[4]]$result[4,16,1], #Hbb1
         output[[4]]$result[5,16,1]) #Hbb5
# extract p-values
p.Fst <- c(output[[1]]$result[3,16,2], #INV02
           output[[2]]$result[4,16,2], #INV07
           output[[3]]$result[5,16,2], #INV12
           output[[4]]$result[2,16,2], #Hba1
           output[[4]]$result[3,16,2], #Hba4
           output[[4]]$result[4,16,2], #Hbb1
           output[[4]]$result[5,16,2]) #Hbb5

# summarise results in df
overalltest <- data.frame(Loc=c("INV02","INV07","INV12","Hba1","Hba4","Hbb1","Hbb5"),
                                 Fst,p=p.Fst)
overalltest

## FDR corr for INV, Hb, Sex tests ####
p.adjust(c(chi2_test$p.value,overalltest$p),method="fdr")

# OBS! Test for differences in proportions between years ####
## Data preparation ####
# OBS! make sure the names are the same in both years
#inspect names
x <- data.frame(metadata5$Station_ID_New,metadata5$Survey_year)
view(unique(x))
#change names
metadata5$Station_ID_New2 <- metadata5$Station_ID_New
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_Year=="Brofjorden_GT19","Brofjorden_grund_inre")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2==	"Byfjorden1","Byfjorden_N")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2==	"Byfjorden2","Byfjorden_S")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Ells","Ellsfjorden")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Fladen_SE","Fladen")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Hakefjorden_snholmarna","Hakefjorden")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="NV_Hven","Hven_NW")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Kungen_NE","Kungen")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Kungsbacka","Kungsbackafjorden")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Marsstrand","Marstrandsfjorden")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Musn","Musfjorden")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Onsala","Onsala_S")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Rss_S","Ross_S")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Skr_Inre","Skr")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2 %in% c("Vedbak","Vedbck"),"Vedbaek")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Vinga_NW","Vinga")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_Year=="byfjorden_GT19","byfjorden_inre")
metadata5$Station_ID_New2 <- replace(metadata5$Station_ID_New2,metadata5$Station_ID_New2=="Havsstensfjorden","Havstensfjorden")
#inspect new names
x <- data.frame(metadata5$Station_ID_New2,metadata5$Survey_year)
view(unique(x))

# Station-wise data for juveniles collected in 2019-2020
juv1920 <- metadata4$Sample_type=="Juvenile" & metadata4$Year %in% c("2019","2020")
station_meta_1920 <- metadata5[juv1920,] %>% 
    group_by(Station_ID_New2,Subdiv,Survey_code,Year,Lat_dec,Lon_dec,Dist_baseline_m,Depth_m,Kg_per_h,Tot_no_per_h,Age_comb) %>% 
    summarise(prop_coast=mean((as.numeric(grp.grp)-1)),prop_F=mean(1-(as.numeric(list_LG11)-1)),n=n()) %>% data.frame
station_meta_1920

#filter to only include stations that have data from the same survey in both years  
#0-groups both years:
station_meta_19_0_vs_20_0 <- filter(station_meta_1920,Age_comb=="0") %>%
  group_by(Station_ID_New2,Survey_code) %>%
  filter(all(2019:2020 %in% Year)) %>% data.frame
# station_meta_1920_0 %>% view #changing the station names gives us 102 rows, instead of 62 if we used Station_ID_New

#0-group 2019, 1-group 2020:
station_meta_19_0_vs_20_1 <- filter(station_meta_1920,Year=="2019" & Age_comb=="0"|Year=="2020"& Age_comb=="1") %>%
  group_by(Station_ID_New2,Survey_code) %>%
  filter(all(2019:2020 %in% Year)) %>% data.frame
# station_meta_19_0_vs_20_1 %>% view


## Weighted ANOVA for interannual differences in ecotype proportions ####
#inter-cohort:
w.anova <- list()
w.anova[[1]] <- lm(prop_coast~Year,filter(station_meta_19_0_vs_20_0,Dist_baseline_m<0),weights=n) %>% Anova %>% data.frame #no effect in offshore region
w.anova[[2]] <- lm(prop_coast~Year,filter(station_meta_19_0_vs_20_0,Dist_baseline_m>0),weights=n) %>% Anova %>% data.frame #no effect in inshore

#intra-cohort:
w.anova[[3]] <- lm(prop_coast~Year,filter(station_meta_19_0_vs_20_1,Dist_baseline_m<0,Subdiv!="23"),weights=n) %>% Anova %>% data.frame #no effect in offshore
w.anova[[4]] <- lm(prop_coast~Year,filter(station_meta_19_0_vs_20_1,Dist_baseline_m>0,Subdiv!="23"),weights=n) %>% Anova %>% data.frame #sign. effect inshore!

#all
w.anova
#extract p values
pvals <- c(w.anova[[1]]$Pr..F.[1],w.anova[[2]]$Pr..F.[1],w.anova[[3]]$Pr..F.[1],w.anova[[4]]$Pr..F.[1])
#fdr correction
pvals.fdr <- p.adjust(pvals,method="fdr")
  
## weighted ANOVA for interannual differences in sex ratios  ####
w.anova_sex <- list()

#inter-cohort
w.anova_sex[[1]] <- lm(prop_F~Year,filter(station_meta_19_0_vs_20_0,Dist_baseline_m<0),weights=n) %>% Anova %>% data.frame #no effect in offshore region
w.anova_sex[[2]] <- lm(prop_F~Year,filter(station_meta_19_0_vs_20_0,Dist_baseline_m>0),weights=n) %>% Anova %>% data.frame #no effect in inshore

#intra-cohort
w.anova_sex[[3]] <- lm(prop_F~Year,filter(station_meta_19_0_vs_20_1,Dist_baseline_m<0,Subdiv!="23"),weights=n) %>% Anova %>% data.frame #no effect in offshore
w.anova_sex[[4]] <- lm(prop_F~Year,filter(station_meta_19_0_vs_20_1,Dist_baseline_m>0,Subdiv!="23"),weights=n) %>% Anova %>% data.frame #sign. effect inshore!

pvals <- c(w.anova_sex[[1]]$Pr..F.[1],w.anova_sex[[2]]$Pr..F.[1],w.anova_sex[[3]]$Pr..F.[1],w.anova_sex[[4]]$Pr..F.[1])
pvals.fdr <- p.adjust(pvals,method="fdr") #all NS


#_______________####

# OBS! Regression modelling, model selection ####
# Create metadata table ####
metadata5 %>% names
meta <- metadata5[,c("Sample_type","Station_ID_New","Survey_code","Year","Station_ID_Year",
                     "New_ID","Age_comb","Subdiv","Lat_dec","Lon_dec",
                     "Dist_baseline_m","Depth_m","grp.grp","list_Hba1","list_Hba4",
                     "list_Hbb1","list_Hbb5","list_INV01","list_INV02","list_INV07",
                     "list_INV12","list_LG11")]

names(meta)
str(meta_ultrasub)
str(meta)


#add correct data.class
meta[] <- mapply(function(x, FUN) FUN(x),
                          meta, 
                          list(as.character,as.character,as.character,as.character,as.character,
                               as.character,as.factor,as.character,as.numeric,as.numeric,
                               as.numeric,as.numeric,as.factor,as.factor,as.factor,
                               as.factor,as.factor,as.factor,as.factor,as.factor,
                               as.factor,as.factor), 
                          SIMPLIFY = FALSE)
str(meta)

#rename columnns 13-22
colnames(meta)[13:22] <- c("Eco","Hba1","Hba4","Hbb1","Hbb5","INV01","INV02","INV07","INV12","Sex")

#create dist_km column
meta$Dist_baseline_km <- meta$Dist_baseline_m/1000

#cohort column
meta$cohort <- rep(NA,nrow(meta))
meta$cohort <- replace(meta$cohort,meta$Year=="2019" & meta$Age_comb=="0","2019")
meta$cohort <- replace(meta$cohort,meta$Year=="2019" & meta$Age_comb=="1","2018")
meta$cohort <- replace(meta$cohort,meta$Year=="2020" & meta$Age_comb=="0","2020")
meta$cohort <- replace(meta$cohort,meta$Year=="2020" & meta$Age_comb=="1","2019")
meta$cohort <- meta$cohort %>% as.factor

# Juvenile and station metadata ####

#filter out adults from metadata
meta_juv <- filter(meta,Sample_type=="Juvenile",Subdiv %notin% c("4A","4B"),Year!="2015",cohort %in% c("2019","2020"))
unique(meta_juv$Subdiv)

#create individual-level metadata including only 0-group juveniles
meta_juv0 <- filter(meta,Sample_type=="Juvenile",Subdiv %notin% c("4A","4B"),Year!="2015",Age_comb=="0",cohort %in% c("2019","2020")) %>% mutate(log.Depth_m=log(Depth_m))

#create station-level metadata
station_meta_juv0 <- meta_juv0 %>% group_by(Station_ID_New,Survey_code,Year,Subdiv,
                                            Lat_dec,Lon_dec,Dist_baseline_km,
                                            Depth_m) %>% 
  summarise(prop_coast=mean(as.numeric(Eco)-1),
            prop_F=1-mean(as.numeric(Sex)-1),
            n=n())


# Linear regression models (Ecotype proportions, Sex ratio) ####
## INSPECT DATA ####

### OBS! variables ####
station_meta_juv0 %>% names

ggplot(data = station_meta_juv0,
       mapping = aes(x = Dist_baseline_km)) +
  geom_histogram() +
  theme_classic()
#Ok

ggplot(data = station_meta_juv0,
       mapping = aes(x = Depth_m)) +
  geom_histogram() +
  theme_classic()
#VERY SKEWED
ggplot(data = station_meta_juv0,
       mapping = aes(x = log(Depth_m))) +
  geom_histogram() +
  theme_classic()
#better, use log-transformed depth

ggplot(data = station_meta_juv0,
       mapping = aes(x = prop_coast)) +
  geom_histogram() +
  theme_classic()

#skewed to both ends of the spectrum

### Relation between variables ####

#collinearity
station_meta_juv0 %>% names
mutate(station_meta_juv0,log_Depth_m=log(Depth_m),num.subdiv=as.numeric(Subdiv))[,c(6:11)] %>% pairs()
mutate(station_meta_juv0,log_Depth_m=log(Depth_m),num.subdiv=as.numeric(Subdiv))[,c(6:11)] %>% cor() %>% view
#dist and log(depth) are slightly collinear (r2=-0.64)
ggplot()+
  geom_point(data=meta_juv0,mapping=aes(x=log(Depth_m),y=Dist_baseline_km))

### Interactions, Eco as response ####
#dist*depth 2 levels
ggplot()+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=prop_coast),col="red")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=prop_coast))+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=prop_coast),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=prop_coast),col="black",method="lm")

#dist*depth 4 levels
ggplot()+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km< -20),mapping=aes(x=log(Depth_m),y=prop_coast),col="red")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km< -20),mapping=aes(x=log(Depth_m),y=prop_coast),col="red",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km<0 & Dist_baseline_km>-20),mapping=aes(x=log(Depth_m),y=prop_coast),col="orange")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km<0 & Dist_baseline_km>-20),mapping=aes(x=log(Depth_m),y=prop_coast),col="orange",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>20),mapping=aes(x=log(Depth_m),y=prop_coast),col="black")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>20),mapping=aes(x=log(Depth_m),y=prop_coast),col="black",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>0 & Dist_baseline_km<20),mapping=aes(x=log(Depth_m),y=prop_coast),col="blue")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>0 & Dist_baseline_km<20),mapping=aes(x=log(Depth_m),y=prop_coast),col="blue",method="lm")+
  theme_classic()
#MAY BE SOMETHING HERE

#year*depth
ggplot()+
  geom_point(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=prop_coast),col="red")+
  geom_point(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=prop_coast))+
  geom_smooth(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=prop_coast),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=prop_coast),col="black",method="lm")
#NO INTERACTION  

#year*dist
ggplot()+
  geom_point(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="red")+
  geom_point(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=prop_coast))+
  geom_smooth(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="black",method="lm")
#PROBABLY NO INTERACTION

#subdiv*depth
ggplot()+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=prop_coast),col="blue")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=prop_coast),col="red")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=prop_coast),col="yellow3")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=prop_coast),col="blue",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=prop_coast),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=prop_coast),col="yellow3",method="lm")
#MAYBE AN INTERACTION

#subdiv*dist
ggplot()+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="blue")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="red")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="yellow3")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="blue",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=prop_coast),col="yellow3",method="lm")
#MAYBE AN INTERACTION


### Interactions, sex as response ####
#dist*depth 2 levels
ggplot()+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=prop_F),col="red")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=prop_F))+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=prop_F),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=prop_F),col="black",method="lm")
#NO INTERACTION
#dist*depth 4 levels
ggplot()+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km< -20),mapping=aes(x=log(Depth_m),y=prop_F),col="red")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km< -20),mapping=aes(x=log(Depth_m),y=prop_F),col="red",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km<0 & Dist_baseline_km>-20),mapping=aes(x=log(Depth_m),y=prop_F),col="orange")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km<0 & Dist_baseline_km>-20),mapping=aes(x=log(Depth_m),y=prop_F),col="orange",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>20),mapping=aes(x=log(Depth_m),y=prop_F),col="black")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>20),mapping=aes(x=log(Depth_m),y=prop_F),col="black",method="lm")+
  geom_point(data=filter(station_meta_juv0,Dist_baseline_km>0 & Dist_baseline_km<20),mapping=aes(x=log(Depth_m),y=prop_F),col="blue")+
  geom_smooth(data=filter(station_meta_juv0,Dist_baseline_km>0 & Dist_baseline_km<20),mapping=aes(x=log(Depth_m),y=prop_F),col="blue",method="lm")+
  theme_classic()
#maybe something

#year*depth
ggplot()+
  geom_point(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=prop_F),col="red")+
  geom_point(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=prop_F))+
  geom_smooth(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=prop_F),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=prop_F),col="black",method="lm")
#NO INTERACTION  

#year*dist
ggplot()+
  geom_point(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="red")+
  geom_point(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=prop_F))+
  geom_smooth(data=filter(station_meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="black",method="lm")
#PROBABLY NO INTERACTION

#subdiv*depth
ggplot()+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=prop_F),col="blue")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=prop_F),col="red")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=prop_F),col="yellow3")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=prop_F),col="blue",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=prop_F),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=prop_F),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*dist
ggplot()+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="blue")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="red")+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="yellow3")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="blue",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="red",method="lm")+
  geom_smooth(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=prop_F),col="yellow3",method="lm")
#NO INTERACTION


## SUMMARY, PLANNED MODELS: ####
#variables: Year + Subdiv + Dist_baseline_km + log(Depth_m)
#interactions: Dist_baseline_km:log(Depth_m) + Subdiv:Dist_baseline_m + Subdiv:log(Depth_m)

## MODEL COMPARISON ####

#variables: Year + Subdiv + Dist_baseline_km + log(Depth_m)
#interactions: Subdiv:Dist_baseline_m + Subdiv:log(Depth_m) [+ Dist_baseline_km:log(Depth_m)]

#create function for model comparison
lm_comps <- function(data, explans, respon) {
  
  cof_out <- vector("list", length(explans))
  names(cof_out) <- seq_along(1:length(explans))
  
  for (i in seq_along(1:length(explans))) {
    lm_out <- lm(reformulate(explans[[i]], paste(respon)),
                 data = data)
    if(length(deparse(lm_out$terms[[3]]))==1){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),deparse(lm_out$terms[[3]]))}
    if(length(deparse(lm_out$terms[[3]]))==2){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),paste(deparse(lm_out$terms[[3]])[1],deparse(lm_out$terms[[3]])[2]))}
    if(length(deparse(lm_out$terms[[3]]))==3){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),paste(deparse(lm_out$terms[[3]])[1],deparse(lm_out$terms[[3]])[2],deparse(lm_out$terms[[3]])[3]))}
    model
    cof_out[[i]] <- coef(summary(lm_out)) %>% data.frame %>%
      mutate(Model = rep(model,nrow(tidy(lm_out))),
             Coef = rownames(coef(summary(lm_out))),
             R2 = glance(lm_out)$r.squared,
             df = glance(lm_out)$df,
             BIC = glance(lm_out)$BIC,
             AIC = glance(lm_out)$AIC,
             AICc = AICc(lm_out),
             LL = glance(lm_out)$logLik)
  }
  # tab <- bind_rows(cof_out)
  # tab <- tab %>% arrange(AICc)
  # tab$dAICc <- tab$AICc-tab$AICc[1]
  tab <- bind_rows(cof_out) %>% arrange(AICc) %>% mutate(dAICc = AICc-AICc[1])
  rownames(tab) <- c(1:nrow(tab))
  tab[,c(5,6,1:4,7:ncol(tab))]
}

### Set up the explanatory variables for the different models ####

# vectors with variable names
exp4 <- c("Year","Subdiv","Dist_baseline_km","log(Depth_m)")
exp6 <- c("Year","Subdiv","Dist_baseline_km","log(Depth_m)","Subdiv:Dist_baseline_km","Subdiv:log(Depth_m)")
exp7 <- c("Year","Subdiv","Dist_baseline_km","log(Depth_m)","Subdiv:Dist_baseline_km","Subdiv:log(Depth_m)","Dist_baseline_km:log(Depth_m)")

#create lists with all possible combinations of variables
exp_all_6vars <- list(
  #6 vars
  exp6,
  #5 vars
  exp6[-c(1)],exp6[-c(2)],exp6[-c(3)],exp6[-c(4)],exp6[-c(5)],exp6[-c(6)],
  #4 vars
  exp6[-c(1,2)],exp6[-c(1,3)],exp6[-c(1,4)],exp6[-c(1,5)],exp6[-c(1,6)],
  exp6[-c(2,3)],exp6[-c(2,4)],exp6[-c(2,5)],exp6[-c(2,6)],
  exp6[-c(3,4)],exp6[-c(3,5)],exp6[-c(3,6)],
  exp6[-c(4,5)],exp6[-c(4,6)],
  exp6[-c(5,6)],
  #3 vars
  exp6[c(1,2,3)],exp6[c(1,2,4)],exp6[c(1,2,5)],exp6[c(1,2,6)],
  exp6[c(1,3,4)],exp6[c(1,3,5)],exp6[c(1,3,6)],
  exp6[c(1,4,5)],exp6[c(1,4,6)],
  exp6[c(1,5,6)],
  exp6[c(2,3,4)],exp6[c(2,3,5)],exp6[c(2,3,6)],
  exp6[c(2,4,5)],exp6[c(2,4,6)],
  exp6[c(2,5,6)],
  exp6[c(3,4,5)],exp6[c(3,4,6)],
  exp6[c(3,5,6)],
  exp6[c(4,5,6)],
  #2 vars
  exp6[c(1,2)],exp6[c(1,3)],exp6[c(1,4)],exp6[c(1,5)],exp6[c(1,6)],
  exp6[c(2,3)],exp6[c(2,4)],exp6[c(2,5)],exp6[c(2,6)],
  exp6[c(3,4)],exp6[c(3,5)],exp6[c(3,6)],
  exp6[c(4,5)],exp6[c(4,6)],
  exp6[c(5,6)],
  #1 var
  exp6[c(1)],exp6[c(2)],exp6[c(3)],exp6[c(4)],exp6[c(5)],exp6[c(6)],
  c("1"))


exp_all_7vars <- list(
  #7 vars
  exp7,
  #6 vars
  exp7[-c(1)],exp7[-c(2)],exp7[-c(3)],exp7[-c(4)],exp7[-c(5)],exp7[-c(6)],exp7[-c(7)],
  #5 vars
  exp7[-c(1,2)],exp7[-c(1,3)],exp7[-c(1,4)],exp7[-c(1,5)],exp7[-c(1,6)],exp7[-c(1,7)],
  exp7[-c(2,3)],exp7[-c(2,4)],exp7[-c(2,5)],exp7[-c(2,6)],exp7[-c(2,7)],
  exp7[-c(3,4)],exp7[-c(3,5)],exp7[-c(3,6)],exp7[-c(3,7)],
  exp7[-c(4,5)],exp7[-c(4,6)],exp7[-c(4,7)],
  exp7[-c(5,6)],exp7[-c(5,7)],
  exp7[-c(6,7)],
  #4 vars
  exp7[-c(1,2,3)],exp7[-c(1,2,4)],exp7[-c(1,2,5)],exp7[-c(1,2,6)],exp7[-c(1,2,7)],
  exp7[-c(1,3,4)],exp7[-c(1,3,5)],exp7[-c(1,3,6)],exp7[-c(1,3,7)],
  exp7[-c(1,4,5)],exp7[-c(1,4,6)],exp7[-c(1,4,7)],
  exp7[-c(1,5,6)],exp7[-c(1,5,7)],
  exp7[-c(1,6,7)],
  exp7[-c(2,3,4)],exp7[-c(2,3,5)],exp7[-c(2,3,6)],exp7[-c(2,3,7)],
  exp7[-c(2,4,5)],exp7[-c(2,4,6)],exp7[-c(2,4,7)],
  exp7[-c(2,5,6)],exp7[-c(2,5,7)],
  exp7[-c(2,6,7)],
  exp7[-c(3,4,5)],exp7[-c(3,4,6)],exp7[-c(3,4,7)],
  exp7[-c(3,5,6)],exp7[-c(3,5,7)],
  exp7[-c(3,6,7)],
  exp7[-c(4,5,6)],exp7[-c(4,5,7)],
  exp7[-c(4,6,7)],
  exp7[-c(5,6,7)],
  #3 vars
  exp7[c(1,2,3)],exp7[c(1,2,4)],exp7[c(1,2,5)],exp7[c(1,2,6)],exp7[c(1,2,7)],
  exp7[c(1,3,4)],exp7[c(1,3,5)],exp7[c(1,3,6)],exp7[c(1,3,7)],
  exp7[c(1,4,5)],exp7[c(1,4,6)],exp7[c(1,4,7)],
  exp7[c(1,5,6)],exp7[c(1,5,7)],
  exp7[c(1,6,7)],
  exp7[c(2,3,4)],exp7[c(2,3,5)],exp7[c(2,3,6)],exp7[c(2,3,7)],
  exp7[c(2,4,5)],exp7[c(2,4,6)],exp7[c(2,4,7)],
  exp7[c(2,5,6)],exp7[c(2,5,7)],
  exp7[c(2,6,7)],
  exp7[c(3,4,5)],exp7[c(3,4,6)],exp7[c(3,4,7)],
  exp7[c(3,5,6)],exp7[c(3,5,7)],
  exp7[c(3,6,7)],
  exp7[c(4,5,6)],exp7[c(4,5,7)],
  exp7[c(4,6,7)],
  exp7[c(5,6,7)],
  #2 vars
  exp7[c(1,2)],exp7[c(1,3)],exp7[c(1,4)],exp7[c(1,5)],exp7[c(1,6)],exp7[c(1,7)],
  exp7[c(2,3)],exp7[c(2,4)],exp7[c(2,5)],exp7[c(2,6)],exp7[c(2,7)],
  exp7[c(3,4)],exp7[c(3,5)],exp7[c(3,6)],exp7[c(3,7)],
  exp7[c(4,5)],exp7[c(4,6)],exp7[c(4,7)],
  exp7[c(5,6)],exp7[c(5,7)],
  exp7[c(6,7)],
  #1 var
  exp7[1],exp7[2],exp7[3],exp7[4],exp7[5],exp7[6],exp7[7],
  #null
  c("1"))


exp_all_4vars <- list(
  #4 vars
  exp4,
  #3 vars
  exp4[-c(1)],exp4[-c(2)],exp4[-c(3)],exp4[-c(4)],
  #2 vars
  exp4[c(1,2)],exp4[c(1,3)],exp4[c(1,4)],
  exp4[c(2,3)],exp4[c(2,4)],
  exp4[c(3,4)],
  #1 var
  exp4[c(1)],exp4[c(2)],exp4[c(3)],exp4[c(4)],
  c("1"))

### Create and compare these sets of models ####
#### Ecotype proportions ####
# fit all the models
model_comp_eco <- lm_comps(data = station_meta_juv0, 
                           explans = exp_all_7vars,
                           respon = "prop_coast")
model_comp_eco %>% view

#create AIC table
AIC_table_eco <- model_comp_eco %>% group_by(Model,R2,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)

#### Sex ratio ####
#fit all the models
model_comp_sex <- lm_comps(data = station_meta_juv0, 
                           explans = exp_all_4vars,
                           respon = "prop_F")
model_comp_sex %>% view 

#create AIC table
AIC_table_sex <- model_comp_sex %>% group_by(Model,R2,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
  # top models include intercept-only model -> not interesting to look into

### check assumptions for output models: ####

# Multicollinearity:
# write function to calculate VIF for all variables in all models
vif_lm <- function(AIC_table,data){
  vif_out <- list()
  for(i in c(1:nrow(AIC_table))){
    x <- strsplit(AIC_table$Model[i]," ")[[1]]
    ifelse(length(x)==3,vif_out[[i]] <- NA, #NA if only one predictor in the model
           vif_out[[i]] <- vif(lm(paste(x[1],str_c(x[-1],collapse=" "),sep=""),
                                  data=data)) )     
  }
  vif_out
}
vif_eco <- vif_lm(AIC_table_eco,station_meta_juv0)
vif_sex <- vif_lm(AIC_table_sex,station_meta_juv0)

# write function to filter out models that include variables with VIF > 2
AIC_vif_lm_filt <- function(marker){ #"NO" if any predictor in the model has VIF>2
  dc <- character() # empty object where data class of objects will be added
  filter_vif <- character() # empty object where filtering values ("OK"/"NO") will be added
  for(i in 1:length(get(paste("vif_",marker,sep="")))){
    dc[i] <- data.class(get(paste("vif_",marker,sep=""))[[i]]) # gets the data.class of the vif_xxx object
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="logical"){filter_vif[i] <- "OK"} #shorthand for null values generated in vif_olm bc only one predictor in model
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="numeric"){ifelse(TRUE %in% c(get(paste("vif_",marker,sep=""))[[i]]>2),filter_vif[i] <- "NO",filter_vif[i] <- "OK")} # if data class = character; returns value "NO" if VIF>2, otherwise "OK"
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="matrix"){ifelse(TRUE %in% c(get(paste("vif_",marker,sep=""))[[i]][,"GVIF"] %>% as.numeric >2),filter_vif[i] <- "NO",filter_vif[i] <- "OK")} # if data class = matrix; returns value "NO" if VIF>2, otherwise "OK"
  }

  # filter out models that include variables with VIF>2
  AIC_table <- get(paste("AIC_table_",marker,sep=""))[filter_vif=="OK",] %>% arrange(AICc)
  AIC_table$dAICc <- AIC_table$AICc-AIC_table$AICc[1] # calculate dAICc
  AIC_table
}

# filter linear models (ecotype, sex) 
AIC_table_eco_vif <- AIC_vif_lm_filt("eco")
AIC_table_sex_vif <- AIC_vif_lm_filt("sex")

# Assumption 1: The linear predictor (explanatory variables) is a set of linear variables i.e. parameters are not exponents.
# We check this by plotting the fitted values vs. residuals and checking for curvature
plot(lm(AIC_table_eco_vif$Model[1],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[2],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[3],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[4],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[5],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[6],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[7],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[8],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[9],data=station_meta_juv0,weights=n),1)
plot(lm(AIC_table_eco_vif$Model[10],data=station_meta_juv0,weights=n),1)

# Assumption 2: The residuals are normally distributed
# Check this by plotting a histogram of the residuals
hist(residuals(lm(AIC_table_eco_vif$Model[1],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[2],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[3],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[4],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[5],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[6],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[7],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[8],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[9],data=station_meta_juv0,weights=n)))
hist(residuals(lm(AIC_table_eco_vif$Model[10],data=station_meta_juv0,weights=n)))

# Also check this by plotting a qqplot
plot(lm(AIC_table_eco_vif$Model[1],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[2],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[3],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[4],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[5],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[6],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[7],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[8],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[9],data=station_meta_juv0,weights=n),2)
plot(lm(AIC_table_eco_vif$Model[10],data=station_meta_juv0,weights=n),2)

# Assumption 3: There is homogeneity of variance: homoscedasticity (opposite is heteroscedasticity)
# Check this by plotting fitted values vs. residuals and seeing if there is a trend (scale-location plot)
plot(lm(AIC_table_eco_vif$Model[1],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[2],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[3],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[4],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[5],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[6],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[7],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[8],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[9],data=station_meta_juv0,weights=n),3)
plot(lm(AIC_table_eco_vif$Model[10],data=station_meta_juv0,weights=n),3)

# Breusch-Pagan Test for homoscedasticity 
p.bp.test <- numeric()
for(i in 1:nrow(AIC_table_eco_vif[-c(42),])){ #remove intercept manually
  p.bp.test[i] <- bptest(lm(AIC_table_eco_vif[-c(42),]$Model[i],data=station_meta_juv0,weights=n))[4]$p.value %>% as.vector
}
p.bp.fdr <- p.adjust(p.bp.test,method="fdr") # no significantly deviating models
p.bp.fdr_ed <- c(p.bp.fdr[1:41],1,p.bp.fdr[42]) #add intercept manually for filtering purposes
AIC_table_eco_vif_bp <- AIC_table_eco_vif[p.bp.fdr_ed>0.05,] 

p.bp.test <- numeric()
for(i in 1:nrow(AIC_table_sex_vif[-c(4),])){ #remove intercept manually
  p.bp.test[i] <- bptest(lm(AIC_table_sex_vif[-c(4),]$Model[i],data=station_meta_juv0,weights=n))[4]$p.value %>% as.vector
}
p.bp.fdr <- p.adjust(p.bp.test,method="fdr") # no significantly deviating models
p.bp.fdr_ed <- c(p.bp.fdr[1:3],1,p.bp.fdr[4:15]) #add intercept manually for filtering purposes
AIC_table_sex_final <- AIC_table_sex_vif[p.bp.fdr_ed>0.05,] 

# Assumption 4: Independence of the error term
# This cannot be tested statistically (except in certain cases) but is about the data collection or experimental design

# Assumption 5: There is no collinearity among explanatory variables
#checked this above, using VIF!

# Check for influential data points
# Calculate the min and max dfbeta values for each coefficient in the model
dfbeta(lm(AIC_table_eco_vif_bp$Model[1],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[1],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[2],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[2],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[3],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[3],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[4],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[4],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[5],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[5],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[6],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[6],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[7],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[7],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[8],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[8],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[9],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[9],data=station_meta_juv0,weights=n)$coefficients

dfbeta(lm(AIC_table_eco_vif_bp$Model[10],data=station_meta_juv0,weights=n)) %>% as_tibble() %>% gather(key = "coefficient", value = "dfbeta") %>% group_by(coefficient) %>% summarise(min = min(dfbeta),max = max(dfbeta))
lm(AIC_table_eco_vif_bp$Model[10],data=station_meta_juv0,weights=n)$coefficients

# remove redundant models
AIC_table_eco_final <- AIC_table_eco_vif_bp[-c(6,16,18),]

## SUMMARY, RESULTS ####

### Table 1A, S7: Ecotype proportions ####
AIC_table_eco_final %>% view 
# simplest top model (STM): subdiv + log(depth) 
# 3 top models (dAICc < 2) with similar R2 (~0.59)
# all 3 contain Subdiv + Depth, model 2 and 3 also contains dist
# all top 6 models include both Subdiv and depth in some combination
# all top 12 models include depth
model_comp_eco_final <- filter(model_comp_eco,Model %in% AIC_table_eco_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_eco_final[,c(1:3,6,7,13)] %>% view 
# in all top models, there is no sign diff btw subdiv 20 and 21,
# but sign. increase between 20 and 23
# in model 2 and 3, dist and dist:depth has a small and N.S. effect
# depth is sign in all models where it is included as a non-interaction
# Subdiv23 is sign in all models where it is included

#### plot predictions ####
AIC_table_eco_final$Model[1] #Subdiv + log(Depth_m)
model_comp_eco_final %>% head(4)

#df with c(predicted props, station metadata)
x <- data.frame(pred_prop_coast=predict(lm(AIC_table_eco_final$Model[1],data=station_meta_juv0,weights=n),type="response"),station_meta_juv0)

#plot
ggplot()+
  geom_point(data=x,mapping=aes(x=Depth_m,y=prop_coast,col=Subdiv,size=n),alpha=0.5)+
  scale_size(range=c(0.5,5),breaks=c(1,3,5,10),name="No. individuals")+
  geom_line(data=x,mapping=aes(x=Depth_m,y=pred_prop_coast,col=Subdiv),size=1)+
  ylim(c(0,1))+theme_classic()+ylab("Coastal ecotype proportion")+ggtitle("Model #1: prop_coast ~ Subdiv + log(Depth_m)")

ggplot()+
  geom_line(data=x,mapping=aes(x=Depth_m,y=pred_prop_coast,col=Subdiv),size=1)+
  geom_point(data=y,mapping=aes(x=Depth_10m,y=mean_prop_coast,col=Subdiv,size=n_stations),shape=15)+
  scale_size(range=c(0.5,5),breaks=c(1,5,10,20,30),name="No. stations")+
  geom_errorbar(data=y,mapping=aes(x=Depth_10m,ymin=ifelse(mean_prop_coast-se<0,0,mean_prop_coast-se),
                                   ymax=ifelse(mean_prop_coast+se>1,1,mean_prop_coast+se),col=Subdiv))+
  ylim(c(0,1))+theme_classic()+ylab("Coastal ecotype proportion")+ggtitle("Model #1: prop_coast ~ Subdiv + log(Depth_m)")mp_eco_a <- 
  
  #weaker trend in subdiv 23, similar trend for subdiv 20 and 21
  
  
  #CONCLUSION: depth and subdiv appear to be the most important predictors of prop_coast
  
  #plot top 3 models:
  # MODEL1  
  ggplot()+
  geom_point(mapping=aes(x=station_meta_juv0$Depth_m %>% log(),y=predict(lm(AIC_table_eco_final$Model[1],data=station_meta_juv0,weights=n)),col=station_meta_juv0$Subdiv),size=3,alpha=0.5,shape=18)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="red",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="green",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="blue",size=2,alpha=0.7)+
  xlab("log(Depth_m)")+ylab("prop_coast")

# MODEL2  
ggplot()+
  geom_point(mapping=aes(x=station_meta_juv0$Depth_m %>% log(),y=predict(lm(AIC_table_eco_final$Model[2],data=station_meta_juv0,weights=n)),col=station_meta_juv0$Subdiv),size=3,alpha=0.5,shape=18)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="red",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="green",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="blue",size=2,alpha=0.7)+
  xlab("log(Depth_m)")+ylab("prop_coast")


# MODEL3  
ggplot()+
  geom_point(mapping=aes(x=station_meta_juv0$Depth_m %>% log(),y=predict(lm(AIC_table_eco_final$Model[3],data=station_meta_juv0,weights=n)),col=station_meta_juv0$Subdiv),size=3,alpha=0.5,shape=18)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="20"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="red",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="21"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="green",size=2,alpha=0.7)+
  geom_point(data=filter(station_meta_juv0,Subdiv=="23"),mapping=aes(x=Depth_m %>% log(),y=prop_coast),col="blue",size=2,alpha=0.7)+
  xlab("log(Depth_m)")+ylab("prop_coast")

### Table S8: Sex: ####
AIC_table_sex_final
#intercept-only model among top models (dAICc < 2)
model_comp_sex_final <- filter(model_comp_sex,Model %in% AIC_table_sex_final$Model) %>% mutate(dAICc=dAICc-dAICc[1])
model_comp_sex_final[,c(1:3,6,7,13)] %>% view 

#CONCLUSION: we see no signs of a geographical pattern in sex ratio

# INV, Hb (ordinal logistic regression) ####

## Prepare the data ####

#filter out inds with "mixed" and "NA" genotypes
#inv02
data_INV02 <- filter(meta_juv0,INV02 %in% c(1,3,5))
data_INV02$INV02 <- replace(data_INV02$INV02 %>% as.numeric,data_INV02$INV02==3,2)
data_INV02$INV02 <- replace(data_INV02$INV02,data_INV02$INV02==5,3) %>% as.factor

#inv12
data_INV12 <- filter(meta_juv0,INV12 %in% c(1,3,5))
data_INV12$INV12 <- replace(data_INV12$INV12 %>% as.numeric,data_INV12$INV12==3,2)
data_INV12$INV12 <- replace(data_INV12$INV12,data_INV12$INV12==5,3) %>% as.factor

#Hb
data_Hba4 <- filter(meta_juv0,Hba4 %in% c(1,2,3))
data_Hbb1 <- filter(meta_juv0,Hbb1 %in% c(1,2,3))
data_Hbb5 <- filter(meta_juv0,Hbb5 %in% c(1,2,3))

## Check assumptions: ####
# 1. The dependent variable are ordered. - Yes
# 2. One or more of the independent variables are either continuous, categorical or ordinal - Yes
# 3. No multi-collinearity 
data_INV12 %>% names
x <- data.frame(Year=data_INV12$Year %>% as.numeric,
                Subdiv=data_INV12$Subdiv %>% as.numeric,
                dist=data_INV12$Dist_baseline_km %>% as.numeric,
                log.depth=data_INV12$Depth_m %>% as.numeric %>% log(),
                Eco=data_INV12$Eco %>% as.numeric,
                sex=data_INV12$Sex %>% as.numeric,
                INV12=data_INV12$INV12 %>% as.numeric)
cor(x) #dist and depth, depth and Eco slightly collinear (0.6), but will be fitted
pairs(x)

# 4. Proportional odds - this will be checked after fitting models

## Explore interactions: ####
### interactions, inv02 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV02)))+
  geom_smooth(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV02)),col="black",method="lm")
#NO

#year*dist
ggplot()+
  geom_point(data=filter(data_INV02,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)))+
  geom_smooth(data=filter(data_INV02,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="black",method="lm")
#NO

#year*depth
ggplot()+
  geom_point(data=filter(data_INV02,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)))+
  geom_smooth(data=filter(data_INV02,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="black",method="lm")
#NO INTERACTION  

#year*Eco
ggplot()+
  geom_point(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)))+
  geom_smooth(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)))+
  geom_smooth(data=filter(data_INV02,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="blue")+
  geom_point(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="yellow3")+
  geom_smooth(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*dist
ggplot()+
  geom_point(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="blue")+
  geom_point(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="yellow3")+
  geom_smooth(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*Eco
ggplot()+
  geom_point(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="blue")+
  geom_point(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="yellow3")+
  geom_smooth(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV02)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*sex
ggplot()+
  geom_point(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="blue")+
  geom_point(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red")+
  geom_point(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="yellow3")+
  geom_smooth(data=filter(data_INV02,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV02,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="yellow3",method="lm")
#NO INTERACTION

#dist*depth
ggplot()+
  geom_point(data=filter(data_INV02,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red",method="lm")
#NO

#dist*Eco
ggplot()+
  geom_point(data=filter(data_INV02,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red",method="lm")
#NO, bco collinearity risks
#dist*sex
ggplot()+
  geom_point(data=filter(data_INV02,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV02)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(data_INV02,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red",method="lm")
#NO
#depth*sex
ggplot()+
  geom_point(data=filter(data_INV02,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV02)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(data_INV02,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)))+
  geom_point(data=filter(data_INV02,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red")+
  geom_smooth(data=filter(data_INV02,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV02,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV02)),col="red",method="lm")
#NO


### interactions, inv07 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV07)))+
  geom_smooth(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV07)),col="black",method="lm")
#HMM, NO bco broad CI

#year*dist
ggplot()+
  geom_point(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)))+
  geom_smooth(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="black",method="lm")
#HMM, NO

#year*depth
ggplot()+
  geom_point(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)))+
  geom_smooth(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="black",method="lm")
#HMM, NO

#year*Eco
ggplot()+
  geom_point(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)))+
  geom_smooth(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)))+
  geom_smooth(data=filter(meta_juv0,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="blue")+
  geom_point(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="yellow3")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="blue",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="yellow3",method="lm")
#HMM, YES (collinearity w Eco?)

#subdiv*dist
ggplot()+
  geom_point(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="blue")+
  geom_point(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="yellow3")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="blue",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="yellow3",method="lm")
#HMM, YES (collinearity w Eco?)

#subdiv*Eco
ggplot()+
  geom_point(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="blue")+
  geom_point(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="yellow3")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="blue",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV07)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*sex
ggplot()+
  geom_point(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="blue")+
  geom_point(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red")+
  geom_point(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="yellow3")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="blue",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red",method="lm")+
  geom_smooth(data=filter(meta_juv0,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="yellow3",method="lm")
#NO INTERACTION

#dist*depth
ggplot()+
  geom_point(data=filter(data_INV07,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)))+
  geom_point(data=filter(data_INV07,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(data_INV07,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV07,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red",method="lm")
#NO
#dist*Eco
ggplot()+
  geom_point(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)))+
  geom_point(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red",method="lm")
#HMM, YES

#dist*sex
ggplot()+
  geom_point(data=filter(meta_juv0,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)))+
  geom_point(data=filter(meta_juv0,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(meta_juv0,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(meta_juv0,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV07)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)))+
  geom_point(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red",method="lm")
#HMMM, NO bco collinearity risks

#depth*sex
ggplot()+
  geom_point(data=filter(meta_juv0,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)))+
  geom_point(data=filter(meta_juv0,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(meta_juv0,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(meta_juv0,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV07)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)))+
  geom_point(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red")+
  geom_smooth(data=filter(meta_juv0,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="black",method="lm")+
  geom_smooth(data=filter(meta_juv0,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV07)),col="red",method="lm")
#NO

### interactions, inv12 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV12)))+
  geom_smooth(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(INV12)),col="black",method="lm")
#NO

#year*dist
ggplot()+
  geom_point(data=filter(data_INV12,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)))+
  geom_smooth(data=filter(data_INV12,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="black",method="lm")
#NO

#year*depth
ggplot()+
  geom_point(data=filter(data_INV12,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)))+
  geom_smooth(data=filter(data_INV12,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="black",method="lm")
#NO INTERACTION  

#year*Eco
ggplot()+
  geom_point(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)))+
  geom_smooth(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)))+
  geom_smooth(data=filter(data_INV12,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="blue")+
  geom_point(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="yellow3")+
  geom_smooth(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="yellow3",method="lm")
#HMM, NO bco large CI

#subdiv*dist
ggplot()+
  geom_point(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="blue")+
  geom_point(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="yellow3")+
  geom_smooth(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*Eco
ggplot()+
  geom_point(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="blue")+
  geom_point(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="yellow3")+
  geom_smooth(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(INV12)),col="yellow3",method="lm")
#HMM, YES

#subdiv*sex
ggplot()+
  geom_point(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="blue")+
  geom_point(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red")+
  geom_point(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="yellow3")+
  geom_smooth(data=filter(data_INV12,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="blue",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red",method="lm")+
  geom_smooth(data=filter(data_INV12,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="yellow3",method="lm")
#NO INTERACTION
#dist*depth
ggplot()+
  geom_point(data=filter(data_INV12,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red",method="lm")
#HMM, YES

#dist*Eco
ggplot()+
  geom_point(data=filter(data_INV12,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red",method="lm")
#HMM, Yes

#dist*sex
ggplot()+
  geom_point(data=filter(data_INV12,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(INV12)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(data_INV12,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red",method="lm")
#HMM,yes

#depth*sex
ggplot()+
  geom_point(data=filter(data_INV12,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(INV12)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(data_INV12,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)))+
  geom_point(data=filter(data_INV12,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red")+
  geom_smooth(data=filter(data_INV12,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="black",method="lm")+
  geom_smooth(data=filter(data_INV12,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(INV12)),col="red",method="lm")
#NO

### interactions, Hba4 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hba4)))+
  geom_smooth(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hba4)),col="black",method="lm")
#NO

#year*dist
ggplot()+
  geom_point(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)))+
  geom_smooth(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="black",method="lm")
#NO

#year*depth
ggplot()+
  geom_point(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)))+
  geom_smooth(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="black",method="lm")
#NO INTERACTION  

#year*Eco
ggplot()+
  geom_point(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)))+
  geom_smooth(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)))+
  geom_smooth(data=filter(data_Hba4,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="blue")+
  geom_point(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="yellow3")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*dist
ggplot()+
  geom_point(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="blue")+
  geom_point(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="yellow3")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*Eco
ggplot()+
  geom_point(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="blue")+
  geom_point(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="yellow3")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hba4)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*sex
ggplot()+
  geom_point(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="blue")+
  geom_point(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red")+
  geom_point(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="yellow3")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hba4,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="yellow3",method="lm")
#NO INTERACTION

ggplot()+
  geom_point(data=filter(data_Hba4,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red",method="lm")
#NO

#dist*Eco
ggplot()+
  geom_point(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red",method="lm")
#NO

#dist*sex
ggplot()+
  geom_point(data=filter(data_Hba4,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hba4)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red",method="lm")
#NO
#depth*sex
ggplot()+
  geom_point(data=filter(data_Hba4,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hba4)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)))+
  geom_point(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red")+
  geom_smooth(data=filter(data_Hba4,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hba4,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hba4)),col="red",method="lm")
#NO

### interactions, Hbb1 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb1)))+
  geom_smooth(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb1)),col="black",method="lm")
#HMM, YES

#year*dist
ggplot()+
  geom_point(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)))+
  geom_smooth(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="black",method="lm")
#NO

#year*depth
ggplot()+
  geom_point(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)))+
  geom_smooth(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="black",method="lm")
#NO INTERACTION  

#year*Eco
ggplot()+
  geom_point(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)))+
  geom_smooth(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)))+
  geom_smooth(data=filter(data_Hbb1,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="blue")+
  geom_point(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*dist
ggplot()+
  geom_point(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="blue")+
  geom_point(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*Eco
ggplot()+
  geom_point(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="blue")+
  geom_point(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb1)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*sex
ggplot()+
  geom_point(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="blue")+
  geom_point(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red")+
  geom_point(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="yellow3",method="lm")
#NO INTERACTION

#dist*depth
ggplot()+
  geom_point(data=filter(data_Hbb1,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red",method="lm")
#NO

#dist*Eco
ggplot()+
  geom_point(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red",method="lm")
#NO, bco collinearity risks
#dist*sex
ggplot()+
  geom_point(data=filter(data_Hbb1,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb1)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red",method="lm")
#NO
#depth*sex
ggplot()+
  geom_point(data=filter(data_Hbb1,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb1)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)))+
  geom_point(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red")+
  geom_smooth(data=filter(data_Hbb1,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb1,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb1)),col="red",method="lm")
#NO

### interactions, Hbb5 as response ####
#variables of interest: Year, subdiv, dist, depth, Ecotype, sex

#year*subdiv
ggplot()+
  geom_point(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb5)))+
  geom_smooth(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Subdiv),y=as.numeric(Hbb5)),col="black",method="lm")
#NO

#year*dist
ggplot()+
  geom_point(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)))+
  geom_smooth(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="black",method="lm")
#NO

#year*depth
ggplot()+
  geom_point(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)))+
  geom_smooth(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="black",method="lm")
#NO INTERACTION  

#year*Eco
ggplot()+
  geom_point(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)))+
  geom_smooth(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="black",method="lm")
#NO INTERACTION 

#year*sex
ggplot()+
  geom_point(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)))+
  geom_smooth(data=filter(data_Hbb5,Year=="2019"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Year=="2020"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="black",method="lm")
#NO INTERACTION 

#subdiv*depth
ggplot()+
  geom_point(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="blue")+
  geom_point(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="yellow3",method="lm")
#HMM, NO bco large CI

#subdiv*dist
ggplot()+
  geom_point(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="blue")+
  geom_point(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="yellow3",method="lm")
#HMM, NO bco LARGE CI

#subdiv*Eco
ggplot()+
  geom_point(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="blue")+
  geom_point(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=as.numeric(Eco),y=as.numeric(Hbb5)),col="yellow3",method="lm")
#NO INTERACTION

#subdiv*sex
ggplot()+
  geom_point(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="blue")+
  geom_point(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red")+
  geom_point(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="yellow3")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="20"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="blue",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="21"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Subdiv=="23"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="yellow3",method="lm")
#NO INTERACTION

#dist*depth
ggplot()+
  geom_point(data=filter(data_Hbb5,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Dist_baseline_km<0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Dist_baseline_km>0),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red",method="lm")
#HMM, Yes

#dist*Eco
ggplot()+
  geom_point(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red",method="lm")
#NO

#dist*sex
ggplot()+
  geom_point(data=filter(data_Hbb5,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Sex=="1"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Sex=="2"),mapping=aes(x=Dist_baseline_km,y=as.numeric(Hbb5)),col="red",method="lm")
#NO
#depth*Eco
ggplot()+
  geom_point(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red",method="lm")
#HMM, Yes

#depth*sex
ggplot()+
  geom_point(data=filter(data_Hbb5,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Sex=="1"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Sex=="2"),mapping=aes(x=log(Depth_m),y=as.numeric(Hbb5)),col="red",method="lm")
#NO
#Eco*sex
ggplot()+
  geom_point(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)))+
  geom_point(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red")+
  geom_smooth(data=filter(data_Hbb5,Eco=="1"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="black",method="lm")+
  geom_smooth(data=filter(data_Hbb5,Eco=="2"),mapping=aes(x=as.numeric(Sex),y=as.numeric(Hbb5)),col="red",method="lm")
#NO

## SUMMARY, PLANNED MODELS: ####
#variables: Year + Subdiv + Dist_baseline_km + log(Depth_m) + Eco + Sex
#interactions: 
#INV02 no int #6
#inv07 subdiv*depth subdiv*dist dist*Eco? depth*Eco? #10
#inv12 subdiv*Eco dist*depth dist*Eco? depth*Eco? #10
#Hba4 no int #6
#Hbb1 year*subdiv #7
#Hbb5 dist*depth depth*Eco #8

#NOTE: there may be downstream problems with collinearity (subdiv, Eco-dist/depth, dist-depth)

## Ordinal regression ####

#write function for ordinal logistic model comparison:
olm_comps <- function(data, explans, respon) {
  
  cof_out <- vector("list", length(explans))
  names(cof_out) <- seq_along(1:length(explans))
  
  for (i in seq_along(1:length(explans))) {
    lm_out <- polr(reformulate(explans[[i]], paste(respon)),
                   data = data,Hess=T)
    if(length(deparse(lm_out$terms[[3]]))==1){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),deparse(lm_out$terms[[3]]))}
    if(length(deparse(lm_out$terms[[3]]))==2){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),paste(deparse(lm_out$terms[[3]])[1],deparse(lm_out$terms[[3]])[2]))}
    if(length(deparse(lm_out$terms[[3]]))==3){model <-  paste(deparse(lm_out$terms[[2]]),deparse(lm_out$terms[[1]]),paste(deparse(lm_out$terms[[3]])[1],deparse(lm_out$terms[[3]])[2],deparse(lm_out$terms[[3]])[3]))}
    
    cof_out[[i]] <- coef(summary(lm_out)) %>% data.frame %>%
      mutate(Model = rep(model,nrow(tidy(lm_out))),
             Coef = rownames(coef(summary(lm_out))),
             edf = glance(lm_out)$edf,
             BIC = glance(lm_out)$BIC,
             AIC = glance(lm_out)$AIC,
             AICc = AICc(lm_out),
             LL = glance(lm_out)$logLik,
             p.value = data.frame(pnorm(abs(coef(summary(lm_out)))[,"t value"],lower.tail = F)*2)$pnorm.abs.coef.summary.lm_out.......t.value....lower.tail...F....,
             Accuracy = nrow(data[predict(lm_out)==data[,respon],])/nrow(data))
  }
  tab <- bind_rows(cof_out) %>% arrange(AICc) %>% mutate(dAICc = AICc-AICc[1])
  rownames(tab) <- c(1:nrow(tab))
  tab[,c(4,5,1:3,6,12,10,11,7:9,13)]
}

### Set up the explanatory variables for the different models ####

#inv07 subdiv*depth subdiv*dist dist*Eco? depth*Eco? #10
#inv12 subdiv*Eco dist*depth dist*Eco? depth*Eco? #10
#Hbb1 year*subdiv #7
#Hbb5 dist*depth depth*Eco #8

#INV02,Hba4 (no interactions)
exp_noint <- c("Year","Subdiv","Dist_baseline_km","log.Depth_m",
               "Eco","Sex")
#others
exp_INV07 <- c("Year","Subdiv","Dist_baseline_km","log.Depth_m",
               "Eco","Sex","Subdiv:Dist_baseline_km",
               "Subdiv:log.Depth_m","Dist_baseline_km:Eco", 
               "log.Depth_m:Eco")
exp_INV12 <- c("Year","Subdiv","Dist_baseline_km","log.Depth_m",
               "Eco","Sex","Subdiv:Eco",
               "Dist_baseline_km:log.Depth_m","Dist_baseline_km:Eco", 
               "log.Depth_m:Eco")
exp_Hbb1 <- c("Year","Subdiv","Dist_baseline_km","log.Depth_m",
              "Eco","Sex","Year:Subdiv")

exp_Hbb5 <- c("Year","Subdiv","Dist_baseline_km","log.Depth_m",
              "Eco","Sex","Dist_baseline_km:log.Depth_m",
              "log.Depth_m:Eco")

#### no int - INV02, Hba4 (6) ####
exp_noint_all_vars <- list(
  #6
  exp_noint,
  #5
  exp_noint[-c(1)],exp_noint[-c(2)],exp_noint[-c(3)],exp_noint[-c(4)],exp_noint[-c(5)],exp_noint[-c(6)],
  #4
  exp_noint[-c(1,2)],exp_noint[-c(1,3)],exp_noint[-c(1,4)],exp_noint[-c(1,5)],exp_noint[-c(1,6)],
  exp_noint[-c(2,3)],exp_noint[-c(2,4)],exp_noint[-c(2,5)],exp_noint[-c(2,6)],
  exp_noint[-c(3,4)],exp_noint[-c(3,5)],exp_noint[-c(3,6)],
  exp_noint[-c(4,5)],exp_noint[-c(4,6)],
  exp_noint[-c(5,6)],
  #3
  exp_noint[c(1,2,3)],exp_noint[c(1,2,4)],exp_noint[c(1,2,5)],exp_noint[c(1,2,6)],
  exp_noint[c(1,3,4)],exp_noint[c(1,3,5)],exp_noint[c(1,3,6)],
  exp_noint[c(1,4,5)],exp_noint[c(1,4,6)],
  exp_noint[c(1,5,6)],
  exp_noint[c(2,3,4)],exp_noint[c(2,3,5)],exp_noint[c(2,3,6)],
  exp_noint[c(2,4,5)],exp_noint[c(2,4,6)],
  exp_noint[c(2,5,6)],
  exp_noint[c(3,4,5)],exp_noint[c(3,4,6)],
  exp_noint[c(3,5,6)],
  exp_noint[c(4,5,6)],
  #2
  exp_noint[c(1,2)],exp_noint[c(1,3)],exp_noint[c(1,4)],exp_noint[c(1,5)],exp_noint[c(1,6)],
  exp_noint[c(2,3)],exp_noint[c(2,4)],exp_noint[c(2,5)],exp_noint[c(2,6)],
  exp_noint[c(3,4)],exp_noint[c(3,5)],exp_noint[c(3,6)],
  exp_noint[c(4,5)],exp_noint[c(4,6)],
  exp_noint[c(5,6)],
  #1
  exp_noint[c(1)],exp_noint[c(2)],exp_noint[c(3)],exp_noint[c(4)],exp_noint[c(5)],exp_noint[c(6)],
  c("1"))

#### INV07 (10) ####

exp_all_INV07vars <- list(
  #10 vars
  exp_INV07,
  #9 vars
  exp_INV07[-c(1)],exp_INV07[-c(2)],exp_INV07[-c(3)],exp_INV07[-c(4)],exp_INV07[-c(5)],exp_INV07[-c(6)],exp_INV07[-c(7)],exp_INV07[-c(8)],exp_INV07[-c(9)],exp_INV07[-c(10)],
  #8 vars
  exp_INV07[-c(1,2)],exp_INV07[-c(1,3)],exp_INV07[-c(1,4)],exp_INV07[-c(1,5)],exp_INV07[-c(1,6)],exp_INV07[-c(1,7)],exp_INV07[-c(1,8)],exp_INV07[-c(1,9)],exp_INV07[-c(1,10)],
  exp_INV07[-c(2,3)],exp_INV07[-c(2,4)],exp_INV07[-c(2,5)],exp_INV07[-c(2,6)],exp_INV07[-c(2,7)],exp_INV07[-c(2,8)],exp_INV07[-c(2,9)],exp_INV07[-c(2,10)],
  exp_INV07[-c(3,4)],exp_INV07[-c(3,5)],exp_INV07[-c(3,6)],exp_INV07[-c(3,7)],exp_INV07[-c(3,8)],exp_INV07[-c(3,9)],exp_INV07[-c(3,10)],
  exp_INV07[-c(4,5)],exp_INV07[-c(4,6)],exp_INV07[-c(4,7)],exp_INV07[-c(4,8)],exp_INV07[-c(4,9)],exp_INV07[-c(4,10)],
  exp_INV07[-c(5,6)],exp_INV07[-c(5,7)],exp_INV07[-c(5,8)],exp_INV07[-c(5,9)],exp_INV07[-c(5,10)],
  exp_INV07[-c(6,7)],exp_INV07[-c(6,8)],exp_INV07[-c(6,9)],exp_INV07[-c(6,10)],
  exp_INV07[-c(7,8)],exp_INV07[-c(7,9)],exp_INV07[-c(7,10)],
  exp_INV07[-c(8,9)],exp_INV07[-c(8,10)],
  exp_INV07[-c(9,10)],
  #7 vars
  exp_INV07[-c(1,2,3)],exp_INV07[-c(1,2,4)],exp_INV07[-c(1,2,5)],exp_INV07[-c(1,2,6)],exp_INV07[-c(1,2,7)],exp_INV07[-c(1,2,8)],exp_INV07[-c(1,2,9)],exp_INV07[-c(1,2,10)],
  exp_INV07[-c(1,3,4)],exp_INV07[-c(1,3,5)],exp_INV07[-c(1,3,6)],exp_INV07[-c(1,3,7)],exp_INV07[-c(1,3,8)],exp_INV07[-c(1,3,9)],exp_INV07[-c(1,3,10)],
  exp_INV07[-c(1,4,5)],exp_INV07[-c(1,4,6)],exp_INV07[-c(1,4,7)],exp_INV07[-c(1,4,8)],exp_INV07[-c(1,4,9)],exp_INV07[-c(1,4,10)],
  exp_INV07[-c(1,5,6)],exp_INV07[-c(1,5,7)],exp_INV07[-c(1,5,8)],exp_INV07[-c(1,5,9)],exp_INV07[-c(1,5,10)],
  exp_INV07[-c(1,6,7)],exp_INV07[-c(1,6,8)],exp_INV07[-c(1,6,9)],exp_INV07[-c(1,6,10)],
  exp_INV07[-c(1,7,8)],exp_INV07[-c(1,7,9)],exp_INV07[-c(1,7,10)],
  exp_INV07[-c(1,8,9)],exp_INV07[-c(1,8,10)],
  exp_INV07[-c(1,9,10)],
  exp_INV07[-c(2,3,4)],exp_INV07[-c(2,3,5)],exp_INV07[-c(2,3,6)],exp_INV07[-c(2,3,7)],exp_INV07[-c(2,3,8)],exp_INV07[-c(2,3,9)],exp_INV07[-c(2,3,10)],
  exp_INV07[-c(2,4,5)],exp_INV07[-c(2,4,6)],exp_INV07[-c(2,4,7)],exp_INV07[-c(2,4,8)],exp_INV07[-c(2,4,9)],exp_INV07[-c(2,4,10)],
  exp_INV07[-c(2,5,6)],exp_INV07[-c(2,5,7)],exp_INV07[-c(2,5,8)],exp_INV07[-c(2,5,9)],exp_INV07[-c(2,5,10)],
  exp_INV07[-c(2,6,7)],exp_INV07[-c(2,6,8)],exp_INV07[-c(2,6,9)],exp_INV07[-c(2,6,10)],
  exp_INV07[-c(2,7,8)],exp_INV07[-c(2,7,9)],exp_INV07[-c(2,7,10)],
  exp_INV07[-c(2,8,9)],exp_INV07[-c(2,8,10)],
  exp_INV07[-c(2,9,10)],
  exp_INV07[-c(3,4,5)],exp_INV07[-c(3,4,6)],exp_INV07[-c(3,4,7)],exp_INV07[-c(3,4,8)],exp_INV07[-c(3,4,9)],exp_INV07[-c(3,4,10)],
  exp_INV07[-c(3,5,6)],exp_INV07[-c(3,5,7)],exp_INV07[-c(3,5,8)],exp_INV07[-c(3,5,9)],exp_INV07[-c(3,5,10)],
  exp_INV07[-c(3,6,7)],exp_INV07[-c(3,6,8)],exp_INV07[-c(3,6,9)],exp_INV07[-c(3,6,10)],
  exp_INV07[-c(3,7,8)],exp_INV07[-c(3,7,9)],exp_INV07[-c(3,7,10)],
  exp_INV07[-c(3,8,9)],exp_INV07[-c(3,8,10)],
  exp_INV07[-c(3,9,10)],
  exp_INV07[-c(4,5,6)],exp_INV07[-c(4,5,7)],exp_INV07[-c(4,5,8)],exp_INV07[-c(4,5,9)],exp_INV07[-c(4,5,10)],
  exp_INV07[-c(4,6,7)],exp_INV07[-c(4,6,8)],exp_INV07[-c(4,6,9)],exp_INV07[-c(4,6,10)],
  exp_INV07[-c(4,7,8)],exp_INV07[-c(4,7,9)],exp_INV07[-c(4,7,10)],
  exp_INV07[-c(4,8,9)],exp_INV07[-c(4,8,10)],
  exp_INV07[-c(4,9,10)],
  exp_INV07[-c(5,6,7)],exp_INV07[-c(5,6,8)],exp_INV07[-c(5,6,9)],exp_INV07[-c(5,6,10)],
  exp_INV07[-c(5,7,8)],exp_INV07[-c(5,7,9)],exp_INV07[-c(5,7,10)],
  exp_INV07[-c(5,8,9)],exp_INV07[-c(5,8,10)],
  exp_INV07[-c(5,9,10)],
  exp_INV07[-c(6,7,8)],exp_INV07[-c(6,7,9)],exp_INV07[-c(6,7,10)],
  exp_INV07[-c(6,8,9)],exp_INV07[-c(6,8,10)],
  exp_INV07[-c(6,9,10)],
  exp_INV07[-c(7,8,9)],exp_INV07[-c(7,8,10)],
  exp_INV07[-c(7,9,10)],
  exp_INV07[-c(8,9,10)],
  #6 vars
  exp_INV07[-c(1,2,3,4)],exp_INV07[-c(1,2,3,5)],exp_INV07[-c(1,2,3,6)],exp_INV07[-c(1,2,3,7)],exp_INV07[-c(1,2,3,8)],exp_INV07[-c(1,2,3,9)],exp_INV07[-c(1,2,3,10)],
  exp_INV07[-c(1,2,4,5)],exp_INV07[-c(1,2,4,6)],exp_INV07[-c(1,2,4,7)],exp_INV07[-c(1,2,4,8)],exp_INV07[-c(1,2,4,9)],exp_INV07[-c(1,2,4,10)],
  exp_INV07[-c(1,2,5,6)],exp_INV07[-c(1,2,5,7)],exp_INV07[-c(1,2,5,8)],exp_INV07[-c(1,2,5,9)],exp_INV07[-c(1,2,5,10)],
  exp_INV07[-c(1,2,6,7)],exp_INV07[-c(1,2,6,8)],exp_INV07[-c(1,2,6,9)],exp_INV07[-c(1,2,6,10)],
  exp_INV07[-c(1,2,7,8)],exp_INV07[-c(1,2,7,9)],exp_INV07[-c(1,2,7,10)],
  exp_INV07[-c(1,2,8,9)],exp_INV07[-c(1,2,8,10)],
  exp_INV07[-c(1,2,9,10)],
  exp_INV07[-c(1,3,4,5)],exp_INV07[-c(1,3,4,6)],exp_INV07[-c(1,3,4,7)],exp_INV07[-c(1,3,4,8)],exp_INV07[-c(1,3,4,9)],exp_INV07[-c(1,3,4,10)],
  exp_INV07[-c(1,3,5,6)],exp_INV07[-c(1,3,5,7)],exp_INV07[-c(1,3,5,8)],exp_INV07[-c(1,3,5,9)],exp_INV07[-c(1,3,5,10)],
  exp_INV07[-c(1,3,6,7)],exp_INV07[-c(1,3,6,8)],exp_INV07[-c(1,3,6,9)],exp_INV07[-c(1,3,6,10)],
  exp_INV07[-c(1,3,7,8)],exp_INV07[-c(1,3,7,9)],exp_INV07[-c(1,3,7,10)],
  exp_INV07[-c(1,3,8,9)],exp_INV07[-c(1,3,8,10)],
  exp_INV07[-c(1,3,9,10)],
  exp_INV07[-c(1,4,5,6)],exp_INV07[-c(1,4,5,7)],exp_INV07[-c(1,4,5,8)],exp_INV07[-c(1,4,5,9)],exp_INV07[-c(1,4,5,10)],
  exp_INV07[-c(1,4,6,7)],exp_INV07[-c(1,4,6,8)],exp_INV07[-c(1,4,6,9)],exp_INV07[-c(1,4,6,10)],
  exp_INV07[-c(1,4,7,8)],exp_INV07[-c(1,4,7,9)],exp_INV07[-c(1,4,7,10)],
  exp_INV07[-c(1,4,8,9)],exp_INV07[-c(1,4,8,10)],
  exp_INV07[-c(1,4,9,10)],
  exp_INV07[-c(1,5,6,7)],exp_INV07[-c(1,5,6,8)],exp_INV07[-c(1,5,6,9)],exp_INV07[-c(1,5,6,10)],
  exp_INV07[-c(1,5,7,8)],exp_INV07[-c(1,5,7,9)],exp_INV07[-c(1,5,7,10)],
  exp_INV07[-c(1,5,8,9)],exp_INV07[-c(1,5,8,10)],
  exp_INV07[-c(1,5,9,10)],
  exp_INV07[-c(1,6,7,8)],exp_INV07[-c(1,6,7,9)],exp_INV07[-c(1,6,7,10)],
  exp_INV07[-c(1,6,8,9)],exp_INV07[-c(1,6,8,10)],
  exp_INV07[-c(1,6,9,10)],
  exp_INV07[-c(1,7,8,9)],exp_INV07[-c(1,7,8,10)],
  exp_INV07[-c(1,7,9,10)],
  exp_INV07[-c(1,8,9,10)],
  
  exp_INV07[-c(2,3,4,5)],exp_INV07[-c(2,3,4,6)],exp_INV07[-c(2,3,4,7)],exp_INV07[-c(2,3,4,8)],exp_INV07[-c(2,3,4,9)],exp_INV07[-c(2,3,4,10)],
  exp_INV07[-c(2,3,5,6)],exp_INV07[-c(2,3,5,7)],exp_INV07[-c(2,3,5,8)],exp_INV07[-c(2,3,5,9)],exp_INV07[-c(2,3,5,10)],
  exp_INV07[-c(2,3,6,7)],exp_INV07[-c(2,3,6,8)],exp_INV07[-c(2,3,6,9)],exp_INV07[-c(2,3,6,10)],
  exp_INV07[-c(2,3,7,8)],exp_INV07[-c(2,3,7,9)],exp_INV07[-c(2,3,7,10)],
  exp_INV07[-c(2,3,8,9)],exp_INV07[-c(2,3,8,10)],
  exp_INV07[-c(2,3,9,10)],
  exp_INV07[-c(2,4,5,6)],exp_INV07[-c(2,4,5,7)],exp_INV07[-c(2,4,5,8)],exp_INV07[-c(2,4,5,9)],exp_INV07[-c(2,4,5,10)],
  exp_INV07[-c(2,4,6,7)],exp_INV07[-c(2,4,6,8)],exp_INV07[-c(2,4,6,9)],exp_INV07[-c(2,4,6,10)],
  exp_INV07[-c(2,4,7,8)],exp_INV07[-c(2,4,7,9)],exp_INV07[-c(2,4,7,10)],
  exp_INV07[-c(2,4,8,9)],exp_INV07[-c(2,4,8,10)],
  exp_INV07[-c(2,4,9,10)],
  exp_INV07[-c(2,5,6,7)],exp_INV07[-c(2,5,6,8)],exp_INV07[-c(2,5,6,9)],exp_INV07[-c(2,5,6,10)],
  exp_INV07[-c(2,5,7,8)],exp_INV07[-c(2,5,7,9)],exp_INV07[-c(2,5,7,10)],
  exp_INV07[-c(2,5,8,9)],exp_INV07[-c(2,5,8,10)],
  exp_INV07[-c(2,5,9,10)],
  exp_INV07[-c(2,6,7,8)],exp_INV07[-c(2,6,7,9)],exp_INV07[-c(2,6,7,10)],
  exp_INV07[-c(2,6,8,9)],exp_INV07[-c(2,6,8,10)],
  exp_INV07[-c(2,6,9,10)],
  exp_INV07[-c(2,7,8,9)],exp_INV07[-c(2,7,8,10)],
  exp_INV07[-c(2,7,9,10)],
  exp_INV07[-c(2,8,9,10)],
  
  exp_INV07[-c(3,4,5,6)],exp_INV07[-c(3,4,5,7)],exp_INV07[-c(3,4,5,8)],exp_INV07[-c(3,4,5,9)],exp_INV07[-c(3,4,5,10)],
  exp_INV07[-c(3,4,6,7)],exp_INV07[-c(3,4,6,8)],exp_INV07[-c(3,4,6,9)],exp_INV07[-c(3,4,6,10)],
  exp_INV07[-c(3,4,7,8)],exp_INV07[-c(3,4,7,9)],exp_INV07[-c(3,4,7,10)],
  exp_INV07[-c(3,4,8,9)],exp_INV07[-c(3,4,8,10)],
  exp_INV07[-c(3,4,9,10)],
  exp_INV07[-c(3,5,6,7)],exp_INV07[-c(3,5,6,8)],exp_INV07[-c(3,5,6,9)],exp_INV07[-c(3,5,6,10)],
  exp_INV07[-c(3,5,7,8)],exp_INV07[-c(3,5,7,9)],exp_INV07[-c(3,5,7,10)],
  exp_INV07[-c(3,5,8,9)],exp_INV07[-c(3,5,8,10)],
  exp_INV07[-c(3,5,9,10)],
  exp_INV07[-c(3,6,7,8)],exp_INV07[-c(3,6,7,9)],exp_INV07[-c(3,6,7,10)],
  exp_INV07[-c(3,6,8,9)],exp_INV07[-c(3,6,8,10)],
  exp_INV07[-c(3,6,9,10)],
  exp_INV07[-c(3,7,8,9)],exp_INV07[-c(3,7,8,10)],
  exp_INV07[-c(3,7,9,10)],
  exp_INV07[-c(3,8,9,10)],
  
  exp_INV07[-c(4,5,6,7)],exp_INV07[-c(4,5,6,8)],exp_INV07[-c(4,5,6,9)],exp_INV07[-c(4,5,6,10)],
  exp_INV07[-c(4,5,7,8)],exp_INV07[-c(4,5,7,9)],exp_INV07[-c(4,5,7,10)],
  exp_INV07[-c(4,5,8,9)],exp_INV07[-c(4,5,8,10)],
  exp_INV07[-c(4,5,9,10)],
  exp_INV07[-c(4,6,7,8)],exp_INV07[-c(4,6,7,9)],exp_INV07[-c(4,6,7,10)],
  exp_INV07[-c(4,6,8,9)],exp_INV07[-c(4,6,8,10)],
  exp_INV07[-c(4,6,9,10)],
  exp_INV07[-c(4,7,8,9)],exp_INV07[-c(4,7,8,10)],
  exp_INV07[-c(4,7,9,10)],
  exp_INV07[-c(4,8,9,10)],
  
  exp_INV07[-c(5,6,7,8)],exp_INV07[-c(5,6,7,9)],exp_INV07[-c(5,6,7,10)],
  exp_INV07[-c(5,6,8,9)],exp_INV07[-c(5,6,8,10)],
  exp_INV07[-c(5,6,9,10)],
  exp_INV07[-c(5,7,8,9)],exp_INV07[-c(5,7,8,10)],
  exp_INV07[-c(5,7,9,10)],
  exp_INV07[-c(5,8,9,10)],
  
  exp_INV07[-c(6,7,8,9)],exp_INV07[-c(6,7,8,10)],
  exp_INV07[-c(6,7,9,10)],
  exp_INV07[-c(6,8,9,10)],
  
  exp_INV07[-c(7,8,9,10)],
  #5 vars
  #1,x
  #1,2
  exp_INV07[c(1,2,3,4,5)],exp_INV07[c(1,2,3,4,6)],exp_INV07[c(1,2,3,4,7)],exp_INV07[c(1,2,3,4,8)],exp_INV07[c(1,2,3,4,9)],exp_INV07[c(1,2,3,4,10)],
  exp_INV07[c(1,2,3,5,6)],exp_INV07[c(1,2,3,5,7)],exp_INV07[c(1,2,3,5,8)],exp_INV07[c(1,2,3,5,9)],exp_INV07[c(1,2,3,5,10)],
  exp_INV07[c(1,2,3,6,7)],exp_INV07[c(1,2,3,6,8)],exp_INV07[c(1,2,3,6,9)],exp_INV07[c(1,2,3,6,10)],
  exp_INV07[c(1,2,3,7,8)],exp_INV07[c(1,2,3,7,9)],exp_INV07[c(1,2,3,7,10)],
  exp_INV07[c(1,2,3,8,9)],exp_INV07[c(1,2,3,8,10)],
  exp_INV07[c(1,2,3,9,10)],
  
  exp_INV07[c(1,2,4,5,6)],exp_INV07[c(1,2,4,5,7)],exp_INV07[c(1,2,4,5,8)],exp_INV07[c(1,2,4,5,9)],exp_INV07[c(1,2,4,5,10)],
  exp_INV07[c(1,2,4,6,7)],exp_INV07[c(1,2,4,6,8)],exp_INV07[c(1,2,4,6,9)],exp_INV07[c(1,2,4,6,10)],
  exp_INV07[c(1,2,4,7,8)],exp_INV07[c(1,2,4,7,9)],exp_INV07[c(1,2,4,7,10)],
  exp_INV07[c(1,2,4,8,9)],exp_INV07[c(1,2,4,8,10)],
  exp_INV07[c(1,2,4,9,10)],
  
  exp_INV07[c(1,2,5,6,7)],exp_INV07[c(1,2,5,6,8)],exp_INV07[c(1,2,5,6,9)],exp_INV07[c(1,2,5,6,10)],
  exp_INV07[c(1,2,5,7,8)],exp_INV07[c(1,2,5,7,9)],exp_INV07[c(1,2,5,7,10)],
  exp_INV07[c(1,2,5,8,9)],exp_INV07[c(1,2,5,8,10)],
  exp_INV07[c(1,2,5,9,10)],
  
  exp_INV07[c(1,2,6,7,8)],exp_INV07[c(1,2,6,7,9)],exp_INV07[c(1,2,6,7,10)],
  exp_INV07[c(1,2,6,8,9)],exp_INV07[c(1,2,6,8,10)],
  exp_INV07[c(1,2,6,9,10)],
  
  exp_INV07[c(1,2,7,8,9)],exp_INV07[c(1,2,7,8,10)],
  exp_INV07[c(1,2,7,9,10)],
  
  exp_INV07[c(1,2,8,9,10)],
  
  #1,3
  exp_INV07[c(1,3,4,5,6)],exp_INV07[c(1,3,4,5,7)],exp_INV07[c(1,3,4,5,8)],exp_INV07[c(1,3,4,5,9)],exp_INV07[c(1,3,4,5,10)],
  exp_INV07[c(1,3,4,6,7)],exp_INV07[c(1,3,4,6,8)],exp_INV07[c(1,3,4,6,9)],exp_INV07[c(1,3,4,6,10)],
  exp_INV07[c(1,3,4,7,8)],exp_INV07[c(1,3,4,7,9)],exp_INV07[c(1,3,4,7,10)],
  exp_INV07[c(1,3,4,8,9)],exp_INV07[c(1,3,4,8,10)],
  exp_INV07[c(1,3,4,9,10)],
  
  exp_INV07[c(1,3,5,6,7)],exp_INV07[c(1,3,5,6,8)],exp_INV07[c(1,3,5,6,9)],exp_INV07[c(1,3,5,6,10)],
  exp_INV07[c(1,3,5,7,8)],exp_INV07[c(1,3,5,7,9)],exp_INV07[c(1,3,5,7,10)],
  exp_INV07[c(1,3,5,8,9)],exp_INV07[c(1,3,5,8,10)],
  exp_INV07[c(1,3,5,9,10)],
  
  exp_INV07[c(1,3,6,7,8)],exp_INV07[c(1,3,6,7,9)],exp_INV07[c(1,3,6,7,10)],
  exp_INV07[c(1,3,6,8,9)],exp_INV07[c(1,3,6,8,10)],
  exp_INV07[c(1,3,6,9,10)],
  
  exp_INV07[c(1,3,7,8,9)],exp_INV07[c(1,3,7,8,10)],
  exp_INV07[c(1,3,7,9,10)],
  
  exp_INV07[c(1,3,8,9,10)],
  
  #1,4
  exp_INV07[c(1,4,5,6,7)],exp_INV07[c(1,4,5,6,8)],exp_INV07[c(1,4,5,6,9)],exp_INV07[c(1,4,5,6,10)],
  exp_INV07[c(1,4,5,7,8)],exp_INV07[c(1,4,5,7,9)],exp_INV07[c(1,4,5,7,10)],
  exp_INV07[c(1,4,5,8,9)],exp_INV07[c(1,4,5,8,10)],
  exp_INV07[c(1,4,5,9,10)],
  
  exp_INV07[c(1,4,6,7,8)],exp_INV07[c(1,4,6,7,9)],exp_INV07[c(1,4,6,7,10)],
  exp_INV07[c(1,4,6,8,9)],exp_INV07[c(1,4,6,8,10)],
  exp_INV07[c(1,4,6,9,10)],
  
  exp_INV07[c(1,4,7,8,9)],exp_INV07[c(1,4,7,8,10)],
  exp_INV07[c(1,4,7,9,10)],
  
  exp_INV07[c(1,4,8,9,10)],
  
  #1,5
  exp_INV07[c(1,5,6,7,8)],exp_INV07[c(1,5,6,7,9)],exp_INV07[c(1,5,6,7,10)],
  exp_INV07[c(1,5,6,8,9)],exp_INV07[c(1,5,6,8,10)],
  exp_INV07[c(1,5,6,9,10)],
  
  exp_INV07[c(1,5,7,8,9)],exp_INV07[c(1,5,7,8,10)],
  exp_INV07[c(1,5,7,9,10)],
  
  exp_INV07[c(1,5,8,9,10)],
  
  #1,6
  exp_INV07[c(1,6,7,8,9)],exp_INV07[c(1,6,7,8,10)],
  exp_INV07[c(1,6,7,9,10)],
  
  exp_INV07[c(1,6,8,9,10)],
  
  #1,7
  exp_INV07[c(1,7,8,9,10)],
  
  
  #2,x
  #2,3
  exp_INV07[c(2,3,4,5,6)],exp_INV07[c(2,3,4,5,7)],exp_INV07[c(2,3,4,5,8)],exp_INV07[c(2,3,4,5,9)],exp_INV07[c(2,3,4,5,10)],
  exp_INV07[c(2,3,4,6,7)],exp_INV07[c(2,3,4,6,8)],exp_INV07[c(2,3,4,6,9)],exp_INV07[c(2,3,4,6,10)],
  exp_INV07[c(2,3,4,7,8)],exp_INV07[c(2,3,4,7,9)],exp_INV07[c(2,3,4,7,10)],
  exp_INV07[c(2,3,4,8,9)],exp_INV07[c(2,3,4,8,10)],
  exp_INV07[c(2,3,4,9,10)],
  
  exp_INV07[c(2,3,5,6,7)],exp_INV07[c(2,3,5,6,8)],exp_INV07[c(2,3,5,6,9)],exp_INV07[c(2,3,5,6,10)],
  exp_INV07[c(2,3,5,7,8)],exp_INV07[c(2,3,5,7,9)],exp_INV07[c(2,3,5,7,10)],
  exp_INV07[c(2,3,5,8,9)],exp_INV07[c(2,3,5,8,10)],
  exp_INV07[c(2,3,5,9,10)],
  
  exp_INV07[c(2,3,6,7,8)],exp_INV07[c(2,3,6,7,9)],exp_INV07[c(2,3,6,7,10)],
  exp_INV07[c(2,3,6,8,9)],exp_INV07[c(2,3,6,8,10)],
  exp_INV07[c(2,3,6,9,10)],
  
  exp_INV07[c(2,3,7,8,9)],exp_INV07[c(2,3,7,8,10)],
  exp_INV07[c(2,3,7,9,10)],
  
  exp_INV07[c(2,3,8,9,10)],
  
  #2,4
  exp_INV07[c(2,4,5,6,7)],exp_INV07[c(2,4,5,6,8)],exp_INV07[c(2,4,5,6,9)],exp_INV07[c(2,4,5,6,10)],
  exp_INV07[c(2,4,5,7,8)],exp_INV07[c(2,4,5,7,9)],exp_INV07[c(2,4,5,7,10)],
  exp_INV07[c(2,4,5,8,9)],exp_INV07[c(2,4,5,8,10)],
  exp_INV07[c(2,4,5,9,10)],
  
  exp_INV07[c(2,4,6,7,8)],exp_INV07[c(2,4,6,7,9)],exp_INV07[c(2,4,6,7,10)],
  exp_INV07[c(2,4,6,8,9)],exp_INV07[c(2,4,6,8,10)],
  exp_INV07[c(2,4,6,9,10)],
  
  exp_INV07[c(2,4,7,8,9)],exp_INV07[c(2,4,7,8,10)],
  exp_INV07[c(2,4,7,9,10)],
  
  exp_INV07[c(2,4,8,9,10)],
  
  #2,5
  exp_INV07[c(2,5,6,7,8)],exp_INV07[c(2,5,6,7,9)],exp_INV07[c(2,5,6,7,10)],
  exp_INV07[c(2,5,6,8,9)],exp_INV07[c(2,5,6,8,10)],
  exp_INV07[c(2,5,6,9,10)],
  
  exp_INV07[c(2,5,7,8,9)],exp_INV07[c(2,5,7,8,10)],
  exp_INV07[c(2,5,7,9,10)],
  
  exp_INV07[c(2,5,8,9,10)],
  
  #2,6
  exp_INV07[c(2,6,7,8,9)],exp_INV07[c(2,6,7,8,10)],
  exp_INV07[c(2,6,7,9,10)],
  
  exp_INV07[c(2,6,8,9,10)],
  
  #2,7
  exp_INV07[c(2,7,8,9,10)],
  
  #3,x
  #3,4
  exp_INV07[c(3,4,5,6,7)],exp_INV07[c(3,4,5,6,8)],exp_INV07[c(3,4,5,6,9)],exp_INV07[c(3,4,5,6,10)],
  exp_INV07[c(3,4,5,7,8)],exp_INV07[c(3,4,5,7,9)],exp_INV07[c(3,4,5,7,10)],
  exp_INV07[c(3,4,5,8,9)],exp_INV07[c(3,4,5,8,10)],
  exp_INV07[c(3,4,5,9,10)],
  
  exp_INV07[c(3,4,6,7,8)],exp_INV07[c(3,4,6,7,9)],exp_INV07[c(3,4,6,7,10)],
  exp_INV07[c(3,4,6,8,9)],exp_INV07[c(3,4,6,8,10)],
  exp_INV07[c(3,4,6,9,10)],
  
  exp_INV07[c(3,4,7,8,9)],exp_INV07[c(3,4,7,8,10)],
  exp_INV07[c(3,4,7,9,10)],
  
  exp_INV07[c(3,4,8,9,10)],
  
  #3,5
  exp_INV07[c(3,5,6,7,8)],exp_INV07[c(3,5,6,7,9)],exp_INV07[c(3,5,6,7,10)],
  exp_INV07[c(3,5,6,8,9)],exp_INV07[c(3,5,6,8,10)],
  exp_INV07[c(3,5,6,9,10)],
  
  exp_INV07[c(3,5,7,8,9)],exp_INV07[c(3,5,7,8,10)],
  exp_INV07[c(3,5,7,9,10)],
  
  exp_INV07[c(3,5,8,9,10)],
  
  #3,6
  exp_INV07[c(3,6,7,8,9)],exp_INV07[c(3,6,7,8,10)],
  exp_INV07[c(3,6,7,9,10)],
  
  exp_INV07[c(3,6,8,9,10)],
  
  #3,7
  exp_INV07[c(3,7,8,9,10)],
  
  #4,x
  #4,5
  exp_INV07[c(4,5,6,7,8)],exp_INV07[c(4,5,6,7,9)],exp_INV07[c(4,5,6,7,10)],
  exp_INV07[c(4,5,6,8,9)],exp_INV07[c(4,5,6,8,10)],
  exp_INV07[c(4,5,6,9,10)],
  
  exp_INV07[c(4,5,7,8,9)],exp_INV07[c(4,5,7,8,10)],
  exp_INV07[c(4,5,7,9,10)],
  
  exp_INV07[c(4,5,8,9,10)],
  
  #4,6
  exp_INV07[c(4,6,7,8,9)],exp_INV07[c(4,6,7,8,10)],
  exp_INV07[c(4,6,7,9,10)],
  
  exp_INV07[c(4,6,8,9,10)],
  
  #4,7
  exp_INV07[c(4,7,8,9,10)],
  
  #5,x
  #5,6
  exp_INV07[c(5,6,7,8,9)],exp_INV07[c(5,6,7,8,10)],
  exp_INV07[c(5,6,7,9,10)],
  
  exp_INV07[c(5,6,8,9,10)],
  
  #5,7
  exp_INV07[c(5,7,8,9,10)],
  
  #6,x
  #6,7
  exp_INV07[c(6,7,8,9,10)],
  
  #4 vars
  exp_INV07[c(1,2,3,4)],exp_INV07[c(1,2,3,5)],exp_INV07[c(1,2,3,6)],exp_INV07[c(1,2,3,7)],exp_INV07[c(1,2,3,8)],exp_INV07[c(1,2,3,9)],exp_INV07[c(1,2,3,10)],
  exp_INV07[c(1,2,4,5)],exp_INV07[c(1,2,4,6)],exp_INV07[c(1,2,4,7)],exp_INV07[c(1,2,4,8)],exp_INV07[c(1,2,4,9)],exp_INV07[c(1,2,4,10)],
  exp_INV07[c(1,2,5,6)],exp_INV07[c(1,2,5,7)],exp_INV07[c(1,2,5,8)],exp_INV07[c(1,2,5,9)],exp_INV07[c(1,2,5,10)],
  exp_INV07[c(1,2,6,7)],exp_INV07[c(1,2,6,8)],exp_INV07[c(1,2,6,9)],exp_INV07[c(1,2,6,10)],
  exp_INV07[c(1,2,7,8)],exp_INV07[c(1,2,7,9)],exp_INV07[c(1,2,7,10)],
  exp_INV07[c(1,2,8,9)],exp_INV07[c(1,2,8,10)],
  exp_INV07[c(1,2,9,10)],
  exp_INV07[c(1,3,4,5)],exp_INV07[c(1,3,4,6)],exp_INV07[c(1,3,4,7)],exp_INV07[c(1,3,4,8)],exp_INV07[c(1,3,4,9)],exp_INV07[c(1,3,4,10)],
  exp_INV07[c(1,3,5,6)],exp_INV07[c(1,3,5,7)],exp_INV07[c(1,3,5,8)],exp_INV07[c(1,3,5,9)],exp_INV07[c(1,3,5,10)],
  exp_INV07[c(1,3,6,7)],exp_INV07[c(1,3,6,8)],exp_INV07[c(1,3,6,9)],exp_INV07[c(1,3,6,10)],
  exp_INV07[c(1,3,7,8)],exp_INV07[c(1,3,7,9)],exp_INV07[c(1,3,7,10)],
  exp_INV07[c(1,3,8,9)],exp_INV07[c(1,3,8,10)],
  exp_INV07[c(1,3,9,10)],
  exp_INV07[c(1,4,5,6)],exp_INV07[c(1,4,5,7)],exp_INV07[c(1,4,5,8)],exp_INV07[c(1,4,5,9)],exp_INV07[c(1,4,5,10)],
  exp_INV07[c(1,4,6,7)],exp_INV07[c(1,4,6,8)],exp_INV07[c(1,4,6,9)],exp_INV07[c(1,4,6,10)],
  exp_INV07[c(1,4,7,8)],exp_INV07[c(1,4,7,9)],exp_INV07[c(1,4,7,10)],
  exp_INV07[c(1,4,8,9)],exp_INV07[c(1,4,8,10)],
  exp_INV07[c(1,4,9,10)],
  exp_INV07[c(1,5,6,7)],exp_INV07[c(1,5,6,8)],exp_INV07[c(1,5,6,9)],exp_INV07[c(1,5,6,10)],
  exp_INV07[c(1,5,7,8)],exp_INV07[c(1,5,7,9)],exp_INV07[c(1,5,7,10)],
  exp_INV07[c(1,5,8,9)],exp_INV07[c(1,5,8,10)],
  exp_INV07[c(1,5,9,10)],
  exp_INV07[c(1,6,7,8)],exp_INV07[c(1,6,7,9)],exp_INV07[c(1,6,7,10)],
  exp_INV07[c(1,6,8,9)],exp_INV07[c(1,6,8,10)],
  exp_INV07[c(1,6,9,10)],
  exp_INV07[c(1,7,8,9)],exp_INV07[c(1,7,8,10)],
  exp_INV07[c(1,7,9,10)],
  exp_INV07[c(1,8,9,10)],
  
  exp_INV07[c(2,3,4,5)],exp_INV07[c(2,3,4,6)],exp_INV07[c(2,3,4,7)],exp_INV07[c(2,3,4,8)],exp_INV07[c(2,3,4,9)],exp_INV07[c(2,3,4,10)],
  exp_INV07[c(2,3,5,6)],exp_INV07[c(2,3,5,7)],exp_INV07[c(2,3,5,8)],exp_INV07[c(2,3,5,9)],exp_INV07[c(2,3,5,10)],
  exp_INV07[c(2,3,6,7)],exp_INV07[c(2,3,6,8)],exp_INV07[c(2,3,6,9)],exp_INV07[c(2,3,6,10)],
  exp_INV07[c(2,3,7,8)],exp_INV07[c(2,3,7,9)],exp_INV07[c(2,3,7,10)],
  exp_INV07[c(2,3,8,9)],exp_INV07[c(2,3,8,10)],
  exp_INV07[c(2,3,9,10)],
  exp_INV07[c(2,4,5,6)],exp_INV07[c(2,4,5,7)],exp_INV07[c(2,4,5,8)],exp_INV07[c(2,4,5,9)],exp_INV07[c(2,4,5,10)],
  exp_INV07[c(2,4,6,7)],exp_INV07[c(2,4,6,8)],exp_INV07[c(2,4,6,9)],exp_INV07[c(2,4,6,10)],
  exp_INV07[c(2,4,7,8)],exp_INV07[c(2,4,7,9)],exp_INV07[c(2,4,7,10)],
  exp_INV07[c(2,4,8,9)],exp_INV07[c(2,4,8,10)],
  exp_INV07[c(2,4,9,10)],
  exp_INV07[c(2,5,6,7)],exp_INV07[c(2,5,6,8)],exp_INV07[c(2,5,6,9)],exp_INV07[c(2,5,6,10)],
  exp_INV07[c(2,5,7,8)],exp_INV07[c(2,5,7,9)],exp_INV07[c(2,5,7,10)],
  exp_INV07[c(2,5,8,9)],exp_INV07[c(2,5,8,10)],
  exp_INV07[c(2,5,9,10)],
  exp_INV07[c(2,6,7,8)],exp_INV07[c(2,6,7,9)],exp_INV07[c(2,6,7,10)],
  exp_INV07[c(2,6,8,9)],exp_INV07[c(2,6,8,10)],
  exp_INV07[c(2,6,9,10)],
  exp_INV07[c(2,7,8,9)],exp_INV07[c(2,7,8,10)],
  exp_INV07[c(2,7,9,10)],
  exp_INV07[c(2,8,9,10)],
  
  exp_INV07[c(3,4,5,6)],exp_INV07[c(3,4,5,7)],exp_INV07[c(3,4,5,8)],exp_INV07[c(3,4,5,9)],exp_INV07[c(3,4,5,10)],
  exp_INV07[c(3,4,6,7)],exp_INV07[c(3,4,6,8)],exp_INV07[c(3,4,6,9)],exp_INV07[c(3,4,6,10)],
  exp_INV07[c(3,4,7,8)],exp_INV07[c(3,4,7,9)],exp_INV07[c(3,4,7,10)],
  exp_INV07[c(3,4,8,9)],exp_INV07[c(3,4,8,10)],
  exp_INV07[c(3,4,9,10)],
  exp_INV07[c(3,5,6,7)],exp_INV07[c(3,5,6,8)],exp_INV07[c(3,5,6,9)],exp_INV07[c(3,5,6,10)],
  exp_INV07[c(3,5,7,8)],exp_INV07[c(3,5,7,9)],exp_INV07[c(3,5,7,10)],
  exp_INV07[c(3,5,8,9)],exp_INV07[c(3,5,8,10)],
  exp_INV07[c(3,5,9,10)],
  exp_INV07[c(3,6,7,8)],exp_INV07[c(3,6,7,9)],exp_INV07[c(3,6,7,10)],
  exp_INV07[c(3,6,8,9)],exp_INV07[c(3,6,8,10)],
  exp_INV07[c(3,6,9,10)],
  exp_INV07[c(3,7,8,9)],exp_INV07[c(3,7,8,10)],
  exp_INV07[c(3,7,9,10)],
  exp_INV07[c(3,8,9,10)],
  
  exp_INV07[c(4,5,6,7)],exp_INV07[c(4,5,6,8)],exp_INV07[c(4,5,6,9)],exp_INV07[c(4,5,6,10)],
  exp_INV07[c(4,5,7,8)],exp_INV07[c(4,5,7,9)],exp_INV07[c(4,5,7,10)],
  exp_INV07[c(4,5,8,9)],exp_INV07[c(4,5,8,10)],
  exp_INV07[c(4,5,9,10)],
  exp_INV07[c(4,6,7,8)],exp_INV07[c(4,6,7,9)],exp_INV07[c(4,6,7,10)],
  exp_INV07[c(4,6,8,9)],exp_INV07[c(4,6,8,10)],
  exp_INV07[c(4,6,9,10)],
  exp_INV07[c(4,7,8,9)],exp_INV07[c(4,7,8,10)],
  exp_INV07[c(4,7,9,10)],
  exp_INV07[c(4,8,9,10)],
  
  exp_INV07[c(5,6,7,8)],exp_INV07[c(5,6,7,9)],exp_INV07[c(5,6,7,10)],
  exp_INV07[c(5,6,8,9)],exp_INV07[c(5,6,8,10)],
  exp_INV07[c(5,6,9,10)],
  exp_INV07[c(5,7,8,9)],exp_INV07[c(5,7,8,10)],
  exp_INV07[c(5,7,9,10)],
  exp_INV07[c(5,8,9,10)],
  
  exp_INV07[c(6,7,8,9)],exp_INV07[c(6,7,8,10)],
  exp_INV07[c(6,7,9,10)],
  exp_INV07[c(6,8,9,10)],
  
  exp_INV07[c(7,8,9,10)],
  
  #3 vars
  exp_INV07[c(1,2,3)],exp_INV07[c(1,2,4)],exp_INV07[c(1,2,5)],exp_INV07[c(1,2,6)],exp_INV07[c(1,2,7)],exp_INV07[c(1,2,8)],exp_INV07[c(1,2,9)],exp_INV07[c(1,2,10)],
  exp_INV07[c(1,3,4)],exp_INV07[c(1,3,5)],exp_INV07[c(1,3,6)],exp_INV07[c(1,3,7)],exp_INV07[c(1,3,8)],exp_INV07[c(1,3,9)],exp_INV07[c(1,3,10)],
  exp_INV07[c(1,4,5)],exp_INV07[c(1,4,6)],exp_INV07[c(1,4,7)],exp_INV07[c(1,4,8)],exp_INV07[c(1,4,9)],exp_INV07[c(1,4,10)],
  exp_INV07[c(1,5,6)],exp_INV07[c(1,5,7)],exp_INV07[c(1,5,8)],exp_INV07[c(1,5,9)],exp_INV07[c(1,5,10)],
  exp_INV07[c(1,6,7)],exp_INV07[c(1,6,8)],exp_INV07[c(1,6,9)],exp_INV07[c(1,6,10)],
  exp_INV07[c(1,7,8)],exp_INV07[c(1,7,9)],exp_INV07[c(1,7,10)],
  exp_INV07[c(1,8,9)],exp_INV07[c(1,8,10)],
  exp_INV07[c(1,9,10)],
  exp_INV07[c(2,3,4)],exp_INV07[c(2,3,5)],exp_INV07[c(2,3,6)],exp_INV07[c(2,3,7)],exp_INV07[c(2,3,8)],exp_INV07[c(2,3,9)],exp_INV07[c(2,3,10)],
  exp_INV07[c(2,4,5)],exp_INV07[c(2,4,6)],exp_INV07[c(2,4,7)],exp_INV07[c(2,4,8)],exp_INV07[c(2,4,9)],exp_INV07[c(2,4,10)],
  exp_INV07[c(2,5,6)],exp_INV07[c(2,5,7)],exp_INV07[c(2,5,8)],exp_INV07[c(2,5,9)],exp_INV07[c(2,5,10)],
  exp_INV07[c(2,6,7)],exp_INV07[c(2,6,8)],exp_INV07[c(2,6,9)],exp_INV07[c(2,6,10)],
  exp_INV07[c(2,7,8)],exp_INV07[c(2,7,9)],exp_INV07[c(2,7,10)],
  exp_INV07[c(2,8,9)],exp_INV07[c(2,8,10)],
  exp_INV07[c(2,9,10)],
  exp_INV07[c(3,4,5)],exp_INV07[c(3,4,6)],exp_INV07[c(3,4,7)],exp_INV07[c(3,4,8)],exp_INV07[c(3,4,9)],exp_INV07[c(3,4,10)],
  exp_INV07[c(3,5,6)],exp_INV07[c(3,5,7)],exp_INV07[c(3,5,8)],exp_INV07[c(3,5,9)],exp_INV07[c(3,5,10)],
  exp_INV07[c(3,6,7)],exp_INV07[c(3,6,8)],exp_INV07[c(3,6,9)],exp_INV07[c(3,6,10)],
  exp_INV07[c(3,7,8)],exp_INV07[c(3,7,9)],exp_INV07[c(3,7,10)],
  exp_INV07[c(3,8,9)],exp_INV07[c(3,8,10)],
  exp_INV07[c(3,9,10)],
  exp_INV07[c(4,5,6)],exp_INV07[c(4,5,7)],exp_INV07[c(4,5,8)],exp_INV07[c(4,5,9)],exp_INV07[c(4,5,10)],
  exp_INV07[c(4,6,7)],exp_INV07[c(4,6,8)],exp_INV07[c(4,6,9)],exp_INV07[c(4,6,10)],
  exp_INV07[c(4,7,8)],exp_INV07[c(4,7,9)],exp_INV07[c(4,7,10)],
  exp_INV07[c(4,8,9)],exp_INV07[c(4,8,10)],
  exp_INV07[c(4,9,10)],
  exp_INV07[c(5,6,7)],exp_INV07[c(5,6,8)],exp_INV07[c(5,6,9)],exp_INV07[c(5,6,10)],
  exp_INV07[c(5,7,8)],exp_INV07[c(5,7,9)],exp_INV07[c(5,7,10)],
  exp_INV07[c(5,8,9)],exp_INV07[c(5,8,10)],
  exp_INV07[c(5,9,10)],
  exp_INV07[c(6,7,8)],exp_INV07[c(6,7,9)],exp_INV07[c(6,7,10)],
  exp_INV07[c(6,8,9)],exp_INV07[c(6,8,10)],
  exp_INV07[c(6,9,10)],
  exp_INV07[c(7,8,9)],exp_INV07[c(7,8,10)],
  exp_INV07[c(7,9,10)],
  exp_INV07[c(8,9,10)],
  
  #2 vars
  exp_INV07[c(1,2)],exp_INV07[c(1,3)],exp_INV07[c(1,4)],exp_INV07[c(1,5)],exp_INV07[c(1,6)],exp_INV07[c(1,7)],exp_INV07[c(1,8)],exp_INV07[c(1,9)],exp_INV07[c(1,10)],
  exp_INV07[c(2,3)],exp_INV07[c(2,4)],exp_INV07[c(2,5)],exp_INV07[c(2,6)],exp_INV07[c(2,7)],exp_INV07[c(2,8)],exp_INV07[c(2,9)],exp_INV07[c(2,10)],
  exp_INV07[c(3,4)],exp_INV07[c(3,5)],exp_INV07[c(3,6)],exp_INV07[c(3,7)],exp_INV07[c(3,8)],exp_INV07[c(3,9)],exp_INV07[c(3,10)],
  exp_INV07[c(4,5)],exp_INV07[c(4,6)],exp_INV07[c(4,7)],exp_INV07[c(4,8)],exp_INV07[c(4,9)],exp_INV07[c(4,10)],
  exp_INV07[c(5,6)],exp_INV07[c(5,7)],exp_INV07[c(5,8)],exp_INV07[c(5,9)],exp_INV07[c(5,10)],
  exp_INV07[c(6,7)],exp_INV07[c(6,8)],exp_INV07[c(6,9)],exp_INV07[c(6,10)],
  exp_INV07[c(7,8)],exp_INV07[c(7,9)],exp_INV07[c(7,10)],
  exp_INV07[c(8,9)],exp_INV07[c(8,10)],
  exp_INV07[c(9,10)],
  #1 var
  exp_INV07[1],exp_INV07[2],exp_INV07[3],exp_INV07[4],exp_INV07[5],exp_INV07[6],exp_INV07[7],exp_INV07[8],exp_INV07[9],exp_INV07[10],
  #null
  c("1"))


#### INV12 (10) ####

exp_all_INV12vars <- list(
  #10 vars
  exp_INV12,
  #9 vars
  exp_INV12[-c(1)],exp_INV12[-c(2)],exp_INV12[-c(3)],exp_INV12[-c(4)],exp_INV12[-c(5)],exp_INV12[-c(6)],exp_INV12[-c(7)],exp_INV12[-c(8)],exp_INV12[-c(9)],exp_INV12[-c(10)],
  #8 vars
  exp_INV12[-c(1,2)],exp_INV12[-c(1,3)],exp_INV12[-c(1,4)],exp_INV12[-c(1,5)],exp_INV12[-c(1,6)],exp_INV12[-c(1,7)],exp_INV12[-c(1,8)],exp_INV12[-c(1,9)],exp_INV12[-c(1,10)],
  exp_INV12[-c(2,3)],exp_INV12[-c(2,4)],exp_INV12[-c(2,5)],exp_INV12[-c(2,6)],exp_INV12[-c(2,7)],exp_INV12[-c(2,8)],exp_INV12[-c(2,9)],exp_INV12[-c(2,10)],
  exp_INV12[-c(3,4)],exp_INV12[-c(3,5)],exp_INV12[-c(3,6)],exp_INV12[-c(3,7)],exp_INV12[-c(3,8)],exp_INV12[-c(3,9)],exp_INV12[-c(3,10)],
  exp_INV12[-c(4,5)],exp_INV12[-c(4,6)],exp_INV12[-c(4,7)],exp_INV12[-c(4,8)],exp_INV12[-c(4,9)],exp_INV12[-c(4,10)],
  exp_INV12[-c(5,6)],exp_INV12[-c(5,7)],exp_INV12[-c(5,8)],exp_INV12[-c(5,9)],exp_INV12[-c(5,10)],
  exp_INV12[-c(6,7)],exp_INV12[-c(6,8)],exp_INV12[-c(6,9)],exp_INV12[-c(6,10)],
  exp_INV12[-c(7,8)],exp_INV12[-c(7,9)],exp_INV12[-c(7,10)],
  exp_INV12[-c(8,9)],exp_INV12[-c(8,10)],
  exp_INV12[-c(9,10)],
  #7 vars
  exp_INV12[-c(1,2,3)],exp_INV12[-c(1,2,4)],exp_INV12[-c(1,2,5)],exp_INV12[-c(1,2,6)],exp_INV12[-c(1,2,7)],exp_INV12[-c(1,2,8)],exp_INV12[-c(1,2,9)],exp_INV12[-c(1,2,10)],
  exp_INV12[-c(1,3,4)],exp_INV12[-c(1,3,5)],exp_INV12[-c(1,3,6)],exp_INV12[-c(1,3,7)],exp_INV12[-c(1,3,8)],exp_INV12[-c(1,3,9)],exp_INV12[-c(1,3,10)],
  exp_INV12[-c(1,4,5)],exp_INV12[-c(1,4,6)],exp_INV12[-c(1,4,7)],exp_INV12[-c(1,4,8)],exp_INV12[-c(1,4,9)],exp_INV12[-c(1,4,10)],
  exp_INV12[-c(1,5,6)],exp_INV12[-c(1,5,7)],exp_INV12[-c(1,5,8)],exp_INV12[-c(1,5,9)],exp_INV12[-c(1,5,10)],
  exp_INV12[-c(1,6,7)],exp_INV12[-c(1,6,8)],exp_INV12[-c(1,6,9)],exp_INV12[-c(1,6,10)],
  exp_INV12[-c(1,7,8)],exp_INV12[-c(1,7,9)],exp_INV12[-c(1,7,10)],
  exp_INV12[-c(1,8,9)],exp_INV12[-c(1,8,10)],
  exp_INV12[-c(1,9,10)],
  exp_INV12[-c(2,3,4)],exp_INV12[-c(2,3,5)],exp_INV12[-c(2,3,6)],exp_INV12[-c(2,3,7)],exp_INV12[-c(2,3,8)],exp_INV12[-c(2,3,9)],exp_INV12[-c(2,3,10)],
  exp_INV12[-c(2,4,5)],exp_INV12[-c(2,4,6)],exp_INV12[-c(2,4,7)],exp_INV12[-c(2,4,8)],exp_INV12[-c(2,4,9)],exp_INV12[-c(2,4,10)],
  exp_INV12[-c(2,5,6)],exp_INV12[-c(2,5,7)],exp_INV12[-c(2,5,8)],exp_INV12[-c(2,5,9)],exp_INV12[-c(2,5,10)],
  exp_INV12[-c(2,6,7)],exp_INV12[-c(2,6,8)],exp_INV12[-c(2,6,9)],exp_INV12[-c(2,6,10)],
  exp_INV12[-c(2,7,8)],exp_INV12[-c(2,7,9)],exp_INV12[-c(2,7,10)],
  exp_INV12[-c(2,8,9)],exp_INV12[-c(2,8,10)],
  exp_INV12[-c(2,9,10)],
  exp_INV12[-c(3,4,5)],exp_INV12[-c(3,4,6)],exp_INV12[-c(3,4,7)],exp_INV12[-c(3,4,8)],exp_INV12[-c(3,4,9)],exp_INV12[-c(3,4,10)],
  exp_INV12[-c(3,5,6)],exp_INV12[-c(3,5,7)],exp_INV12[-c(3,5,8)],exp_INV12[-c(3,5,9)],exp_INV12[-c(3,5,10)],
  exp_INV12[-c(3,6,7)],exp_INV12[-c(3,6,8)],exp_INV12[-c(3,6,9)],exp_INV12[-c(3,6,10)],
  exp_INV12[-c(3,7,8)],exp_INV12[-c(3,7,9)],exp_INV12[-c(3,7,10)],
  exp_INV12[-c(3,8,9)],exp_INV12[-c(3,8,10)],
  exp_INV12[-c(3,9,10)],
  exp_INV12[-c(4,5,6)],exp_INV12[-c(4,5,7)],exp_INV12[-c(4,5,8)],exp_INV12[-c(4,5,9)],exp_INV12[-c(4,5,10)],
  exp_INV12[-c(4,6,7)],exp_INV12[-c(4,6,8)],exp_INV12[-c(4,6,9)],exp_INV12[-c(4,6,10)],
  exp_INV12[-c(4,7,8)],exp_INV12[-c(4,7,9)],exp_INV12[-c(4,7,10)],
  exp_INV12[-c(4,8,9)],exp_INV12[-c(4,8,10)],
  exp_INV12[-c(4,9,10)],
  exp_INV12[-c(5,6,7)],exp_INV12[-c(5,6,8)],exp_INV12[-c(5,6,9)],exp_INV12[-c(5,6,10)],
  exp_INV12[-c(5,7,8)],exp_INV12[-c(5,7,9)],exp_INV12[-c(5,7,10)],
  exp_INV12[-c(5,8,9)],exp_INV12[-c(5,8,10)],
  exp_INV12[-c(5,9,10)],
  exp_INV12[-c(6,7,8)],exp_INV12[-c(6,7,9)],exp_INV12[-c(6,7,10)],
  exp_INV12[-c(6,8,9)],exp_INV12[-c(6,8,10)],
  exp_INV12[-c(6,9,10)],
  exp_INV12[-c(7,8,9)],exp_INV12[-c(7,8,10)],
  exp_INV12[-c(7,9,10)],
  exp_INV12[-c(8,9,10)],
  #6 vars
  exp_INV12[-c(1,2,3,4)],exp_INV12[-c(1,2,3,5)],exp_INV12[-c(1,2,3,6)],exp_INV12[-c(1,2,3,7)],exp_INV12[-c(1,2,3,8)],exp_INV12[-c(1,2,3,9)],exp_INV12[-c(1,2,3,10)],
  exp_INV12[-c(1,2,4,5)],exp_INV12[-c(1,2,4,6)],exp_INV12[-c(1,2,4,7)],exp_INV12[-c(1,2,4,8)],exp_INV12[-c(1,2,4,9)],exp_INV12[-c(1,2,4,10)],
  exp_INV12[-c(1,2,5,6)],exp_INV12[-c(1,2,5,7)],exp_INV12[-c(1,2,5,8)],exp_INV12[-c(1,2,5,9)],exp_INV12[-c(1,2,5,10)],
  exp_INV12[-c(1,2,6,7)],exp_INV12[-c(1,2,6,8)],exp_INV12[-c(1,2,6,9)],exp_INV12[-c(1,2,6,10)],
  exp_INV12[-c(1,2,7,8)],exp_INV12[-c(1,2,7,9)],exp_INV12[-c(1,2,7,10)],
  exp_INV12[-c(1,2,8,9)],exp_INV12[-c(1,2,8,10)],
  exp_INV12[-c(1,2,9,10)],
  exp_INV12[-c(1,3,4,5)],exp_INV12[-c(1,3,4,6)],exp_INV12[-c(1,3,4,7)],exp_INV12[-c(1,3,4,8)],exp_INV12[-c(1,3,4,9)],exp_INV12[-c(1,3,4,10)],
  exp_INV12[-c(1,3,5,6)],exp_INV12[-c(1,3,5,7)],exp_INV12[-c(1,3,5,8)],exp_INV12[-c(1,3,5,9)],exp_INV12[-c(1,3,5,10)],
  exp_INV12[-c(1,3,6,7)],exp_INV12[-c(1,3,6,8)],exp_INV12[-c(1,3,6,9)],exp_INV12[-c(1,3,6,10)],
  exp_INV12[-c(1,3,7,8)],exp_INV12[-c(1,3,7,9)],exp_INV12[-c(1,3,7,10)],
  exp_INV12[-c(1,3,8,9)],exp_INV12[-c(1,3,8,10)],
  exp_INV12[-c(1,3,9,10)],
  exp_INV12[-c(1,4,5,6)],exp_INV12[-c(1,4,5,7)],exp_INV12[-c(1,4,5,8)],exp_INV12[-c(1,4,5,9)],exp_INV12[-c(1,4,5,10)],
  exp_INV12[-c(1,4,6,7)],exp_INV12[-c(1,4,6,8)],exp_INV12[-c(1,4,6,9)],exp_INV12[-c(1,4,6,10)],
  exp_INV12[-c(1,4,7,8)],exp_INV12[-c(1,4,7,9)],exp_INV12[-c(1,4,7,10)],
  exp_INV12[-c(1,4,8,9)],exp_INV12[-c(1,4,8,10)],
  exp_INV12[-c(1,4,9,10)],
  exp_INV12[-c(1,5,6,7)],exp_INV12[-c(1,5,6,8)],exp_INV12[-c(1,5,6,9)],exp_INV12[-c(1,5,6,10)],
  exp_INV12[-c(1,5,7,8)],exp_INV12[-c(1,5,7,9)],exp_INV12[-c(1,5,7,10)],
  exp_INV12[-c(1,5,8,9)],exp_INV12[-c(1,5,8,10)],
  exp_INV12[-c(1,5,9,10)],
  exp_INV12[-c(1,6,7,8)],exp_INV12[-c(1,6,7,9)],exp_INV12[-c(1,6,7,10)],
  exp_INV12[-c(1,6,8,9)],exp_INV12[-c(1,6,8,10)],
  exp_INV12[-c(1,6,9,10)],
  exp_INV12[-c(1,7,8,9)],exp_INV12[-c(1,7,8,10)],
  exp_INV12[-c(1,7,9,10)],
  exp_INV12[-c(1,8,9,10)],
  
  exp_INV12[-c(2,3,4,5)],exp_INV12[-c(2,3,4,6)],exp_INV12[-c(2,3,4,7)],exp_INV12[-c(2,3,4,8)],exp_INV12[-c(2,3,4,9)],exp_INV12[-c(2,3,4,10)],
  exp_INV12[-c(2,3,5,6)],exp_INV12[-c(2,3,5,7)],exp_INV12[-c(2,3,5,8)],exp_INV12[-c(2,3,5,9)],exp_INV12[-c(2,3,5,10)],
  exp_INV12[-c(2,3,6,7)],exp_INV12[-c(2,3,6,8)],exp_INV12[-c(2,3,6,9)],exp_INV12[-c(2,3,6,10)],
  exp_INV12[-c(2,3,7,8)],exp_INV12[-c(2,3,7,9)],exp_INV12[-c(2,3,7,10)],
  exp_INV12[-c(2,3,8,9)],exp_INV12[-c(2,3,8,10)],
  exp_INV12[-c(2,3,9,10)],
  exp_INV12[-c(2,4,5,6)],exp_INV12[-c(2,4,5,7)],exp_INV12[-c(2,4,5,8)],exp_INV12[-c(2,4,5,9)],exp_INV12[-c(2,4,5,10)],
  exp_INV12[-c(2,4,6,7)],exp_INV12[-c(2,4,6,8)],exp_INV12[-c(2,4,6,9)],exp_INV12[-c(2,4,6,10)],
  exp_INV12[-c(2,4,7,8)],exp_INV12[-c(2,4,7,9)],exp_INV12[-c(2,4,7,10)],
  exp_INV12[-c(2,4,8,9)],exp_INV12[-c(2,4,8,10)],
  exp_INV12[-c(2,4,9,10)],
  exp_INV12[-c(2,5,6,7)],exp_INV12[-c(2,5,6,8)],exp_INV12[-c(2,5,6,9)],exp_INV12[-c(2,5,6,10)],
  exp_INV12[-c(2,5,7,8)],exp_INV12[-c(2,5,7,9)],exp_INV12[-c(2,5,7,10)],
  exp_INV12[-c(2,5,8,9)],exp_INV12[-c(2,5,8,10)],
  exp_INV12[-c(2,5,9,10)],
  exp_INV12[-c(2,6,7,8)],exp_INV12[-c(2,6,7,9)],exp_INV12[-c(2,6,7,10)],
  exp_INV12[-c(2,6,8,9)],exp_INV12[-c(2,6,8,10)],
  exp_INV12[-c(2,6,9,10)],
  exp_INV12[-c(2,7,8,9)],exp_INV12[-c(2,7,8,10)],
  exp_INV12[-c(2,7,9,10)],
  exp_INV12[-c(2,8,9,10)],
  
  exp_INV12[-c(3,4,5,6)],exp_INV12[-c(3,4,5,7)],exp_INV12[-c(3,4,5,8)],exp_INV12[-c(3,4,5,9)],exp_INV12[-c(3,4,5,10)],
  exp_INV12[-c(3,4,6,7)],exp_INV12[-c(3,4,6,8)],exp_INV12[-c(3,4,6,9)],exp_INV12[-c(3,4,6,10)],
  exp_INV12[-c(3,4,7,8)],exp_INV12[-c(3,4,7,9)],exp_INV12[-c(3,4,7,10)],
  exp_INV12[-c(3,4,8,9)],exp_INV12[-c(3,4,8,10)],
  exp_INV12[-c(3,4,9,10)],
  exp_INV12[-c(3,5,6,7)],exp_INV12[-c(3,5,6,8)],exp_INV12[-c(3,5,6,9)],exp_INV12[-c(3,5,6,10)],
  exp_INV12[-c(3,5,7,8)],exp_INV12[-c(3,5,7,9)],exp_INV12[-c(3,5,7,10)],
  exp_INV12[-c(3,5,8,9)],exp_INV12[-c(3,5,8,10)],
  exp_INV12[-c(3,5,9,10)],
  exp_INV12[-c(3,6,7,8)],exp_INV12[-c(3,6,7,9)],exp_INV12[-c(3,6,7,10)],
  exp_INV12[-c(3,6,8,9)],exp_INV12[-c(3,6,8,10)],
  exp_INV12[-c(3,6,9,10)],
  exp_INV12[-c(3,7,8,9)],exp_INV12[-c(3,7,8,10)],
  exp_INV12[-c(3,7,9,10)],
  exp_INV12[-c(3,8,9,10)],
  
  exp_INV12[-c(4,5,6,7)],exp_INV12[-c(4,5,6,8)],exp_INV12[-c(4,5,6,9)],exp_INV12[-c(4,5,6,10)],
  exp_INV12[-c(4,5,7,8)],exp_INV12[-c(4,5,7,9)],exp_INV12[-c(4,5,7,10)],
  exp_INV12[-c(4,5,8,9)],exp_INV12[-c(4,5,8,10)],
  exp_INV12[-c(4,5,9,10)],
  exp_INV12[-c(4,6,7,8)],exp_INV12[-c(4,6,7,9)],exp_INV12[-c(4,6,7,10)],
  exp_INV12[-c(4,6,8,9)],exp_INV12[-c(4,6,8,10)],
  exp_INV12[-c(4,6,9,10)],
  exp_INV12[-c(4,7,8,9)],exp_INV12[-c(4,7,8,10)],
  exp_INV12[-c(4,7,9,10)],
  exp_INV12[-c(4,8,9,10)],
  
  exp_INV12[-c(5,6,7,8)],exp_INV12[-c(5,6,7,9)],exp_INV12[-c(5,6,7,10)],
  exp_INV12[-c(5,6,8,9)],exp_INV12[-c(5,6,8,10)],
  exp_INV12[-c(5,6,9,10)],
  exp_INV12[-c(5,7,8,9)],exp_INV12[-c(5,7,8,10)],
  exp_INV12[-c(5,7,9,10)],
  exp_INV12[-c(5,8,9,10)],
  
  exp_INV12[-c(6,7,8,9)],exp_INV12[-c(6,7,8,10)],
  exp_INV12[-c(6,7,9,10)],
  exp_INV12[-c(6,8,9,10)],
  
  exp_INV12[-c(7,8,9,10)],
  #5 vars
  #1,x
  #1,2
  exp_INV12[c(1,2,3,4,5)],exp_INV12[c(1,2,3,4,6)],exp_INV12[c(1,2,3,4,7)],exp_INV12[c(1,2,3,4,8)],exp_INV12[c(1,2,3,4,9)],exp_INV12[c(1,2,3,4,10)],
  exp_INV12[c(1,2,3,5,6)],exp_INV12[c(1,2,3,5,7)],exp_INV12[c(1,2,3,5,8)],exp_INV12[c(1,2,3,5,9)],exp_INV12[c(1,2,3,5,10)],
  exp_INV12[c(1,2,3,6,7)],exp_INV12[c(1,2,3,6,8)],exp_INV12[c(1,2,3,6,9)],exp_INV12[c(1,2,3,6,10)],
  exp_INV12[c(1,2,3,7,8)],exp_INV12[c(1,2,3,7,9)],exp_INV12[c(1,2,3,7,10)],
  exp_INV12[c(1,2,3,8,9)],exp_INV12[c(1,2,3,8,10)],
  exp_INV12[c(1,2,3,9,10)],
  
  exp_INV12[c(1,2,4,5,6)],exp_INV12[c(1,2,4,5,7)],exp_INV12[c(1,2,4,5,8)],exp_INV12[c(1,2,4,5,9)],exp_INV12[c(1,2,4,5,10)],
  exp_INV12[c(1,2,4,6,7)],exp_INV12[c(1,2,4,6,8)],exp_INV12[c(1,2,4,6,9)],exp_INV12[c(1,2,4,6,10)],
  exp_INV12[c(1,2,4,7,8)],exp_INV12[c(1,2,4,7,9)],exp_INV12[c(1,2,4,7,10)],
  exp_INV12[c(1,2,4,8,9)],exp_INV12[c(1,2,4,8,10)],
  exp_INV12[c(1,2,4,9,10)],
  
  exp_INV12[c(1,2,5,6,7)],exp_INV12[c(1,2,5,6,8)],exp_INV12[c(1,2,5,6,9)],exp_INV12[c(1,2,5,6,10)],
  exp_INV12[c(1,2,5,7,8)],exp_INV12[c(1,2,5,7,9)],exp_INV12[c(1,2,5,7,10)],
  exp_INV12[c(1,2,5,8,9)],exp_INV12[c(1,2,5,8,10)],
  exp_INV12[c(1,2,5,9,10)],
  
  exp_INV12[c(1,2,6,7,8)],exp_INV12[c(1,2,6,7,9)],exp_INV12[c(1,2,6,7,10)],
  exp_INV12[c(1,2,6,8,9)],exp_INV12[c(1,2,6,8,10)],
  exp_INV12[c(1,2,6,9,10)],
  
  exp_INV12[c(1,2,7,8,9)],exp_INV12[c(1,2,7,8,10)],
  exp_INV12[c(1,2,7,9,10)],
  
  exp_INV12[c(1,2,8,9,10)],
  
  #1,3
  exp_INV12[c(1,3,4,5,6)],exp_INV12[c(1,3,4,5,7)],exp_INV12[c(1,3,4,5,8)],exp_INV12[c(1,3,4,5,9)],exp_INV12[c(1,3,4,5,10)],
  exp_INV12[c(1,3,4,6,7)],exp_INV12[c(1,3,4,6,8)],exp_INV12[c(1,3,4,6,9)],exp_INV12[c(1,3,4,6,10)],
  exp_INV12[c(1,3,4,7,8)],exp_INV12[c(1,3,4,7,9)],exp_INV12[c(1,3,4,7,10)],
  exp_INV12[c(1,3,4,8,9)],exp_INV12[c(1,3,4,8,10)],
  exp_INV12[c(1,3,4,9,10)],
  
  exp_INV12[c(1,3,5,6,7)],exp_INV12[c(1,3,5,6,8)],exp_INV12[c(1,3,5,6,9)],exp_INV12[c(1,3,5,6,10)],
  exp_INV12[c(1,3,5,7,8)],exp_INV12[c(1,3,5,7,9)],exp_INV12[c(1,3,5,7,10)],
  exp_INV12[c(1,3,5,8,9)],exp_INV12[c(1,3,5,8,10)],
  exp_INV12[c(1,3,5,9,10)],
  
  exp_INV12[c(1,3,6,7,8)],exp_INV12[c(1,3,6,7,9)],exp_INV12[c(1,3,6,7,10)],
  exp_INV12[c(1,3,6,8,9)],exp_INV12[c(1,3,6,8,10)],
  exp_INV12[c(1,3,6,9,10)],
  
  exp_INV12[c(1,3,7,8,9)],exp_INV12[c(1,3,7,8,10)],
  exp_INV12[c(1,3,7,9,10)],
  
  exp_INV12[c(1,3,8,9,10)],
  
  #1,4
  exp_INV12[c(1,4,5,6,7)],exp_INV12[c(1,4,5,6,8)],exp_INV12[c(1,4,5,6,9)],exp_INV12[c(1,4,5,6,10)],
  exp_INV12[c(1,4,5,7,8)],exp_INV12[c(1,4,5,7,9)],exp_INV12[c(1,4,5,7,10)],
  exp_INV12[c(1,4,5,8,9)],exp_INV12[c(1,4,5,8,10)],
  exp_INV12[c(1,4,5,9,10)],
  
  exp_INV12[c(1,4,6,7,8)],exp_INV12[c(1,4,6,7,9)],exp_INV12[c(1,4,6,7,10)],
  exp_INV12[c(1,4,6,8,9)],exp_INV12[c(1,4,6,8,10)],
  exp_INV12[c(1,4,6,9,10)],
  
  exp_INV12[c(1,4,7,8,9)],exp_INV12[c(1,4,7,8,10)],
  exp_INV12[c(1,4,7,9,10)],
  
  exp_INV12[c(1,4,8,9,10)],
  
  #1,5
  exp_INV12[c(1,5,6,7,8)],exp_INV12[c(1,5,6,7,9)],exp_INV12[c(1,5,6,7,10)],
  exp_INV12[c(1,5,6,8,9)],exp_INV12[c(1,5,6,8,10)],
  exp_INV12[c(1,5,6,9,10)],
  
  exp_INV12[c(1,5,7,8,9)],exp_INV12[c(1,5,7,8,10)],
  exp_INV12[c(1,5,7,9,10)],
  
  exp_INV12[c(1,5,8,9,10)],
  
  #1,6
  exp_INV12[c(1,6,7,8,9)],exp_INV12[c(1,6,7,8,10)],
  exp_INV12[c(1,6,7,9,10)],
  
  exp_INV12[c(1,6,8,9,10)],
  
  #1,7
  exp_INV12[c(1,7,8,9,10)],
  
  
  #2,x
  #2,3
  exp_INV12[c(2,3,4,5,6)],exp_INV12[c(2,3,4,5,7)],exp_INV12[c(2,3,4,5,8)],exp_INV12[c(2,3,4,5,9)],exp_INV12[c(2,3,4,5,10)],
  exp_INV12[c(2,3,4,6,7)],exp_INV12[c(2,3,4,6,8)],exp_INV12[c(2,3,4,6,9)],exp_INV12[c(2,3,4,6,10)],
  exp_INV12[c(2,3,4,7,8)],exp_INV12[c(2,3,4,7,9)],exp_INV12[c(2,3,4,7,10)],
  exp_INV12[c(2,3,4,8,9)],exp_INV12[c(2,3,4,8,10)],
  exp_INV12[c(2,3,4,9,10)],
  
  exp_INV12[c(2,3,5,6,7)],exp_INV12[c(2,3,5,6,8)],exp_INV12[c(2,3,5,6,9)],exp_INV12[c(2,3,5,6,10)],
  exp_INV12[c(2,3,5,7,8)],exp_INV12[c(2,3,5,7,9)],exp_INV12[c(2,3,5,7,10)],
  exp_INV12[c(2,3,5,8,9)],exp_INV12[c(2,3,5,8,10)],
  exp_INV12[c(2,3,5,9,10)],
  
  exp_INV12[c(2,3,6,7,8)],exp_INV12[c(2,3,6,7,9)],exp_INV12[c(2,3,6,7,10)],
  exp_INV12[c(2,3,6,8,9)],exp_INV12[c(2,3,6,8,10)],
  exp_INV12[c(2,3,6,9,10)],
  
  exp_INV12[c(2,3,7,8,9)],exp_INV12[c(2,3,7,8,10)],
  exp_INV12[c(2,3,7,9,10)],
  
  exp_INV12[c(2,3,8,9,10)],
  
  #2,4
  exp_INV12[c(2,4,5,6,7)],exp_INV12[c(2,4,5,6,8)],exp_INV12[c(2,4,5,6,9)],exp_INV12[c(2,4,5,6,10)],
  exp_INV12[c(2,4,5,7,8)],exp_INV12[c(2,4,5,7,9)],exp_INV12[c(2,4,5,7,10)],
  exp_INV12[c(2,4,5,8,9)],exp_INV12[c(2,4,5,8,10)],
  exp_INV12[c(2,4,5,9,10)],
  
  exp_INV12[c(2,4,6,7,8)],exp_INV12[c(2,4,6,7,9)],exp_INV12[c(2,4,6,7,10)],
  exp_INV12[c(2,4,6,8,9)],exp_INV12[c(2,4,6,8,10)],
  exp_INV12[c(2,4,6,9,10)],
  
  exp_INV12[c(2,4,7,8,9)],exp_INV12[c(2,4,7,8,10)],
  exp_INV12[c(2,4,7,9,10)],
  
  exp_INV12[c(2,4,8,9,10)],
  
  #2,5
  exp_INV12[c(2,5,6,7,8)],exp_INV12[c(2,5,6,7,9)],exp_INV12[c(2,5,6,7,10)],
  exp_INV12[c(2,5,6,8,9)],exp_INV12[c(2,5,6,8,10)],
  exp_INV12[c(2,5,6,9,10)],
  
  exp_INV12[c(2,5,7,8,9)],exp_INV12[c(2,5,7,8,10)],
  exp_INV12[c(2,5,7,9,10)],
  
  exp_INV12[c(2,5,8,9,10)],
  
  #2,6
  exp_INV12[c(2,6,7,8,9)],exp_INV12[c(2,6,7,8,10)],
  exp_INV12[c(2,6,7,9,10)],
  
  exp_INV12[c(2,6,8,9,10)],
  
  #2,7
  exp_INV12[c(2,7,8,9,10)],
  
  #3,x
  #3,4
  exp_INV12[c(3,4,5,6,7)],exp_INV12[c(3,4,5,6,8)],exp_INV12[c(3,4,5,6,9)],exp_INV12[c(3,4,5,6,10)],
  exp_INV12[c(3,4,5,7,8)],exp_INV12[c(3,4,5,7,9)],exp_INV12[c(3,4,5,7,10)],
  exp_INV12[c(3,4,5,8,9)],exp_INV12[c(3,4,5,8,10)],
  exp_INV12[c(3,4,5,9,10)],
  
  exp_INV12[c(3,4,6,7,8)],exp_INV12[c(3,4,6,7,9)],exp_INV12[c(3,4,6,7,10)],
  exp_INV12[c(3,4,6,8,9)],exp_INV12[c(3,4,6,8,10)],
  exp_INV12[c(3,4,6,9,10)],
  
  exp_INV12[c(3,4,7,8,9)],exp_INV12[c(3,4,7,8,10)],
  exp_INV12[c(3,4,7,9,10)],
  
  exp_INV12[c(3,4,8,9,10)],
  
  #3,5
  exp_INV12[c(3,5,6,7,8)],exp_INV12[c(3,5,6,7,9)],exp_INV12[c(3,5,6,7,10)],
  exp_INV12[c(3,5,6,8,9)],exp_INV12[c(3,5,6,8,10)],
  exp_INV12[c(3,5,6,9,10)],
  
  exp_INV12[c(3,5,7,8,9)],exp_INV12[c(3,5,7,8,10)],
  exp_INV12[c(3,5,7,9,10)],
  
  exp_INV12[c(3,5,8,9,10)],
  
  #3,6
  exp_INV12[c(3,6,7,8,9)],exp_INV12[c(3,6,7,8,10)],
  exp_INV12[c(3,6,7,9,10)],
  
  exp_INV12[c(3,6,8,9,10)],
  
  #3,7
  exp_INV12[c(3,7,8,9,10)],
  
  #4,x
  #4,5
  exp_INV12[c(4,5,6,7,8)],exp_INV12[c(4,5,6,7,9)],exp_INV12[c(4,5,6,7,10)],
  exp_INV12[c(4,5,6,8,9)],exp_INV12[c(4,5,6,8,10)],
  exp_INV12[c(4,5,6,9,10)],
  
  exp_INV12[c(4,5,7,8,9)],exp_INV12[c(4,5,7,8,10)],
  exp_INV12[c(4,5,7,9,10)],
  
  exp_INV12[c(4,5,8,9,10)],
  
  #4,6
  exp_INV12[c(4,6,7,8,9)],exp_INV12[c(4,6,7,8,10)],
  exp_INV12[c(4,6,7,9,10)],
  
  exp_INV12[c(4,6,8,9,10)],
  
  #4,7
  exp_INV12[c(4,7,8,9,10)],
  
  #5,x
  #5,6
  exp_INV12[c(5,6,7,8,9)],exp_INV12[c(5,6,7,8,10)],
  exp_INV12[c(5,6,7,9,10)],
  
  exp_INV12[c(5,6,8,9,10)],
  
  #5,7
  exp_INV12[c(5,7,8,9,10)],
  
  #6,x
  #6,7
  exp_INV12[c(6,7,8,9,10)],
  
  #4 vars
  exp_INV12[c(1,2,3,4)],exp_INV12[c(1,2,3,5)],exp_INV12[c(1,2,3,6)],exp_INV12[c(1,2,3,7)],exp_INV12[c(1,2,3,8)],exp_INV12[c(1,2,3,9)],exp_INV12[c(1,2,3,10)],
  exp_INV12[c(1,2,4,5)],exp_INV12[c(1,2,4,6)],exp_INV12[c(1,2,4,7)],exp_INV12[c(1,2,4,8)],exp_INV12[c(1,2,4,9)],exp_INV12[c(1,2,4,10)],
  exp_INV12[c(1,2,5,6)],exp_INV12[c(1,2,5,7)],exp_INV12[c(1,2,5,8)],exp_INV12[c(1,2,5,9)],exp_INV12[c(1,2,5,10)],
  exp_INV12[c(1,2,6,7)],exp_INV12[c(1,2,6,8)],exp_INV12[c(1,2,6,9)],exp_INV12[c(1,2,6,10)],
  exp_INV12[c(1,2,7,8)],exp_INV12[c(1,2,7,9)],exp_INV12[c(1,2,7,10)],
  exp_INV12[c(1,2,8,9)],exp_INV12[c(1,2,8,10)],
  exp_INV12[c(1,2,9,10)],
  exp_INV12[c(1,3,4,5)],exp_INV12[c(1,3,4,6)],exp_INV12[c(1,3,4,7)],exp_INV12[c(1,3,4,8)],exp_INV12[c(1,3,4,9)],exp_INV12[c(1,3,4,10)],
  exp_INV12[c(1,3,5,6)],exp_INV12[c(1,3,5,7)],exp_INV12[c(1,3,5,8)],exp_INV12[c(1,3,5,9)],exp_INV12[c(1,3,5,10)],
  exp_INV12[c(1,3,6,7)],exp_INV12[c(1,3,6,8)],exp_INV12[c(1,3,6,9)],exp_INV12[c(1,3,6,10)],
  exp_INV12[c(1,3,7,8)],exp_INV12[c(1,3,7,9)],exp_INV12[c(1,3,7,10)],
  exp_INV12[c(1,3,8,9)],exp_INV12[c(1,3,8,10)],
  exp_INV12[c(1,3,9,10)],
  exp_INV12[c(1,4,5,6)],exp_INV12[c(1,4,5,7)],exp_INV12[c(1,4,5,8)],exp_INV12[c(1,4,5,9)],exp_INV12[c(1,4,5,10)],
  exp_INV12[c(1,4,6,7)],exp_INV12[c(1,4,6,8)],exp_INV12[c(1,4,6,9)],exp_INV12[c(1,4,6,10)],
  exp_INV12[c(1,4,7,8)],exp_INV12[c(1,4,7,9)],exp_INV12[c(1,4,7,10)],
  exp_INV12[c(1,4,8,9)],exp_INV12[c(1,4,8,10)],
  exp_INV12[c(1,4,9,10)],
  exp_INV12[c(1,5,6,7)],exp_INV12[c(1,5,6,8)],exp_INV12[c(1,5,6,9)],exp_INV12[c(1,5,6,10)],
  exp_INV12[c(1,5,7,8)],exp_INV12[c(1,5,7,9)],exp_INV12[c(1,5,7,10)],
  exp_INV12[c(1,5,8,9)],exp_INV12[c(1,5,8,10)],
  exp_INV12[c(1,5,9,10)],
  exp_INV12[c(1,6,7,8)],exp_INV12[c(1,6,7,9)],exp_INV12[c(1,6,7,10)],
  exp_INV12[c(1,6,8,9)],exp_INV12[c(1,6,8,10)],
  exp_INV12[c(1,6,9,10)],
  exp_INV12[c(1,7,8,9)],exp_INV12[c(1,7,8,10)],
  exp_INV12[c(1,7,9,10)],
  exp_INV12[c(1,8,9,10)],
  
  exp_INV12[c(2,3,4,5)],exp_INV12[c(2,3,4,6)],exp_INV12[c(2,3,4,7)],exp_INV12[c(2,3,4,8)],exp_INV12[c(2,3,4,9)],exp_INV12[c(2,3,4,10)],
  exp_INV12[c(2,3,5,6)],exp_INV12[c(2,3,5,7)],exp_INV12[c(2,3,5,8)],exp_INV12[c(2,3,5,9)],exp_INV12[c(2,3,5,10)],
  exp_INV12[c(2,3,6,7)],exp_INV12[c(2,3,6,8)],exp_INV12[c(2,3,6,9)],exp_INV12[c(2,3,6,10)],
  exp_INV12[c(2,3,7,8)],exp_INV12[c(2,3,7,9)],exp_INV12[c(2,3,7,10)],
  exp_INV12[c(2,3,8,9)],exp_INV12[c(2,3,8,10)],
  exp_INV12[c(2,3,9,10)],
  exp_INV12[c(2,4,5,6)],exp_INV12[c(2,4,5,7)],exp_INV12[c(2,4,5,8)],exp_INV12[c(2,4,5,9)],exp_INV12[c(2,4,5,10)],
  exp_INV12[c(2,4,6,7)],exp_INV12[c(2,4,6,8)],exp_INV12[c(2,4,6,9)],exp_INV12[c(2,4,6,10)],
  exp_INV12[c(2,4,7,8)],exp_INV12[c(2,4,7,9)],exp_INV12[c(2,4,7,10)],
  exp_INV12[c(2,4,8,9)],exp_INV12[c(2,4,8,10)],
  exp_INV12[c(2,4,9,10)],
  exp_INV12[c(2,5,6,7)],exp_INV12[c(2,5,6,8)],exp_INV12[c(2,5,6,9)],exp_INV12[c(2,5,6,10)],
  exp_INV12[c(2,5,7,8)],exp_INV12[c(2,5,7,9)],exp_INV12[c(2,5,7,10)],
  exp_INV12[c(2,5,8,9)],exp_INV12[c(2,5,8,10)],
  exp_INV12[c(2,5,9,10)],
  exp_INV12[c(2,6,7,8)],exp_INV12[c(2,6,7,9)],exp_INV12[c(2,6,7,10)],
  exp_INV12[c(2,6,8,9)],exp_INV12[c(2,6,8,10)],
  exp_INV12[c(2,6,9,10)],
  exp_INV12[c(2,7,8,9)],exp_INV12[c(2,7,8,10)],
  exp_INV12[c(2,7,9,10)],
  exp_INV12[c(2,8,9,10)],
  
  exp_INV12[c(3,4,5,6)],exp_INV12[c(3,4,5,7)],exp_INV12[c(3,4,5,8)],exp_INV12[c(3,4,5,9)],exp_INV12[c(3,4,5,10)],
  exp_INV12[c(3,4,6,7)],exp_INV12[c(3,4,6,8)],exp_INV12[c(3,4,6,9)],exp_INV12[c(3,4,6,10)],
  exp_INV12[c(3,4,7,8)],exp_INV12[c(3,4,7,9)],exp_INV12[c(3,4,7,10)],
  exp_INV12[c(3,4,8,9)],exp_INV12[c(3,4,8,10)],
  exp_INV12[c(3,4,9,10)],
  exp_INV12[c(3,5,6,7)],exp_INV12[c(3,5,6,8)],exp_INV12[c(3,5,6,9)],exp_INV12[c(3,5,6,10)],
  exp_INV12[c(3,5,7,8)],exp_INV12[c(3,5,7,9)],exp_INV12[c(3,5,7,10)],
  exp_INV12[c(3,5,8,9)],exp_INV12[c(3,5,8,10)],
  exp_INV12[c(3,5,9,10)],
  exp_INV12[c(3,6,7,8)],exp_INV12[c(3,6,7,9)],exp_INV12[c(3,6,7,10)],
  exp_INV12[c(3,6,8,9)],exp_INV12[c(3,6,8,10)],
  exp_INV12[c(3,6,9,10)],
  exp_INV12[c(3,7,8,9)],exp_INV12[c(3,7,8,10)],
  exp_INV12[c(3,7,9,10)],
  exp_INV12[c(3,8,9,10)],
  
  exp_INV12[c(4,5,6,7)],exp_INV12[c(4,5,6,8)],exp_INV12[c(4,5,6,9)],exp_INV12[c(4,5,6,10)],
  exp_INV12[c(4,5,7,8)],exp_INV12[c(4,5,7,9)],exp_INV12[c(4,5,7,10)],
  exp_INV12[c(4,5,8,9)],exp_INV12[c(4,5,8,10)],
  exp_INV12[c(4,5,9,10)],
  exp_INV12[c(4,6,7,8)],exp_INV12[c(4,6,7,9)],exp_INV12[c(4,6,7,10)],
  exp_INV12[c(4,6,8,9)],exp_INV12[c(4,6,8,10)],
  exp_INV12[c(4,6,9,10)],
  exp_INV12[c(4,7,8,9)],exp_INV12[c(4,7,8,10)],
  exp_INV12[c(4,7,9,10)],
  exp_INV12[c(4,8,9,10)],
  
  exp_INV12[c(5,6,7,8)],exp_INV12[c(5,6,7,9)],exp_INV12[c(5,6,7,10)],
  exp_INV12[c(5,6,8,9)],exp_INV12[c(5,6,8,10)],
  exp_INV12[c(5,6,9,10)],
  exp_INV12[c(5,7,8,9)],exp_INV12[c(5,7,8,10)],
  exp_INV12[c(5,7,9,10)],
  exp_INV12[c(5,8,9,10)],
  
  exp_INV12[c(6,7,8,9)],exp_INV12[c(6,7,8,10)],
  exp_INV12[c(6,7,9,10)],
  exp_INV12[c(6,8,9,10)],
  
  exp_INV12[c(7,8,9,10)],
  
  #3 vars
  exp_INV12[c(1,2,3)],exp_INV12[c(1,2,4)],exp_INV12[c(1,2,5)],exp_INV12[c(1,2,6)],exp_INV12[c(1,2,7)],exp_INV12[c(1,2,8)],exp_INV12[c(1,2,9)],exp_INV12[c(1,2,10)],
  exp_INV12[c(1,3,4)],exp_INV12[c(1,3,5)],exp_INV12[c(1,3,6)],exp_INV12[c(1,3,7)],exp_INV12[c(1,3,8)],exp_INV12[c(1,3,9)],exp_INV12[c(1,3,10)],
  exp_INV12[c(1,4,5)],exp_INV12[c(1,4,6)],exp_INV12[c(1,4,7)],exp_INV12[c(1,4,8)],exp_INV12[c(1,4,9)],exp_INV12[c(1,4,10)],
  exp_INV12[c(1,5,6)],exp_INV12[c(1,5,7)],exp_INV12[c(1,5,8)],exp_INV12[c(1,5,9)],exp_INV12[c(1,5,10)],
  exp_INV12[c(1,6,7)],exp_INV12[c(1,6,8)],exp_INV12[c(1,6,9)],exp_INV12[c(1,6,10)],
  exp_INV12[c(1,7,8)],exp_INV12[c(1,7,9)],exp_INV12[c(1,7,10)],
  exp_INV12[c(1,8,9)],exp_INV12[c(1,8,10)],
  exp_INV12[c(1,9,10)],
  exp_INV12[c(2,3,4)],exp_INV12[c(2,3,5)],exp_INV12[c(2,3,6)],exp_INV12[c(2,3,7)],exp_INV12[c(2,3,8)],exp_INV12[c(2,3,9)],exp_INV12[c(2,3,10)],
  exp_INV12[c(2,4,5)],exp_INV12[c(2,4,6)],exp_INV12[c(2,4,7)],exp_INV12[c(2,4,8)],exp_INV12[c(2,4,9)],exp_INV12[c(2,4,10)],
  exp_INV12[c(2,5,6)],exp_INV12[c(2,5,7)],exp_INV12[c(2,5,8)],exp_INV12[c(2,5,9)],exp_INV12[c(2,5,10)],
  exp_INV12[c(2,6,7)],exp_INV12[c(2,6,8)],exp_INV12[c(2,6,9)],exp_INV12[c(2,6,10)],
  exp_INV12[c(2,7,8)],exp_INV12[c(2,7,9)],exp_INV12[c(2,7,10)],
  exp_INV12[c(2,8,9)],exp_INV12[c(2,8,10)],
  exp_INV12[c(2,9,10)],
  exp_INV12[c(3,4,5)],exp_INV12[c(3,4,6)],exp_INV12[c(3,4,7)],exp_INV12[c(3,4,8)],exp_INV12[c(3,4,9)],exp_INV12[c(3,4,10)],
  exp_INV12[c(3,5,6)],exp_INV12[c(3,5,7)],exp_INV12[c(3,5,8)],exp_INV12[c(3,5,9)],exp_INV12[c(3,5,10)],
  exp_INV12[c(3,6,7)],exp_INV12[c(3,6,8)],exp_INV12[c(3,6,9)],exp_INV12[c(3,6,10)],
  exp_INV12[c(3,7,8)],exp_INV12[c(3,7,9)],exp_INV12[c(3,7,10)],
  exp_INV12[c(3,8,9)],exp_INV12[c(3,8,10)],
  exp_INV12[c(3,9,10)],
  exp_INV12[c(4,5,6)],exp_INV12[c(4,5,7)],exp_INV12[c(4,5,8)],exp_INV12[c(4,5,9)],exp_INV12[c(4,5,10)],
  exp_INV12[c(4,6,7)],exp_INV12[c(4,6,8)],exp_INV12[c(4,6,9)],exp_INV12[c(4,6,10)],
  exp_INV12[c(4,7,8)],exp_INV12[c(4,7,9)],exp_INV12[c(4,7,10)],
  exp_INV12[c(4,8,9)],exp_INV12[c(4,8,10)],
  exp_INV12[c(4,9,10)],
  exp_INV12[c(5,6,7)],exp_INV12[c(5,6,8)],exp_INV12[c(5,6,9)],exp_INV12[c(5,6,10)],
  exp_INV12[c(5,7,8)],exp_INV12[c(5,7,9)],exp_INV12[c(5,7,10)],
  exp_INV12[c(5,8,9)],exp_INV12[c(5,8,10)],
  exp_INV12[c(5,9,10)],
  exp_INV12[c(6,7,8)],exp_INV12[c(6,7,9)],exp_INV12[c(6,7,10)],
  exp_INV12[c(6,8,9)],exp_INV12[c(6,8,10)],
  exp_INV12[c(6,9,10)],
  exp_INV12[c(7,8,9)],exp_INV12[c(7,8,10)],
  exp_INV12[c(7,9,10)],
  exp_INV12[c(8,9,10)],
  
  #2 vars
  exp_INV12[c(1,2)],exp_INV12[c(1,3)],exp_INV12[c(1,4)],exp_INV12[c(1,5)],exp_INV12[c(1,6)],exp_INV12[c(1,7)],exp_INV12[c(1,8)],exp_INV12[c(1,9)],exp_INV12[c(1,10)],
  exp_INV12[c(2,3)],exp_INV12[c(2,4)],exp_INV12[c(2,5)],exp_INV12[c(2,6)],exp_INV12[c(2,7)],exp_INV12[c(2,8)],exp_INV12[c(2,9)],exp_INV12[c(2,10)],
  exp_INV12[c(3,4)],exp_INV12[c(3,5)],exp_INV12[c(3,6)],exp_INV12[c(3,7)],exp_INV12[c(3,8)],exp_INV12[c(3,9)],exp_INV12[c(3,10)],
  exp_INV12[c(4,5)],exp_INV12[c(4,6)],exp_INV12[c(4,7)],exp_INV12[c(4,8)],exp_INV12[c(4,9)],exp_INV12[c(4,10)],
  exp_INV12[c(5,6)],exp_INV12[c(5,7)],exp_INV12[c(5,8)],exp_INV12[c(5,9)],exp_INV12[c(5,10)],
  exp_INV12[c(6,7)],exp_INV12[c(6,8)],exp_INV12[c(6,9)],exp_INV12[c(6,10)],
  exp_INV12[c(7,8)],exp_INV12[c(7,9)],exp_INV12[c(7,10)],
  exp_INV12[c(8,9)],exp_INV12[c(8,10)],
  exp_INV12[c(9,10)],
  #1 var
  exp_INV12[1],exp_INV12[2],exp_INV12[3],exp_INV12[4],exp_INV12[5],exp_INV12[6],exp_INV12[7],exp_INV12[8],exp_INV12[9],exp_INV12[10],
  #null
  c("1"))


#### Hbb1 (7) ####

exp_all_Hbb1vars <- list(
  #7
  exp_Hbb1,
  #6
  exp_Hbb1[-c(1)],exp_Hbb1[-c(2)],exp_Hbb1[-c(3)],exp_Hbb1[-c(4)],exp_Hbb1[-c(5)],exp_Hbb1[-c(6)],exp_Hbb1[-c(7)],
  #5
  exp_Hbb1[-c(1,2)],exp_Hbb1[-c(1,3)],exp_Hbb1[-c(1,4)],exp_Hbb1[-c(1,5)],exp_Hbb1[-c(1,6)],exp_Hbb1[-c(1,7)],
  exp_Hbb1[-c(2,3)],exp_Hbb1[-c(2,4)],exp_Hbb1[-c(2,5)],exp_Hbb1[-c(2,6)],exp_Hbb1[-c(2,7)],
  exp_Hbb1[-c(3,4)],exp_Hbb1[-c(3,5)],exp_Hbb1[-c(3,6)],exp_Hbb1[-c(3,7)],
  exp_Hbb1[-c(4,5)],exp_Hbb1[-c(4,6)],exp_Hbb1[-c(4,7)],
  exp_Hbb1[-c(5,6)],exp_Hbb1[-c(5,7)],
  exp_Hbb1[-c(6,7)],
  #4
  exp_Hbb1[-c(1,2,3)],exp_Hbb1[-c(1,2,4)],exp_Hbb1[-c(1,2,5)],exp_Hbb1[-c(1,2,6)],exp_Hbb1[-c(1,2,7)],
  exp_Hbb1[-c(1,3,4)],exp_Hbb1[-c(1,3,5)],exp_Hbb1[-c(1,3,6)],exp_Hbb1[-c(1,3,7)],
  exp_Hbb1[-c(1,4,5)],exp_Hbb1[-c(1,4,6)],exp_Hbb1[-c(1,4,7)],
  exp_Hbb1[-c(1,5,6)],exp_Hbb1[-c(1,5,7)],
  exp_Hbb1[-c(1,6,7)],
  exp_Hbb1[-c(2,3,4)],exp_Hbb1[-c(2,3,5)],exp_Hbb1[-c(2,3,6)],exp_Hbb1[-c(2,3,7)],
  exp_Hbb1[-c(2,4,5)],exp_Hbb1[-c(2,4,6)],exp_Hbb1[-c(2,4,7)],
  exp_Hbb1[-c(2,5,6)],exp_Hbb1[-c(2,5,7)],
  exp_Hbb1[-c(2,6,7)],
  exp_Hbb1[-c(3,4,5)],exp_Hbb1[-c(3,4,6)],exp_Hbb1[-c(3,4,7)],
  exp_Hbb1[-c(3,5,6)],exp_Hbb1[-c(3,5,7)],
  exp_Hbb1[-c(3,6,7)],
  exp_Hbb1[-c(4,5,6)],exp_Hbb1[-c(4,5,7)],
  exp_Hbb1[-c(4,6,7)],
  exp_Hbb1[-c(5,6,7)],
  #3
  exp_Hbb1[c(1,2,3)],exp_Hbb1[c(1,2,4)],exp_Hbb1[c(1,2,5)],exp_Hbb1[c(1,2,6)],exp_Hbb1[c(1,2,7)],
  exp_Hbb1[c(1,3,4)],exp_Hbb1[c(1,3,5)],exp_Hbb1[c(1,3,6)],exp_Hbb1[c(1,3,7)],
  exp_Hbb1[c(1,4,5)],exp_Hbb1[c(1,4,6)],exp_Hbb1[c(1,4,7)],
  exp_Hbb1[c(1,5,6)],exp_Hbb1[c(1,5,7)],
  exp_Hbb1[c(1,6,7)],
  exp_Hbb1[c(2,3,4)],exp_Hbb1[c(2,3,5)],exp_Hbb1[c(2,3,6)],exp_Hbb1[c(2,3,7)],
  exp_Hbb1[c(2,4,5)],exp_Hbb1[c(2,4,6)],exp_Hbb1[c(2,4,7)],
  exp_Hbb1[c(2,5,6)],exp_Hbb1[c(2,5,7)],
  exp_Hbb1[c(2,6,7)],
  exp_Hbb1[c(3,4,5)],exp_Hbb1[c(3,4,6)],exp_Hbb1[c(3,4,7)],
  exp_Hbb1[c(3,5,6)],exp_Hbb1[c(3,5,7)],
  exp_Hbb1[c(3,6,7)],
  exp_Hbb1[c(4,5,6)],exp_Hbb1[c(4,5,7)],
  exp_Hbb1[c(4,6,7)],
  exp_Hbb1[c(5,6,7)],
  #2
  exp_Hbb1[c(1,2)],exp_Hbb1[c(1,3)],exp_Hbb1[c(1,4)],exp_Hbb1[c(1,5)],exp_Hbb1[c(1,6)],exp_Hbb1[c(1,7)],
  exp_Hbb1[c(2,3)],exp_Hbb1[c(2,4)],exp_Hbb1[c(2,5)],exp_Hbb1[c(2,6)],exp_Hbb1[c(2,7)],
  exp_Hbb1[c(3,4)],exp_Hbb1[c(3,5)],exp_Hbb1[c(3,6)],exp_Hbb1[c(3,7)],
  exp_Hbb1[c(4,5)],exp_Hbb1[c(4,6)],exp_Hbb1[c(4,7)],
  exp_Hbb1[c(5,6)],exp_Hbb1[c(5,7)],
  exp_Hbb1[c(6,7)],
  #1
  exp_Hbb1[1],exp_Hbb1[2],exp_Hbb1[3],exp_Hbb1[4],exp_Hbb1[5],exp_Hbb1[6],exp_Hbb1[7],
  #null
  c("1"))

#remove rank-deficient models (otherwise problems sownstream):
exp_all_Hbb1vars_ed <- exp_all_Hbb1vars[-c(30,31,33,99,109,117,119,120,127)]

#### Hbb5 (8) ####

exp_all_Hbb5vars <- list(
  #8
  exp_Hbb5,
  #7
  exp_Hbb5[-c(1)],exp_Hbb5[-c(2)],exp_Hbb5[-c(3)],exp_Hbb5[-c(4)],exp_Hbb5[-c(5)],exp_Hbb5[-c(6)],exp_Hbb5[-c(7)],exp_Hbb5[-c(8)],
  #6
  exp_Hbb5[-c(1,2)],exp_Hbb5[-c(1,3)],exp_Hbb5[-c(1,4)],exp_Hbb5[-c(1,5)],exp_Hbb5[-c(1,6)],exp_Hbb5[-c(1,7)],exp_Hbb5[-c(1,8)],
  exp_Hbb5[-c(2,3)],exp_Hbb5[-c(2,4)],exp_Hbb5[-c(2,5)],exp_Hbb5[-c(2,6)],exp_Hbb5[-c(2,7)],exp_Hbb5[-c(2,8)],
  exp_Hbb5[-c(3,4)],exp_Hbb5[-c(3,5)],exp_Hbb5[-c(3,6)],exp_Hbb5[-c(3,7)],exp_Hbb5[-c(3,8)],
  exp_Hbb5[-c(4,5)],exp_Hbb5[-c(4,6)],exp_Hbb5[-c(4,7)],exp_Hbb5[-c(4,8)],
  exp_Hbb5[-c(5,6)],exp_Hbb5[-c(5,7)],exp_Hbb5[-c(5,8)],
  exp_Hbb5[-c(6,7)],exp_Hbb5[-c(6,8)],
  exp_Hbb5[-c(7,8)],
  #5
  exp_Hbb5[-c(1,2,3)],exp_Hbb5[-c(1,2,4)],exp_Hbb5[-c(1,2,5)],exp_Hbb5[-c(1,2,6)],exp_Hbb5[-c(1,2,7)],exp_Hbb5[-c(1,2,8)],
  exp_Hbb5[-c(1,3,4)],exp_Hbb5[-c(1,3,5)],exp_Hbb5[-c(1,3,6)],exp_Hbb5[-c(1,3,7)],exp_Hbb5[-c(1,3,8)],
  exp_Hbb5[-c(1,4,5)],exp_Hbb5[-c(1,4,6)],exp_Hbb5[-c(1,4,7)],exp_Hbb5[-c(1,4,8)],
  exp_Hbb5[-c(1,5,6)],exp_Hbb5[-c(1,5,7)],exp_Hbb5[-c(1,5,8)],
  exp_Hbb5[-c(1,6,7)],exp_Hbb5[-c(1,6,8)],
  exp_Hbb5[-c(1,7,8)],
  exp_Hbb5[-c(2,3,4)],exp_Hbb5[-c(2,3,5)],exp_Hbb5[-c(2,3,6)],exp_Hbb5[-c(2,3,7)],exp_Hbb5[-c(2,3,8)],
  exp_Hbb5[-c(2,4,5)],exp_Hbb5[-c(2,4,6)],exp_Hbb5[-c(2,4,7)],exp_Hbb5[-c(2,4,8)],
  exp_Hbb5[-c(2,5,6)],exp_Hbb5[-c(2,5,7)],exp_Hbb5[-c(2,5,8)],
  exp_Hbb5[-c(2,6,7)],exp_Hbb5[-c(2,6,8)],
  exp_Hbb5[-c(2,7,8)],
  exp_Hbb5[-c(3,4,5)],exp_Hbb5[-c(3,4,6)],exp_Hbb5[-c(3,4,7)],exp_Hbb5[-c(3,4,8)],
  exp_Hbb5[-c(3,5,6)],exp_Hbb5[-c(3,5,7)],exp_Hbb5[-c(3,5,8)],
  exp_Hbb5[-c(3,6,7)],exp_Hbb5[-c(3,6,8)],
  exp_Hbb5[-c(3,7,8)],
  exp_Hbb5[-c(4,5,6)],exp_Hbb5[-c(4,5,7)],exp_Hbb5[-c(4,5,8)],
  exp_Hbb5[-c(4,6,7)],exp_Hbb5[-c(4,6,8)],
  exp_Hbb5[-c(4,7,8)],
  exp_Hbb5[-c(5,6,7)],exp_Hbb5[-c(5,6,8)],
  exp_Hbb5[-c(5,7,8)],
  exp_Hbb5[-c(6,7,8)],
  #4
  exp_Hbb5[c(1,2,3,4)],exp_Hbb5[c(1,2,3,5)],exp_Hbb5[c(1,2,3,6)],exp_Hbb5[c(1,2,3,7)],exp_Hbb5[c(1,2,3,8)],
  exp_Hbb5[c(1,2,4,5)],exp_Hbb5[c(1,2,4,6)],exp_Hbb5[c(1,2,4,7)],exp_Hbb5[c(1,2,4,8)],
  exp_Hbb5[c(1,2,5,6)],exp_Hbb5[c(1,2,5,7)],exp_Hbb5[c(1,2,5,8)],
  exp_Hbb5[c(1,2,6,7)],exp_Hbb5[c(1,2,6,8)],
  exp_Hbb5[c(1,2,7,8)],
  exp_Hbb5[c(1,3,4,5)],exp_Hbb5[c(1,3,4,6)],exp_Hbb5[c(1,3,4,7)],exp_Hbb5[c(1,3,4,8)],
  exp_Hbb5[c(1,3,5,6)],exp_Hbb5[c(1,3,5,7)],exp_Hbb5[c(1,3,5,8)],
  exp_Hbb5[c(1,3,6,7)],exp_Hbb5[c(1,3,6,8)],
  exp_Hbb5[c(1,3,7,8)],
  exp_Hbb5[c(1,4,5,6)],exp_Hbb5[c(1,4,5,7)],exp_Hbb5[c(1,4,5,8)],
  exp_Hbb5[c(1,4,6,7)],exp_Hbb5[c(1,4,6,8)],
  exp_Hbb5[c(1,4,7,8)],
  exp_Hbb5[c(1,5,6,7)],exp_Hbb5[c(1,5,6,8)],
  exp_Hbb5[c(1,5,7,8)],
  exp_Hbb5[c(1,6,7,8)],
  
  exp_Hbb5[c(2,3,4,5)],exp_Hbb5[c(2,3,4,6)],exp_Hbb5[c(2,3,4,7)],exp_Hbb5[c(2,3,4,8)],
  exp_Hbb5[c(2,3,5,6)],exp_Hbb5[c(2,3,5,7)],exp_Hbb5[c(2,3,5,8)],
  exp_Hbb5[c(2,3,6,7)],exp_Hbb5[c(2,3,6,8)],
  exp_Hbb5[c(2,3,7,8)],
  exp_Hbb5[c(2,4,5,6)],exp_Hbb5[c(2,4,5,7)],exp_Hbb5[c(2,4,5,8)],
  exp_Hbb5[c(2,4,6,7)],exp_Hbb5[c(2,4,6,8)],
  exp_Hbb5[c(2,4,7,8)],
  exp_Hbb5[c(2,5,6,7)],exp_Hbb5[c(2,5,6,8)],
  exp_Hbb5[c(2,5,7,8)],
  exp_Hbb5[c(2,6,7,8)],
  
  exp_Hbb5[c(3,4,5,6)],exp_Hbb5[c(3,4,5,7)],exp_Hbb5[c(3,4,5,8)],
  exp_Hbb5[c(3,4,6,7)],exp_Hbb5[c(3,4,6,8)],
  exp_Hbb5[c(3,4,7,8)],
  exp_Hbb5[c(3,5,6,7)],exp_Hbb5[c(3,5,6,8)],
  exp_Hbb5[c(3,5,7,8)],
  exp_Hbb5[c(3,6,7,8)],
  
  exp_Hbb5[c(4,5,6,7)],exp_Hbb5[c(4,5,6,8)],
  exp_Hbb5[c(4,5,7,8)],
  exp_Hbb5[c(4,6,7,8)],
  
  exp_Hbb5[c(5,6,7,8)],
  #3
  exp_Hbb5[c(1,2,3)],exp_Hbb5[c(1,2,4)],exp_Hbb5[c(1,2,5)],exp_Hbb5[c(1,2,6)],exp_Hbb5[c(1,2,7)],exp_Hbb5[c(1,2,8)],
  exp_Hbb5[c(1,3,4)],exp_Hbb5[c(1,3,5)],exp_Hbb5[c(1,3,6)],exp_Hbb5[c(1,3,7)],exp_Hbb5[c(1,3,8)],
  exp_Hbb5[c(1,4,5)],exp_Hbb5[c(1,4,6)],exp_Hbb5[c(1,4,7)],exp_Hbb5[c(1,4,8)],
  exp_Hbb5[c(1,5,6)],exp_Hbb5[c(1,5,7)],exp_Hbb5[c(1,5,8)],
  exp_Hbb5[c(1,6,7)],exp_Hbb5[c(1,6,8)],
  exp_Hbb5[c(1,7,8)],
  exp_Hbb5[c(2,3,4)],exp_Hbb5[c(2,3,5)],exp_Hbb5[c(2,3,6)],exp_Hbb5[c(2,3,7)],exp_Hbb5[c(2,3,8)],
  exp_Hbb5[c(2,4,5)],exp_Hbb5[c(2,4,6)],exp_Hbb5[c(2,4,7)],exp_Hbb5[c(2,4,8)],
  exp_Hbb5[c(2,5,6)],exp_Hbb5[c(2,5,7)],exp_Hbb5[c(2,5,8)],
  exp_Hbb5[c(2,6,7)],exp_Hbb5[c(2,6,8)],
  exp_Hbb5[c(2,7,8)],
  exp_Hbb5[c(3,4,5)],exp_Hbb5[c(3,4,6)],exp_Hbb5[c(3,4,7)],exp_Hbb5[c(3,4,8)],
  exp_Hbb5[c(3,5,6)],exp_Hbb5[c(3,5,7)],exp_Hbb5[c(3,5,8)],
  exp_Hbb5[c(3,6,7)],exp_Hbb5[c(3,6,8)],
  exp_Hbb5[c(3,7,8)],
  exp_Hbb5[c(4,5,6)],exp_Hbb5[c(4,5,7)],exp_Hbb5[c(4,5,8)],
  exp_Hbb5[c(4,6,7)],exp_Hbb5[c(4,6,8)],
  exp_Hbb5[c(4,7,8)],
  exp_Hbb5[c(5,6,7)],exp_Hbb5[c(5,6,8)],
  exp_Hbb5[c(5,7,8)],
  exp_Hbb5[c(6,7,8)],
  #2
  exp_Hbb5[c(1,2)],exp_Hbb5[c(1,3)],exp_Hbb5[c(1,4)],exp_Hbb5[c(1,5)],exp_Hbb5[c(1,6)],exp_Hbb5[c(1,7)],exp_Hbb5[c(1,8)],
  exp_Hbb5[c(2,3)],exp_Hbb5[c(2,4)],exp_Hbb5[c(2,5)],exp_Hbb5[c(2,6)],exp_Hbb5[c(2,7)],exp_Hbb5[c(2,8)],
  exp_Hbb5[c(3,4)],exp_Hbb5[c(3,5)],exp_Hbb5[c(3,6)],exp_Hbb5[c(3,7)],exp_Hbb5[c(3,8)],
  exp_Hbb5[c(4,5)],exp_Hbb5[c(4,6)],exp_Hbb5[c(4,7)],exp_Hbb5[c(4,8)],
  exp_Hbb5[c(5,6)],exp_Hbb5[c(5,7)],exp_Hbb5[c(5,8)],
  exp_Hbb5[c(6,7)],exp_Hbb5[c(6,8)],
  exp_Hbb5[c(7,8)],
  #1
  exp_Hbb5[1],exp_Hbb5[2],exp_Hbb5[3],exp_Hbb5[4],exp_Hbb5[5],exp_Hbb5[6],exp_Hbb5[7],exp_Hbb5[8],
  #null
  c("1"))

#### Run the models ####

model_comp_INV02 <- olm_comps(data = data_INV02, 
                              explans = exp_noint_all_vars,
                              respon = "INV02")

model_comp_INV07 <- olm_comps(data = meta_juv0, 
                              explans = exp_all_INV07vars,
                              respon = "INV07")

model_comp_INV12 <- olm_comps(data = data_INV12, 
                              explans = exp_all_INV12vars,
                              respon = "INV12")
#warnings: a number of rank-deficient models -> some coefs are dropped -> multiple synonymous models
#This we will consider later in the AIC_vif_filt function

model_comp_Hba4 <- olm_comps(data = data_Hba4, 
                             explans = exp_noint_all_vars,
                             respon = "Hba4")

model_comp_Hbb1 <- olm_comps(data = data_Hbb1, 
                             explans = exp_all_Hbb1vars_ed,
                             respon = "Hbb1")
#rank deficiency if all models are included (exp_all_Hbb1vars). a few models removed manually in "exp_all_Hbb1vars_ed"
#warnings: rank-deficiency, similar as INV12

model_comp_Hbb5 <- olm_comps(data = data_Hbb5, 
                             explans = exp_all_Hbb5vars,
                             respon = "Hbb5")

#view output
model_comp_INV02 %>% view # examine the results
model_comp_INV07 %>% view # examine the results
model_comp_INV12 %>% view # examine the results
model_comp_Hba4 %>% view # examine the results
model_comp_Hbb1 %>% view # examine the results
model_comp_Hbb5 %>% view # examine the results
model_comp_LG16a %>% view # examine the results
model_comp_LG16b %>% view # examine the results
model_comp_LG16c %>% view # examine the results

#make AIC tables
AIC_table_INV02 <- model_comp_INV02 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
AIC_table_INV07 <- model_comp_INV07 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
AIC_table_INV12 <- model_comp_INV12 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
AIC_table_Hba4 <- model_comp_Hba4 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
AIC_table_Hbb1 <- model_comp_Hbb1 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)
AIC_table_Hbb5 <- model_comp_Hbb5 %>% group_by(Model,Accuracy,BIC,AIC,AICc,dAICc) %>% summarise %>% arrange(dAICc)

### check assumptions for output models: ####
#check multicollinearity problems with VIF:

#calculate VIF for each model by transforming polr to lm with as.numeric response
vif_olm <- function(AIC_table,data){
  vif_out <- list()
  for(i in c(1:nrow(AIC_table))){
    x <- strsplit(AIC_table$Model[i]," ")[[1]]
    a <- alias(lm(paste("as.numeric(",x[1],") ",
                        str_c(x[-1],collapse=" "),sep=""),
                  data=data))
    ifelse("Complete" %in% names(a),vif_out[[i]] <- "aliased coefficients in the model", #if aliased coefficients exist, the alias() output will have a column named "Complete"
           ifelse(length(x)==3,vif_out[[i]] <- NA, #NA if only one predictor in the model
                  vif_out[[i]] <- vif(lm(paste("as.numeric(",x[1],") ", #else
                                               str_c(x[-1],collapse=" "),sep=""),
                                         data=data))  )     )
  }
  vif_out
}

vif_INV02 <- vif_olm(AIC_table_INV02,data_INV02)
vif_INV07 <- vif_olm(AIC_table_INV07,meta_juv0)
vif_INV12 <- vif_olm(AIC_table_INV12,data_INV12)
vif_Hba4 <- vif_olm(AIC_table_Hba4,data_Hba4)
vif_Hbb1 <- vif_olm(AIC_table_Hbb1,data_Hbb1) #error solved
vif_Hbb5 <- vif_olm(AIC_table_Hbb5,data_Hbb5)

#filter out models containing coefs with VIF>2 (strict!)
AIC_vif_olm_filt <- function(marker){ #"NO" if any predictor in the model has VIF>2 (strict!!!)
  filter_vif <- character()
  dc <- character()
  for(i in 1:length(get(paste("vif_",marker,sep="")))){
    dc[i] <- data.class(get(paste("vif_",marker,sep=""))[[i]])
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="character"){filter_vif[i] <- "NO"} #models w aliased coefs
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="logical"){filter_vif[i] <- "OK"} #shorthand for null values generated in vif_olm bc only one predictor in model
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="numeric"){ifelse(TRUE %in% c(get(paste("vif_",marker,sep=""))[[i]]>2),filter_vif[i] <- "NO",filter_vif[i] <- "OK")}
    if(data.class(get(paste("vif_",marker,sep=""))[[i]])=="matrix"){ifelse(TRUE %in% c(get(paste("vif_",marker,sep=""))[[i]][,"GVIF"] %>% as.numeric >2),filter_vif[i] <- "NO",filter_vif[i] <- "OK")}
  }
  dc
  filter_vif
  data.frame(dc,filter_vif) #why OK/NO
  
  AIC_table <- get(paste("AIC_table_",marker,sep=""))[filter_vif=="OK",] %>% arrange(AICc)
  AIC_table$dAICc <- AIC_table$AICc-AIC_table$AICc[1]
  AIC_table
}

AIC_table_INV02_vif <- AIC_vif_olm_filt("INV02")
AIC_table_INV07_vif <- AIC_vif_olm_filt("INV07")
AIC_table_INV12_vif <- AIC_vif_olm_filt("INV12") #a lot of collinear models filtered out
AIC_table_Hba4_vif <- AIC_vif_olm_filt("Hba4")
AIC_table_Hbb1_vif <- AIC_vif_olm_filt("Hbb1")
AIC_table_Hbb5_vif <- AIC_vif_olm_filt("Hbb5")

#check assumption 4: parallel regression
#brant test function:
AIC_brant_filt <- function(AIC_table_vif,data){
  test <- list()
  brant_filt <- character()
  for(i in 1:nrow(AIC_table_vif)){
    olm <- polr(AIC_table_vif$Model[i],data=data)
    ifelse(strsplit(AIC_table_vif$Model[i]," ")[[1]][3]=="1", #IF INTERCEPT ONLY
           test[[i]] <- "INTERCEPT ONLY", 
           test[[i]] <- brant::brant(olm))
    ifelse(test[[i]]=="INTERCEPT ONLY",brant_filt[i] <- "OK",
           ifelse(test[[i]][1,3]>=0.05,brant_filt[i] <- "OK",brant_filt[i] <- "NO"))
    
  }
  AIC_brant <- AIC_table_vif[brant_filt=="OK",]  
}

#perform Brant test
AIC_table_INV02_vif_brant <- AIC_brant_filt(AIC_table_INV02_vif,data_INV02)
AIC_table_INV07_vif_brant <- AIC_brant_filt(AIC_table_INV07_vif,meta_juv0)
AIC_table_INV12_vif_brant <- AIC_brant_filt(AIC_table_INV12_vif,data_INV12)
AIC_table_Hba4_vif_brant <- AIC_brant_filt(AIC_table_Hba4_vif,data_Hba4)
AIC_table_Hbb1_vif_brant <- AIC_brant_filt(AIC_table_Hbb1_vif,data_Hbb1)
AIC_table_Hbb5_vif_brant <- AIC_brant_filt(AIC_table_Hbb5_vif,data_Hbb5)
# all N.S.

#remove redundant models
x <- AIC_table_Hbb5_vif_brant
# x <- filter(x,remove!="x")
x$redundant <- character(nrow(x))
for(i in 1:nrow(x)){
  if(i==1){ifelse(round(x$AICc[i],3)==round(x$AICc[i+1],3),
                  x$redundant[i] <- "Below",x$redundant[i] <- "FALSE")
    }
  if(i==nrow(x)){ifelse(round(x$AICc[i],3)==round(x$AICc[i-1],3),
                        x$redundant[i] <- "Above",x$redundant[i] <- "FALSE")
    }
  if(i %notin% c(1,nrow(x))){ifelse(round(x$AICc[i],3)==round(x$AICc[i+1],3),x$redundant[i]<- "Below",
                                    ifelse(round(x$AICc[i],3)==round(x$AICc[i-1],3),x$redundant[i]<-"Above",x$redundant[i] <- "FALSE"))
  }
}
data.frame(x[,c(1,7)],n=1:nrow(x)) %>% view

x$remove <- character(nrow(x))
for(i in 1:nrow(x)){
  if(i %in% c(2,6,9,14,18,25,29,34,38,48,59,65)){x$remove[i] <- "x" }
}
x[,c(1,8,7)] %>% view


#go through manually to identify the models with redundant variables
AIC_table_INV02_final <- AIC_table_INV02_vif_brant
AIC_table_INV07_final <- AIC_table_INV07_vif_brant[-c(2:4,5,9,10,12,14,15,16,18,20,23,26,31,34,36,37,39,42,43,45,51,52,54,61,63,64,67,71,75,78,80,82,85,88,95,97,100,102,109,112,118,120,123,126,127,130,133,134,138,139,143,148,152,154,159,163),]
AIC_table_INV12_final <- AIC_table_INV12_vif_brant[-c(5,14,21,22,34,36,43,51,55,61,67,72,145,151,154,158,171,176,177,180),]
AIC_table_Hba4_final <- AIC_table_Hba4_vif_brant
AIC_table_Hbb1_final <- AIC_table_Hbb1_vif_brant[-c(3,4,13,14,17,18,20,21,28,29,37,38,44,45,46,48,49,50,52,54,55,57,58,59,61,63,73,74),]
AIC_table_Hbb5_final <- AIC_table_Hbb5_vif_brant[-c(2,6,9,14,18,25,29,34,38,48,59,65),]

## Summary, results ####
### Table 1B, S9: INV02 ####
AIC_table_INV02_final %>% view
# simplest top model (STM): dist+Eco
# dist and eco included in all 4 top models (dAICc < 2)
# Eco included in all top 24 models, eco only has dAICc = 2.54
# sharp increase in dAICc from 5.1 to 21.6 when eco is dropped from the predictor

model_comp_INV02_final <- filter(model_comp_INV02,Model %in% AIC_table_INV02_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_INV02_final[,c(1:3,7,9,13)] %>% view 
# eco and dist are the only exp vars w significant effects among top models

# conclusion: ecotype appears to be the strongest predictor of genotype

### Table 1C, S10: INV07 ####
AIC_table_INV07_final %>% view 
# STM: log.depth:eco (model #4)
# 6 top models (dAICc < 2)
# log.depth included in all top 57 models
# depth:eco in all top 4 models

model_comp_INV07_final <- filter(model_comp_INV07,Model %in% AIC_table_INV07_final$Model)%>% mutate(dAICc=AICc-AICc[1])
model_comp_INV07_final[,c(1:3,7,9,13)] %>% view 
# if we interpret the depth:eco interaction, it appears log odds decreases with 
# depth in both ecotypes, but the effect is smaller and less sign in the 
# coastal ecotype

# conclusion: the main predictor appears to be depth, but depth may have an 
# effect of different magnitude in the two ecotypes

### Table 1D, S11: INV12 ####
AIC_table_INV12_final %>% view 
# STM: Dist_baseline_km + log.Depth_m:Eco(dAIC=1.4687575)
# 8 top models
# depth, eco and dist in different combs in all top 18 models (dAICc = 3.3)
# depth and eco in all top 34 models (dAICc = 4.6940919)
# eco in all top 108 models
# depth:eco best one-term model (dAICc = 3.48)

model_comp_INV12_final <- filter(model_comp_INV12,Model %in% AIC_table_INV12_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_INV12_final[,c(1:3,7,9,13)] %>% view 
# it appears the effect of depth is neg in offshore ecotype and pos in coastal across the board
# in general: dist has pos effect, depth neg (if single or in eco1)/pos (in eco2),eco2 pos
# conclusion: both ecotype and geography appear to influence INV12
# in line with Barth et al 2019, may be involved in the adaptation to coastal env

### Table S12: Hba4 ####
AIC_table_Hba4_final %>% view
# STM: Eco
# 7 top models
# eco involved in all 8 top models
# eco only one of the top models (model #2)
model_comp_Hba4_final <- filter(model_comp_Hba4,Model %in% AIC_table_Hba4_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_Hba4_final[,c(1:3,7,9,13)] %>% view 
# in the other top models, all other predictors are N.S., only eco is sign.
# conclusion: eco is the main predictor, no geographical pattern observed

### Table S13: Hbb1 ####
AIC_table_Hbb1_final %>% view 
# STM: eco
# 9 top models
# Eco in all top 30 models
model_comp_Hbb1_final <- filter(model_comp_Hbb1,Model %in% AIC_table_Hbb1_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_Hbb1_final[,c(1:3,7,9,13)] %>% view 
# eco is also the only predictor that is consistently significant in other top models including more predictors
# conclusion:  eco main predictor, no geographical pattern observed

### Table S14: Hbb5 ####
AIC_table_Hbb5_final %>% view
# STM: depth:eco OR eco
# eco included in all top 83 models
# depth:eco also very frequent in top models

model_comp_Hbb5_final <- filter(model_comp_Hbb5,Model %in% AIC_table_Hbb5_final$Model) %>% mutate(dAICc=AICc-AICc[1])
model_comp_Hbb5_final[,c(1:3,7,9,13)] %>% view 
# eco the only predictor consistently sign., also depth:eco2 sign
# both have negative effects
# depth:eco1 smaller neg effect than depth:eco2
# conclusion: appears to be an effect of ecotype, and potentially an effect of depth that is more neg in eco2

### plot predictions ####

#INV02

AIC_table_INV02_final$Model[1] #Dist+eco
model_comp_INV02_final %>% head
x <- predict(polr(AIC_table_INV02_final$Model[1],data=data_INV02),type="p")
yi02 <- data.frame(x,af1=x[,1]+x[,2]/2,af2=x[,3]+x[,2]/2,data_INV02[,c("Dist_baseline_km","Depth_m","log.Depth_m","Eco")])
#mp_i2 <-
ggplot()+
  # geom_point(data=yi02,mapping=aes(x=Dist_baseline_km,y=af1,col=Eco),shape=15)+
  geom_line(data=yi02,mapping=aes(x=Dist_baseline_km,y=af1,col=Eco),size=1)+
  ylim(c(0,1))+theme_classic()+ylab("Ancestral allele frequency")+
  scale_color_manual(values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"),name="Ecotype")+
  ggtitle("Model #1: INV02 ~ Dist_baseline_km + Eco") 
#allele 1 (ancestral(?), more common in coastal) increases w inshore distance
# ggsave("Figures/INV02_model1_Dist_eco.png",dpi=300,scale=1)

#INV07
AIC_table_INV07_final$Model[1]
model_comp_INV07_final[c(1:20),]
model_comp_INV07_final %>% view
AIC_table_INV07_final$Model[8]
model_comp_INV07_final[c(46:49),]
x <- predict(polr(AIC_table_INV07_final$Model[8],data=meta_juv0),type="p")
yi07 <- data.frame(x,af1=x[,1]+x[,2]/2,af2=x[,3]+x[,2]/2,meta_juv0[,c("Dist_baseline_km","Depth_m","log.Depth_m","Eco","Subdiv")])
#mp_i7 <-
ggplot()+
  # geom_point(data=yi07,mapping=aes(x=Depth_m,y=af2,col=Eco),shape=15)+
  geom_line(data=yi07,mapping=aes(x=log(Depth_m),y=af2,col=Eco),size=1)+
  ylim(c(0,1))+theme_classic()+ylab("Ancestral allele frequency")+
  scale_color_manual(values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"),name="Ecotype")+
  ggtitle("Model #4: INV07 ~ log.Depth_m:Eco") 
#allele 2 (ancestral(?), more common in coastal) decreases w depth
# ggsave("Figures/INV07_model4_logdepth-eco.png",dpi=300,scale=1)

#INV12
# AIC_table_INV12_final[c(1:23),] %>% view
AIC_table_INV12_final$Model[6] #INV12 ~ Dist_baseline_km + log.Depth_m:Eco
AIC_table_INV12_final$Model[23] #INV12 ~ log.Depth_m:Eco - use this one for plot
model_comp_INV12_final[c(28:32),]
x <- predict(polr(AIC_table_INV12_final$Model[23],data=data_INV12),type="p")
yi12 <- data.frame(x,af1=x[,1]+x[,2]/2,af2=x[,3]+x[,2]/2,data_INV12[,c("Dist_baseline_km","Depth_m","log.Depth_m","Eco")])
#mp_i12 <-
ggplot()+
  # geom_point(data=yi12,mapping=aes(x=Depth_m,y=af1,col=Eco),shape=15)+
  geom_line(data=yi12,mapping=aes(x=log(Depth_m),y=af1,col=Eco),size=1)+
  ylim(c(0,1))+theme_classic()+ylab("Ancestral allele frequency")+
  scale_color_manual(values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"),name="Ecotype")+
  ggtitle("Model #19: INV12 ~ log.Depth_m:Eco") 
#allele 1 (ancestral(?), common in offshore, uncommon in coastal)
#af1 increases sharply with depth, but only in offshore ecotype
# ggsave("Figures/INV12_model19_logdepth-eco.png",dpi=300,scale=1)

#invs together:
ggarrange(mp_i2,mp_i7,mp_i12,
          ncol=2,nrow=2,labels="AUTO",common.legend = T,legend="")

#Hbb5
AIC_table_Hbb5_final$Model[3] #model 8 (eco only) is also top
model_comp_Hbb5_final[c(9:12),]
x <- predict(polr(AIC_table_Hbb5_final$Model[3],data=data_Hbb5),type="p")
y <- data.frame(x,af1=x[,1]+x[,2]/2,af2=x[,3]+x[,2]/2,data_Hbb5[,c("Dist_baseline_km","Depth_m","log.Depth_m","Eco")])
ggplot()+
  geom_point(data=y,mapping=aes(x=log.Depth_m,y=af1,col=Eco),shape=15)+
  geom_smooth(data=y,mapping=aes(x=log.Depth_m,y=af1,col=Eco),method="lm")+
  geom_point(data=y,mapping=aes(x=log.Depth_m,y=af2,col=Eco),shape=17)+
  geom_smooth(data=y,mapping=aes(x=log.Depth_m,y=af2,col=Eco),method="lm")+
  ylim(c(0,1))+theme_classic()+
  scale_color_manual(values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"),name="Ecotype")

#LG16a
AIC_table_LG16a_final$Model[1] #model 9 (eco only) ALMOST top
model_comp_LG16a_final %>% head
i=10
x <- predict(polr(AIC_table_LG16a_final$Model[i],data=data_LG16a),type="p")
y <- data.frame(x,af1=x[,1]+x[,2]/2,af2=x[,3]+x[,2]/2,data_LG16a[,c("Dist_baseline_km","Depth_m","log.Depth_m","Eco")])
ggplot()+
  geom_point(data=y,mapping=aes(x=log.Depth_m,y=af1,col=Eco),shape=15)+
  geom_smooth(data=y,mapping=aes(x=log.Depth_m,y=af1,col=Eco),method="lm")+
  geom_point(data=y,mapping=aes(x=log.Depth_m,y=af2,col=Eco),shape=17)+
  geom_smooth(data=y,mapping=aes(x=log.Depth_m,y=af2,col=Eco),method="lm")+
  ylim(c(0,1))+theme_classic()+
  scale_color_manual(values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"),name="Ecotype")


# SUMMARISE ALL RESULTS IN ONE TABLE ####

#AIC tables
x <- rbind(AIC_table_eco_final,AIC_table_sex_final)
y <- data.frame(x[,1],round(x[,c(2:ncol(AIC_table_eco_final))],2))
# write.table(y,"AIC_eco_sex_filtered_in_R.txt",sep="\t")

x <- rbind(AIC_table_INV02_final,AIC_table_INV07_final,AIC_table_INV12_final,
           AIC_table_Hba4_final,AIC_table_Hbb1_final,AIC_table_Hbb5_final)
y <- data.frame(x[,1],round(x[,c(2:ncol(AIC_table_INV02_final))],2))
# write.table(y,"AIC_adaptation_filtered_in_R.txt",sep="\t")


#Full model comparison tables
x <- rbind(model_comp_eco_final,model_comp_sex_final)
y <- data.frame(x[,c(1,2)],round(x[,c(3:7)],2),df=x[,8],round(x[,c(9:13)],2))
# write.table(x,"AIC_eco_sex_full_raw_filtered_in_R.txt",sep="\t")
# write.table(y,"AIC_eco_sex_full_filtered_in_R.txt",sep="\t")

x <- rbind(model_comp_INV02_final,model_comp_INV07_final,model_comp_INV12_final,
           model_comp_Hba4_final,model_comp_Hbb1_final,model_comp_Hbb5_final)
y <- data.frame(x[,c(1,2)],round(x[,c(3:5)],2),edf=x[,6],round(x[,c(7:13)],2))
# write.table(x,"AIC_adaptation_full_raw_filtered_in_R.txt",sep="\t")
# write.table(y,"AIC_adaptation_full_filtered_in_R.txt",sep="\t")


#_______________####
# 2b-RAD ####
# load data ####
data <- read.genepop("genotypes_2bRAD.gen",ncode=3)

# Metadata ####
#Get metadata for all inds
metadata_2bRAD <- readxl::read_xlsx("metadata_synth_2bRAD.xlsx")
#set indnames
indNames(data) <- metadata_2bRAD$New_ID

# add vector for ordering inds N-S
order_NS_juv_ad_ind <- metadata_2bRAD$order_NS_juv_ad_ind

# Pool all samples from the same fjord in column "station_pool" 
metadata_2bRAD$Station_pool <- paste(metadata_2bRAD$Station_ID_New,"_",metadata_2bRAD$Sample_type,sep="") #new column
orig_id <- unique(metadata_2bRAD$Station_pool[order(order_NS_juv_ad_ind)]) #original ID
new_id  <- c(rep("Risr",3),"byfjorden","byfjorden",
             "Brofjorden","Brofjorden","Skr","Skr","Finnsbo",
             "Torgestad","Frlevfjorden","Saltkllefjorden","Ellsefjorden","Ellsefjorden",
             "Havstensfjorden","Byfjorden","Byfjorden","Byfjorden","Byfjorden",
             "Stigfjorden","Hakefjorden","Hakefjorden","Kungsbackafjorden","Kungsbackafjorden",
             "Kullen","Kullen",rep("resund",6),"North Sea adults","Fjord adults",
             "Fjord adults","Kattegat adults","Kattegat adults",rep("resund adults",3)) #new ID
for(i in 1:length(orig_id)){ #rename stations
  metadata_2bRAD$Station_pool <- replace(metadata_2bRAD$Station_pool,metadata_2bRAD$Station_pool==orig_id[i],new_id[i]) 
}

#ordering vectors for Station_pool
order_NS_station_pool <- integer()
for(i in 1:nrow(metadata_2bRAD)){
  for(j in 1:length(unique(metadata_2bRAD[order(order_NS_juv_ad_ind),]$Station_pool))){
    if(metadata_2bRAD$Station_pool[i]==unique(metadata_2bRAD[order(order_NS_juv_ad_ind),]$Station_pool)[j])
    {order_NS_station_pool[i] <- j}    }  }
order_coastal_NS_station_pool <- order_NS_station_pool[metadata_2bRAD$grp.grp=="2"|metadata_2bRAD$Station_pool=="North Sea adults"]

metadata_2bRAD$order_NS_station_pool <- order_NS_station_pool #add column for sorting
station_pool_n <- metadata_2bRAD[metadata_2bRAD$grp.grp=="2"|metadata_2bRAD$Station_pool=="North Sea adults",] %>% group_by(order_NS_station_pool,Station_pool) %>% summarise(n=n()) #df for naming cols and rows (adding n)

data_MAF_coastal_station_pool <- data_MAF[metadata_2bRAD$grp.grp=="2" | metadata_2bRAD$Station_pool=="North Sea adults"]
pop(data_MAF_coastal_station_pool) <- metadata_2bRAD[metadata_2bRAD$grp.grp=="2" | metadata_2bRAD$Station_pool=="North Sea adults",]$Station_pool

# Get Chr and pos data on loci ####

# Create df w Chr_name and pos:
loci2b_all <- t(data.frame(strsplit(locNames(data), "_"))) #split locname into GenBank ID and pos
loci2b_all <- data.frame(locNames(data),loci2b_all) #paste locname
rownames(loci2b_all) <- c(1:length(locNames(data))) #number rows

LG <- c("LG01","LG02","LG03","LG04","LG05","LG06","LG07","LG08","LG09","LG10",
        "LG11","LG12","LG13","LG14","LG15","LG16","LG17","LG18","LG19","LG20",
        "LG21","LG22","LG23")
CHR <- c("chr 1","chr 2","chr 3","chr 4","chr 5","chr 6","chr 7","chr 8","chr 9","chr 10",
         "chr 11","chr 12","chr 13","chr 14","chr 15","chr 16","chr 17","chr 18","chr 19","chr 20",
         "chr 21","chr 22","chr 23")

LG_key <- data.frame(LG,CHR,unique(loci2b_all[c(302:nrow(loci2b_all)),2])) #key for renaming the loci

lg <- vector()
chr <- vector()
for(i in 1:nrow(loci2b_all)){
  for(j in 1:nrow(LG_key)){
    if(loci2b_all[i,2]==LG_key[j,3])
    {lg[i] <- LG_key[j,1]
    chr[i] <- LG_key[j,2]}
  }
  ifelse(lg[i] %in% LG_key[,1],lg[i] <- lg[i],lg[i] <- "unplaced")
  ifelse(chr[i] %in% LG_key[,2],chr[i] <- chr[i],chr[i] <- "unplaced")
  
}
data.frame(lg,chr) %>% view

loci2b_all <- data.frame(c(1:nrow(loci2b_all)),loci2b_all[,c(1:2)],lg,chr,loci2b_all[,3],minorAllele(data))
colnames(loci2b_all) <- c("Order_original","Loc","GenBank_ID_ish","LG","Chr","Pos","MAF")
loci2b_all %>% str
loci2b_all$Pos <- as.numeric(loci2b_all$Pos) #make pos numeric, enables correct sorting
loci2b_all %>% str

#Sort loci by chr and location - look in NCBI at GenBank ID 
loci2b_all_sorted <- loci2b_all[with(loci2b_all, order(LG,Pos)),]
view(loci2b_all_sorted[c(800:1800),])

# prel. PCAs ####

x.data <- tab(data,freq=TRUE,NA.method="mean") 
pca.data <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <- pca.data$eig/sum(pca.data$eig)*100

s.class(pca.data$li, fac=as.factor(metadata_2bRAD$list_INV12), 
        col=transp(funky(5),0.4),
        axesel=TRUE, cstar=0, cpoint=2, clabel = 1, xax=1,yax=2)
add.scatter.eig(pca.data$eig[1:50],3,1,2, ratio=.2,sub="PC eigenvalues")

#this clustering is driven by INV07 (PC1), and INV12 (PC2) - also INV02 (PC3), 

#PCA w/o LG2,7,12
x <- loci2b_all$LG %notin% c("LG02","LG07","LG12") #filters out LGs w known inversions 

#PCA of loci excluding LG2, 7, 12
x.data <- tab(data[loc=x],freq=TRUE,NA.method="mean") 
pca.data <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <- pca.data$eig/sum(pca.data$eig)*100

s.class(pca.data$li, fac=as.factor(metadata_2bRAD$grp.grp), 
        col=transp(c("dodgerblue4","orange2","black"),0.7),
        axesel=TRUE, cstar=0, cpoint=2, clabel = 1, xax=1,yax=2)
add.scatter.eig(pca.data$eig[1:50],3,1,2, ratio=.2,sub="PC eigenvalues")


# Filtering loci (MAF>0.05, INV, ind heterozygosity, ...?) ####

## minor allele freq ####
MAF <- minorAllele(data)
data_MAF <- data[loc = MAF>0.05] #data filtered for MAF>0.05
loci2b <- loci2b_all[MAF>0.05,] #locus metadata filtered for MAF > 0.05

## inveRsion: inversion assignment ####

# we work from a text file (as in the example "genotypes.txt" from inveRsion)

#create snp matrix
freq_MAF <- makefreq(data_MAF) #get allele freqs per ind
index <- c(1:(ncol(freq_MAF)/2))*2-1 #create index to select every other col
snp_matrix <- rbind(loci2b$Pos,(freq_MAF[,index]*2)) #create matrix with correct format (top row=chr pos, remaining rows=genotypes)

#create ordered .txt file and gDat object for LG02, 07, 12
snp_matrix_LG02 <- snp_matrix[,loci2b$LG=="LG02"]
snp_matrix_LG02_order <- snp_matrix_LG02[,order(snp_matrix_LG02[1,])]
write.table(snp_matrix_LG02_order,"snp_matrix_LG02_order.txt",sep="\t",row.names = F,col.names = F,quote=F) #txt file in correct format
data_LG02_gDat <-setUpGenoDatFile(file="snp_matrix_LG02_order.txt",sortMinor=TRUE,saveRes=FALSE)
data_LG02_hapCode <- codeHaplo(data_LG02_gDat,blockSize = 3,minAllele = 0.05)
data_LG02_scan <- list() #empty list for loop
data_LG02_list <- list() #empty list for loop

snp_matrix_LG07 <- snp_matrix[,loci2b$LG=="LG07"]
snp_matrix_LG07_order <- snp_matrix_LG07[,order(snp_matrix_LG07[1,])]
write.table(snp_matrix_LG07_order,"snp_matrix_LG07_order.txt",sep="\t",row.names = F,col.names = F,quote=F)
data_LG07_gDat <-setUpGenoDatFile(file="snp_matrix_LG07_order.txt",sortMinor=TRUE,saveRes=FALSE)
data_LG07_hapCode <- codeHaplo(data_LG07_gDat,blockSize = 3,minAllele = 0.05)
data_LG07_scan <- list()
data_LG07_list <- list()

snp_matrix_LG12 <- snp_matrix[,loci2b$LG=="LG12"]
snp_matrix_LG12_order <- snp_matrix_LG12[,order(snp_matrix_LG12[1,])]
write.table(snp_matrix_LG12_order,"snp_matrix_LG12_order.txt",sep="\t",row.names = F,col.names = F,quote=F)
data_LG12_gDat <-setUpGenoDatFile(file="snp_matrix_LG12_order.txt",sortMinor=TRUE,saveRes=FALSE)
data_LG12_hapCode <- codeHaplo(data_LG12_gDat,blockSize = 3,minAllele = 0.05)
data_LG12_scan <- list()
data_LG12_list <- list()

#perform scan w different window sizes (=i)
for(i in 1:30){
  data_LG02_scan[[i]] <- scanInv(data_LG02_hapCode, window = i,maxSteps=30,geno=TRUE,saveRes = TRUE)
  plot(data_LG02_scan[[i]],which="b",thBic=-Inf,xlim=c(0,35))

  data_LG07_scan[[i]] <- scanInv(data_LG07_hapCode, window = i,maxSteps=30,geno=TRUE,saveRes = TRUE)
  plot(data_LG07_scan[[i]],which="b",thBic=-Inf,xlim=c(0,35))

  data_LG12_scan[[i]] <- scanInv(data_LG12_hapCode, window = i,maxSteps=30,geno=TRUE,saveRes = TRUE)
  plot(data_LG12_scan[[i]],which="b",thBic=-Inf,xlim=c(0,35))
}
#make list of inversions for different window sizes (=i), separate loops for each LG
for(i in 1:30){
  data_LG02_list[[i]] <- listInv(data_LG02_scan[[i]],hapCode=data_LG02_hapCode,geno=T,all=T,thBic=0)
}
for(i in 1:30){
  data_LG07_list[[i]] <- listInv(data_LG07_scan[[i]],hapCode=data_LG07_hapCode,geno=T,all=T,thBic=0)
}
for(i in 1:30){
  data_LG12_list[[i]] <- listInv(data_LG12_scan[[i]],hapCode=data_LG12_hapCode,geno=T,all=T,thBic=0)
}

### Table S17: Inversion BPs ####
data_LG02_list
data_LG07_list
data_LG12_list

## Fig. S6: Compare inv assignment with LD ####
data_MAF_1pop <- data_MAF
pop(data_MAF_1pop) <- rep("Pop1",length(indNames(data_MAF)))

#calculate pairwise LD for LG 2,7,12
LD_LG02 <- gl.report.ld(gi2gl(data_MAF_1pop[loc=loci2b$LG=="LG02"]))
LD_LG07 <- gl.report.ld(gi2gl(data_MAF_1pop[loc=loci2b$LG=="LG07"]))
LD_LG12 <- gl.report.ld(gi2gl(data_MAF_1pop[loc=loci2b$LG=="LG12"]))
view(LD_LG02)

#joining (non-mean) data, all pairwise R2 values per loc1 pos
loci2b_LG02 <- filter(loci2b,LG=="LG02") %>% mutate(loc1=c(1:nrow(filter(loci2b,LG=="LG02"))))
loci2b_LG02_LD <- merge(loci2b_LG02, LD_LG02, by = "loc1")
loci2b_LG02_LD_sorted <- loci2b_LG02_LD[with(loci2b_LG02_LD,order(Pos)),]
loci2b_LG07 <- filter(loci2b,LG=="LG07") %>% mutate(loc1=c(1:nrow(filter(loci2b,LG=="LG07"))))
loci2b_LG07_LD <- merge(loci2b_LG07, LD_LG07, by = "loc1")
loci2b_LG07_LD_sorted <- loci2b_LG07_LD[with(loci2b_LG07_LD,order(Pos)),]
loci2b_LG12 <- filter(loci2b,LG=="LG12") %>% mutate(loc1=c(1:nrow(filter(loci2b,LG=="LG12"))))
loci2b_LG12_LD <- merge(loci2b_LG12, LD_LG12, by = "loc1")
loci2b_LG12_LD_sorted <- loci2b_LG12_LD[with(loci2b_LG12_LD,order(Pos)),]

#plot R2 and inv breakpoints:
ggarrange(ggplot(loci2b_LG02_LD_sorted)+xlim(c(0,34))+
            geom_point(mapping=aes(x=Pos/1000000,y=R2))+
            labs(title="Chr 2",x="Chromosomal position (Mb)",y="All pairwise R2 values")+
            geom_vline(xintercept=c(0.456389,4.48618),col="red")+
            theme_classic(),
          ggplot(loci2b_LG07_LD_sorted)+xlim(c(0,34))+
            geom_point(mapping=aes(x=Pos/1000000,y=R2))+
            labs(title="Chr 7",x="Chromosomal position (Mb)",y="All pairwise R2 values")+
            geom_vline(xintercept=c(16.57467,26.51457),col="red")+
            theme_classic(),
          ggplot(loci2b_LG12_LD_sorted)+xlim(c(0,34))+
            geom_point(mapping=aes(x=Pos/1000000,y=R2))+
            labs(title="Chr 12",x="Chromosomal position (Mb)",y="All pairwise R2 values")+
            geom_vline(xintercept=c(0.658292,1.064904,14.44895,14.6491,14.10688),col="red")+
            theme_classic(),
          labels="AUTO",nrow=3,ncol=1
)

# ggsave("Figures/LD_vs_inv_assign.png",scale=1,dpi=300)
# We will use the most extreme cutoffs (furthest left and right)

## Table S18: Compare inversion assignments ####

#create empty df:s for loop
inv02 <- data.frame(matrix(nrow=235,ncol=4))
inv07 <- data.frame(matrix(nrow=235,ncol=4))
inv12 <- data.frame(matrix(nrow=235,ncol=4))
inv02[,1] <- indNames(data_MAF)
inv07[,1] <- indNames(data_MAF)
inv12[,1] <- indNames(data_MAF)

#Retrieve list of assigned inversion state (mean from top models)  
for(i in 1:nrow(metadata_2bRAD)){
  for(j in 2:4){
    inv02[i,j] <- mean(c(getClassif(data_LG02_list[[1]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG02_list[[2]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG02_list[[3]],thBic=0, wROI=1,geno=TRUE)[i,j] ) )
    
    inv07[i,j] <- mean(c(getClassif(data_LG07_list[[1]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[2]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[3]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[4]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[5]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[6]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[7]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[8]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG07_list[[9]],thBic=0, wROI=1,geno=TRUE)[i,j]))
    
    inv12[i,j] <- mean(c(getClassif(data_LG12_list[[1]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[2]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[3]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[4]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[5]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[6]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[7]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[8]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[9]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[10]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[11]],thBic=0, wROI=1,geno=TRUE)[i,j],
                         getClassif(data_LG12_list[[12]],thBic=0, wROI=1,geno=TRUE)[i,j]))
  }
}
#summarise in one df
inv_assign_vs <- data.frame(INV02=inv02,INV02_assign=metadata_2bRAD$list_INV02,
                            INV07=inv07,INV07_assign=metadata_2bRAD$list_INV07,
                            INV12=inv12,INV12_assign=metadata_2bRAD$list_INV12)
inv_assign_vs

#add info about if loci are located within inversions (Y) or not (N):
loci2b$INV <- rep(NA,nrow(loci2b))
for(i in 1:nrow(loci2b)){
  ifelse(loci2b$LG[i]=="LG02" & loci2b$Pos[i] >= 0.456389e6 & loci2b$Pos[i] <= 4.48618e6,loci2b$INV[i] <- "Y",
         ifelse(loci2b$LG[i]=="LG07" & loci2b$Pos[i] >= 16.57467e6 & loci2b$Pos[i] <= 26.51457e6, loci2b$INV[i] <- "Y",
                ifelse(loci2b$LG[i]=="LG12" & loci2b$Pos[i] >= 0.658292e6 & loci2b$Pos[i] <= 14.6491e6, loci2b$INV[i] <- "Y",
                       loci2b$INV[i] <- "N")))
}
loci2b_sorted <- loci2b[with(loci2b, order(LG,Pos)),]

# Add column with "running position" for all loci
loci2b_sorted$Running_Pos <- loci2b_sorted$Pos
for(i in 2:nrow(loci2b_sorted)){
  for(j in 2:length(unique(loci2b_sorted$LG)))
    if(loci2b_sorted$LG[i]==unique(loci2b_sorted$LG)[j]){loci2b_sorted$Running_Pos[i] <- (loci2b_sorted$Pos[i] + max(filter(loci2b_sorted,LG==unique(loci2b_sorted$LG)[j-1])$Running_Pos))}
}
loci2b_sorted$Running_Pos
loci2b_sorted[with(loci2b_sorted,order(Order_original)),]
loci2b$Running_Pos <- loci2b_sorted[with(loci2b_sorted,order(Order_original)),]$Running_Pos
inv_BPs <- data.frame(LG=c("LG02","LG07","LG12"),LBP=c(456389,16574670,658292),RBP=c(4486180,26514570,14649100),
                      LBP_Running=c(456389+max(loci2b[loci2b$LG=="LG01","Running_Pos"]),16574670+max(loci2b[loci2b$LG=="LG06","Running_Pos"]),658292+max(loci2b[loci2b$LG=="LG11","Running_Pos"])),
                      RBP_Running=c(4486180+max(loci2b[loci2b$LG=="LG01","Running_Pos"]),26514570+max(loci2b[loci2b$LG=="LG06","Running_Pos"]),14649100+max(loci2b[loci2b$LG=="LG11","Running_Pos"])))

## Fig. S7: PCA of INV loci ####    
#INV02
x.data <- tab(data_MAF[loc=loci2b$LG=="LG02" & loci2b$INV=="Y"],freq=TRUE,NA.method="mean") 
pca.data_INV02 <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
pca.data_INV02_perc <- pca.data_INV02$eig/sum(pca.data_INV02$eig)*100
ggplot(data=pca.data_INV02$li, mapping=aes(x=-Axis1,y=Axis2,bg=as.factor(-as.numeric(metadata_2bRAD$list_INV02))))+
  geom_point(pch=21,size=3,alpha=0.7)+ggtitle("Chr 2 inversion")+
  xlab(paste("PC1 (",round(pca.data_INV02_perc[1],1)," %)",sep=""))+
  ylab(paste("PC2 (",round(pca.data_INV02_perc[2],1)," %)",sep=""))+
  scale_fill_manual(name="Assigned inversion state",values=c("yellow2","green3","dodgerblue4","black"),labels=c("Derived","Heterozygote","Ancestral","NA"))+
  theme_classic() -> pca_inv02_anc

#INV07
x.data <- tab(data_MAF[loc=loci2b$LG=="LG07" & loci2b$INV=="Y"],freq=TRUE,NA.method="mean") 
pca.data_INV07 <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
pca.data_INV07_perc <- pca.data_INV07$eig/sum(pca.data_INV07$eig)*100
ggplot(data=pca.data_INV07$li, mapping=aes(x=Axis1,y=Axis2,bg=as.factor(as.numeric(metadata_2bRAD$list_INV07))))+
  geom_point(pch=21,size=3,alpha=0.7)+ggtitle("Chr 7 inversion")+
  xlab(paste("PC1 (",round(pca.data_INV07_perc[1],1)," %)",sep=""))+
  ylab(paste("PC2 (",round(pca.data_INV07_perc[2],1)," %)",sep=""))+
  scale_fill_manual(name="Assigned inversion state",values=c("yellow2","green3","dodgerblue4","black"),labels=c("Homozygote 1","Heterozygote","Homozygote 2","NA"))+
  theme_classic() -> pca_inv07_anc

#INV12
x.data <- tab(data_MAF[loc=loci2b$LG=="LG12" & loci2b$INV=="Y"],freq=TRUE,NA.method="mean") 
pca.data_INV12 <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
pca.data_INV12_perc <- pca.data_INV12$eig/sum(pca.data_INV12$eig)*100
list_INV12_anc <- replace(-as.numeric(metadata_2bRAD$list_INV12),metadata_2bRAD$list_INV12=="3",-4.5)
ggplot(data=pca.data_INV12$li, mapping=aes(x=Axis1,y=Axis2,bg=as.factor(list_INV12_anc)))+
  geom_point(pch=21,size=3,alpha=0.7)+ggtitle("Chr 12 inversion")+
  xlab(paste("PC1 (",round(pca.data_INV12_perc[1],1)," %)",sep=""))+
  ylab(paste("PC2 (",round(pca.data_INV12_perc[2],1)," %)",sep=""))+
  scale_fill_manual(name="Assigned inversion state",values=c("yellow2","green3","dodgerblue","dodgerblue4","black"),labels=c("Derived","Heterozygote","Mixed 2","Ancestral","NA"))+
  theme_classic() -> pca_inv12_anc

#all 3 plots together
ggarrange(pca_inv02_anc,pca_inv07_anc,pca_inv12_anc,nrow=3,ncol=1,labels="AUTO",
          common.legend=T,legend.grob = get_legend(pca_inv12_anc),legend="right")
add.scatter.eig(pca.data_INV02$eig[1:30],3,1,2, ratio=.07,inset=c(0.05,0.75),sub="")
add.scatter.eig(pca.data_INV07$eig[1:30],3,1,2, ratio=.07,inset=c(0.05,0.39),sub="")
add.scatter.eig(pca.data_INV12$eig[1:30],3,1,2, ratio=.07,inset=c(0.05,0.05),sub="")

# Pairwise Fst between station pools ####
## Calculate Fst + p-values using StrataG ####
data_MAF_noninv_eco <- data_MAF[loc=loci2b$INV=="N"]
pop(data_MAF_noninv_eco) <- metadata_2bRAD$grp.grp

#pairwise, between ecotypes
pw_test_MAF_noninv_assigned_eco <-
  pairwiseTest(genind2gtypes(data_MAF_noninv_eco[pop(data_MAF_noninv_eco)!="NA"]),nrep=1)
pw_test_MAF_noninv_assigned_eco

# pairwise, between station_pools
pw_test_MAF_coastal_station_pool_noninv <-
  pairwiseTest(genind2gtypes(data_MAF_coastal_station_pool[loc=loci2b$Loc[loci2b$INV=="N"]]),nrep=1)
pw_test_MAF_coastal_station_pool_noninv

## create Fst matrices for plotting ####
pw_summary_noninv <- list()
for(i in 1:153){
  strata <- data.frame(pw_test_MAF_coastal_station_pool_noninv[[i]]$strata.freq)
  res <- data.frame(pw_test_MAF_coastal_station_pool_noninv[[i]]$result)[c(8,9,16),]
  pw_summary_noninv[[i]] <- data.frame(Pop1=strata$Var1[1],Pop2=strata$Var1[2],Freq1=strata$Freq[1],Freq2=strata$Freq[2],
                                       Fst=res$estimate[1],Fst_prime=res$estimate[2],wcFst=res$estimate[3],
                                       p_Fst=res$p.val[1],p_Fst_prime=res$p.val[2],p_wcFst=res$p.val[3])
}
pw_summary_noninv <- bind_rows(pw_summary_noninv)

pw_summary_noninv_noNS <- pw_summary_noninv[-c(11,27,42,56,69,81,92,102,111,119,126,133:138),]

pw_summary_noninv$p_Fst_FDR <- p.adjust(pw_summary_noninv$p_Fst,method="fdr")
pw_summary_noninv$p_Fst_prime_FDR <- p.adjust(pw_summary_noninv$p_Fst_prime,method="fdr")
pw_summary_noninv$p_wcFst_FDR <- p.adjust(pw_summary_noninv$p_wcFst,method="fdr")
pw_summary_noninv$p_wcFst_sign <- rep(NA,nrow(pw_summary_noninv))
for(i in 1:nrow(pw_summary_noninv)){
  ifelse(pw_summary_noninv$p_wcFst_FDR[i]<=0.05,pw_summary_noninv$p_wcFst_sign[i] <- "*",pw_summary_noninv$p_wcFst_sign[i] <- "NS")
}
pw_summary_noninv %>% view

#turn into a matrix
pw_mat_noninv <- data.frame(matrix(ncol=length(levels(pw_summary_noninv$Pop1)),nrow=length(levels(pw_summary_noninv$Pop1))))
colnames(pw_mat_noninv) <- levels(pw_summary_noninv$Pop1)
rownames(pw_mat_noninv) <- levels(pw_summary_noninv$Pop1)
for(i in 1:length(pw_summary_noninv$Pop1)){
  x <- levels(pw_summary_noninv$Pop1)
  for(j in 1:length(x)){
    for(k in 1:length(x)){
      if(pw_summary_noninv$Pop1[i]==x[j] & pw_summary_noninv$Pop2[i]==x[k]){pw_mat_noninv[j,k] <- pw_summary_noninv$wcFst[i]} #Fst above diagonal
      if(pw_summary_noninv$Pop1[i]==x[j] & pw_summary_noninv$Pop2[i]==x[k]){pw_mat_noninv[k,j] <- pw_summary_noninv$p_wcFst_sign[i]} #p_FDR below diagonal
    }
  }
}
view(pw_mat_noninv)

#significance matrix for plotting:
#replace NS, 1, NA
pw_mat_noninv_sign <- replace(pw_mat_noninv,is.na(pw_mat_noninv),as.numeric(0))
pw_mat_noninv_mirror <- replace(pw_mat_noninv,is.na(pw_mat_noninv),as.numeric(0))
pw_mat_noninv_sign <- replace(pw_mat_noninv_sign,pw_mat_noninv_sign=="*",as.numeric(1))
pw_mat_noninv_sign <- replace(pw_mat_noninv_sign,pw_mat_noninv=="NS",as.numeric(0))

#mirror it
for(i in 1:nrow(pw_mat_noninv_sign)){
  pw_mat_noninv_sign[,i] <-pw_mat_noninv_sign[,i] %>% as.numeric
  pw_mat_noninv_mirror[,i] <-pw_mat_noninv_mirror[,i] %>% as.numeric
  for(j in 1:ncol(pw_mat_noninv_sign)){
    if(i<j){pw_mat_noninv_sign[i,j] <- pw_mat_noninv_sign[j,i]}
    if(i<j){pw_mat_noninv_mirror[j,i] <- pw_mat_noninv_mirror[i,j]}
  }
}
for(i in 1:ncol(pw_mat_noninv_mirror)){
  pw_mat_noninv_mirror[,i] <- pw_mat_noninv_mirror[,i] %>% as.numeric
}

#sorting vector for full matrix
x <- station_pool_n[order(station_pool_n$Station_pool),]
x$new_order <- c(1:18)
x <- x[order(x$order_NS_station_pool),]

## Table 2: Fst heatmap ####
# write function
pheatmap_lab_col <- function(matrix,labels){
  breaksList <- seq(0,max(abs(replace(matrix,is.na(matrix),0))), by = 0.0001)
  pheatmap(matrix,cluster_rows = F,cluster_cols = F,display_numbers = T,number_format = "%.3f",labels_row=paste(data.frame(labels)[,2]," (n=",data.frame(labels)[,3],")",sep=""),labels_col=paste(data.frame(labels)[,2]," (n=",data.frame(labels)[,3],")",sep=""),color = colorRampPalette(rev(brewer.pal(n = 7, name = "RdYlBu")))(length(breaksList)), breaks = breaksList )
}

pheatmap_lab_col(pw_mat_noninv_sign[x$new_order,x$new_order],station_pool_n)
pheatmap_lab_col(pw_mat_noninv_mirror[x$new_order,x$new_order],station_pool_n)

## MDS plot ####

# station_pool, noninv loci
d <- pw_mat_noninv_mirror[x$new_order,x$new_order]
labels <- station_pool_n
labels$order_NS_station_pool <- labels$order_NS_station_pool %>% as.factor

labels$Station_n <- paste(labels$Station_pool," (n=",labels$n,")",sep="")

x <- cmdscale(d,k=11,eig=T)
rownames(x$points)==station_pool_n$Station_pool #all TRUE
mds_eig_perc <- cmdscale(d,k=11,eig=T)$eig[1:11]/sum(cmdscale(d,k=11,eig=T)$eig[1:11])*100

#define shape and col based on subdiv(20/21/23)/sample type(juv/ad)
labels$Station_pool
shape <- c(rep(15,11),rep(17,2),rep(18,1),rep(19,4))
pal2 <- c(c("black","red4","red","brown2","orange3","orange","yellow2","green","forestgreen","dodgerblue4","dodgerblue"), #skagerrak cols
          c("black","red","blue"), #kattegat-resund cols
          viridis(5,option="C")[-5]) #adult cols

#plot MDS of noninv loci
ggplot()+
  geom_point(data=data.frame(x$points),
             mapping=aes(x=X1*1000,y=X2*1000,shape=labels$order_NS_station_pool,
                         col=labels$order_NS_station_pool),size=2.5,alpha=0.8)+
  scale_colour_manual(name="Station group",values = pal2,labels=labels$Station_n)+
  scale_shape_manual(name="Station group",values = shape,labels=labels$Station_n)+ 
  xlab(paste("Dimension 1 (",round(mds_eig_perc[1],1)," %)",sep=""))+
  ylab(paste("Dimension 2 (",round(mds_eig_perc[2],1)," %)",sep=""))+
  coord_fixed()+ theme_classic()+ guides(col=guide_legend(nrow=6))+
  theme(legend.position = "bottom",legend.title = element_blank(),legend.key.height = unit(0,units="cm"),legend.direction = "horizontal") -> mds_pool
mds_pool
add.scatter.eig(cmdscale(d,eig=T)$eig[1:11],3,3,2, ratio=.13,inset=c(0.078,0.26),sub="")

## PCA on only coastal ecotype ####
x <- data_MAF_coastal_station_pool[loc=loci2b$INV=="N"]
x <- x[pop(x)!=c("North Sea adults")]

x.data <- tab(x,freq=TRUE,NA.method="mean") 
pca.data <- dudi.pca(x.data,center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <- pca.data$eig/sum(pca.data$eig)*100

order_PCA <- vector()
for(i in 1:length(pop(x))){
  for(j in 1:nrow(labels)){
    if(pop(x)[i]==labels$Station_pool[j]){order_PCA[i] <- labels$order_NS_station_pool[j]}
  }
}
order_PCA <- order_PCA %>% as.factor

pal3 <- pal2[-15]
ggplot()+
  geom_point(mapping=aes(x=pca.data$li$Axis1,y=pca.data$li$Axis2,col=order_PCA,shape=order_PCA),size=2.5,alpha=0.8)+
  scale_colour_manual(name="Station group",values = pal3,labels=labels$Station_n[-15])+
  scale_shape_manual(name="Station group",values = shape,labels=labels$Station_n[-15])+ 
  xlab(paste("PC1 (",round(eig.perc[1],2)," %)",sep=""))+
  ylab(paste("PC2 (",round(eig.perc[2],2)," %)",sep=""))+
  coord_fixed()+theme_classic()+guides(col=guide_legend(nrow=6))+
  theme(legend.position = "bottom",legend.title = element_blank(),legend.key.height = unit(0,units="cm"),legend.direction = "horizontal") -> pca_coast_pool
pca_coast_pool
add.scatter.eig(pca.data$eig[1:50],3,1,2, inset=c(0.1,0.08), ratio=.13,sub="")

## Fig. 6: combine MDS + PCA ####  
ggarrange(pca_coast_pool,mds_pool,labels="AUTO",common.legend = T,legend.grob = get_legend(mds_pool),legend="bottom")  
add.scatter.eig(pca.data$eig[1:30],3,1,2, inset=c(0.055,0.32), ratio=.13,sub="")
add.scatter.eig(cmdscale(d,eig=T)$eig[1:11],3,3,2, ratio=.13,inset=c(0.55,0.26),sub="")

# Outlier tests ####
## BayeScan ####

# Skip to #4 to analyse output data from BayeScan, otherwise:

#1. write genePop files to analyse:
# all inds, all loci, pop=grp.grp
# data_all_eco <- data_MAF
# pop(data_all_eco) <- metadata_2bRAD$grp.grp
# only assigned inds, pop=grp.grp
# genind_to_genepop(data_all_eco[pop=c("1","2")],output="BayeScan/data_assigned_eco_genepop.txt")

#2. convert to bayescan format using pgdspider

#3. analyse in bayescan

#4. write function for plotting BayeScan results
plot_bayescan<-function(res,FDR=0.05,size=1,pos=0.35,highlight=NULL,name_highlighted=F,add_text=T)
{
  if (is.character(res))
    res=read.table(res)
  
  colfstat=5
  colq=colfstat-2
  
  highlight_rows=which(is.element(as.numeric(row.names(res)),highlight))
  non_highlight_rows=setdiff(1:nrow(res),highlight_rows)
  
  outliers=as.integer(row.names(res[res[,colq]<=FDR,]))
  
  ok_outliers=TRUE
  if (sum(res[,colq]<=FDR)==0)
    ok_outliers=FALSE;
  
  res[res[,colq]<=0.0001,colq]=0.0001
  
  # plot
  plot(log10(res[,colq]),res[,colfstat],xlim=rev(range(log10(res[,colq]))),xlab="log10(q value)",ylab=names(res[colfstat]),type="n")
  points(log10(res[non_highlight_rows,colq]),res[non_highlight_rows,colfstat],pch=19,cex=size)
  
  if (name_highlighted) {
    if (length(highlight_rows)>0) {
      text(log10(res[highlight_rows,colq]),res[highlight_rows,colfstat],row.names(res[highlight_rows,]),col="red",cex=size*1.2,font=2)
    }
  }
  else {
    points(log10(res[highlight_rows,colq]),res[highlight_rows,colfstat],col="red",pch=19,cex=size)
    # add names of loci over p and vertical line
    if (ok_outliers & add_text) {
      text(log10(res[res[,colq]<=FDR,][,colq])+pos*(round(runif(nrow(res[res[,colq]<=FDR,]),1,2))*2-3),res[res[,colq]<=FDR,][,colfstat],row.names(res[res[,colq]<=FDR,]),cex=size)
    }
  }
  lines(c(log10(FDR),log10(FDR)),c(-1,1),lwd=2)
  
  return(list("outliers"=outliers,"nb_outliers"=length(outliers)))
}

#5. Plot results
plot_bayescan("BayeScan/bs_assigned_eco_PO10_fst.txt",FDR=0.05) #57 outliers!
loci2b_BS_outliers <- loci2b[plot_bayescan("BayeScan/bs_assigned_eco_PO10_fst.txt",FDR=0.05)$outliers,]

## Outlier analysis outFLANK ####

#create snp matrix for
SNPmat <- freq_MAF[,index]*2 #create matrix with correct format (cols=loci,rows=genotypes, )
SNPmat <- replace(SNPmat,is.na(SNPmat),9) #replace "NA" w "9"

#create fstmat for outflank input
#assigned eco
Fstmat_assigned_eco <- MakeDiploidFSTMat(SNPmat[metadata_2bRAD$grp.grp %in% c("1","2"),],locNames(data_MAF),metadata_2bRAD$grp.grp[metadata_2bRAD$grp.grp %in% c("1","2")])

#Check for loci with low sample sizes or unusual values of uncorrected Fst
plot(Fstmat_assigned_eco$FST, Fstmat_assigned_eco$FSTNoCorr,xlim=c(-0.01,0.3), ylim=c(-0.01,0.3),pch=20)+abline(0,1)

#check if Fsts look Chi distributed
plot(Fstmat_assigned_eco$He, Fstmat_assigned_eco$FSTNoCorr, pch=20, col="grey")
hist(Fstmat_assigned_eco$FSTNoCorr, breaks=300)

# Run outflank
OF_assigned_eco <- OutFLANK(Fstmat_assigned_eco, NumberOfSamples=2)

loci2b_OF_outliers <- loci2b[OF_assigned_eco$results$OutlierFlag==TRUE,]

#number of outliers
sum(OF_assigned_eco$results$OutlierFlag==TRUE, na.rm=TRUE) 
#156 outliers!

## Fig. 3: Manhattan plots: ####
breaks <- NA
for(i in 1:length(unique(loci2b_sorted$LG))){
    breaks[i] <- mean(c(min(filter(loci2b,LG==unique(loci2b_sorted$LG)[i])$Running_Pos),max(filter(loci2b,LG==unique(loci2b_sorted$LG)[i])$Running_Pos)))
}

#Fig. 3A: BayeScan outliers
# Basic stats for all loci 
data_all_eco <- data_MAF
pop(data_all_eco) <- metadata_2bRAD$grp.grp

bs_assigned_eco <- basic.stats(data_all_eco[pop=c("1","2")])
data_eco
ggplot()+
  geom_point(mapping=aes(x=loci2b$Running_Pos,
                         y=bs_assigned_eco$perloc$Fst,col=loci2b$Chr),size=1)+
  scale_color_manual(values=c(rep(c("black","grey"),12),"red"),labels=c(loci2b_sorted$Chr_new %>% unique,"Outliers"),name="Linkage Group")+
  labs(x="Chromosomal position",y=expression(Locus-wise~italic(F)[ST]),title="BayeScan outliers, offshore vs coastal ecotype")+
  scale_x_continuous(breaks=breaks,labels=loci2b_sorted$Chr %>% unique)+
  geom_point(mapping=aes(x=loci2b_BS_outliers$Running_Pos,
                         y=bs_assigned_eco$perloc$Fst[loci2b$Loc %in% loci2b_BS_outliers$Loc]),col="red",size=1)+
  geom_rect(data=inv_BPs,mapping=aes(xmin=LBP_Running, xmax=RBP_Running, ymin=min(na.omit(bs_assigned_eco$perloc$Fst)),
                                     ymax=max(na.omit(bs_assigned_eco$perloc$Fst)), group=NULL), color="transparent", fill="orange", alpha=0.2)+
  theme_classic()+
  theme(legend.position = "none",axis.text.x = element_text(angle = 90,vjust=0.5,hjust=1)) -> man_BS_eco

# Fig. 3B: OutFLANK outliers
ggplot()+
  geom_point(mapping=aes(x=loci2b$Running_Pos,
                         y=OF_assigned_eco$results$FST,col=loci2b$LG),size=1)+
  scale_color_manual(values=c(rep(c("black","grey"),12),"red"),labels=c(loci2b_sorted$Chr %>% unique,"Outliers"),name="Chromosome")+
  labs(x="Chromosomal position",y=expression(Locus-wise~italic(F)[ST]),title="OutFLANK outliers, offshore vs coastal ecotype")+
  scale_x_continuous(breaks=breaks,labels=loci2b_sorted$Chr %>% unique)+
  geom_point(mapping=aes(x=loci2b_OF_outliers$Running_Pos,
                         y=OF_assigned_eco$results$FST[OF_assigned_eco$results$OutlierFlag==TRUE]),col="red",size=1)+
  geom_rect(data=inv_BPs,mapping=aes(xmin=LBP_Running, xmax=RBP_Running, ymin=min(na.omit(OF_assigned_eco$results$FST)),
                                     ymax=max(na.omit(OF_assigned_eco$results$FST)), group=NULL), color="transparent", fill="orange", alpha=0.2)+
  theme_classic()+
  theme(legend.position = "none",axis.text.x = element_text(angle = 90,vjust=0.5,hjust=1)) -> man_OF_eco

# Fig. 3: Combine
ggarrange(man_BS_eco,man_OF_eco+scale_y_continuous(labels=scales::number_format(accuracy = 0.01)),nrow=2,ncol=1,labels="AUTO")

# which outlier loci are shared?
loci2b_BS_outliers$Loc %in% loci2b_BS_outliers$Loc #all BayeScan outliers were also detected by OutFLANK

# Fig. 2: compare DAPC, PCA with different panels  ####

# 2bRAD PCA w/o inv loci:
data_assigned_eco <- data_all_eco[metadata_2bRAD$grp.grp!="NA"]
pca.data_noninv <- dudi.pca(tab(data_assigned_eco[loc=loci2b$INV=="N"],freq=TRUE,NA.method="mean"),center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc <-pca.data_noninv$eig/sum(pca.data_noninv$eig)*100

ggplot(data=pca.data_noninv$li)+
  geom_point(mapping=aes(x=Axis1,y=Axis2,col=filter(metadata_2bRAD,grp.grp!="NA")$grp.grp),size=3,alpha=0.7)+
  xlab(paste("PC1 (",round(eig.perc[1],2)," %)",sep=""))+
  ylab(paste("PC2 (",round(eig.perc[2],2)," %)",sep=""))+
  scale_color_manual(name="Ecotype",values=c("dodgerblue2","orange2"),labels=c("Offshore","Coastal"))+
  coord_fixed(ratio=pca.data_noninv$eig[2]/pca.data_noninv$eig[1])+
  scale_x_continuous(labels = scales::number_format(accuracy = 0.1))+
  scale_y_continuous(labels = scales::number_format(accuracy = 0.1))+
  theme_classic() -> pca_2b

loci2b_noninv <- filter(loci2b,INV=="N")

pca.data_noBS <- dudi.pca(tab(data_assigned_eco[loc=filter(loci2b_noninv,Loc %notin% loci2b_BS_outliers$Loc)$Loc],freq=TRUE,NA.method="mean"),center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc_noBS <- pca.data_noBS$eig/sum(pca.data_noBS$eig)*100

ggplot() +
  geom_point(data = pca.data_noBS$li,
             mapping = aes(x = Axis1, y = Axis2,
                           colour = filter(metadata_2bRAD,grp.grp!="NA")$grp.grp), size=2.5, alpha=0.7) +
  xlab(paste("PC1 (", round(eig.perc_noBS[1],2)," %)",sep=""))+ ylab(paste("PC2 (", round(eig.perc_noBS[2],2)," %)",sep=""))+
  theme_classic() +
  coord_fixed(ratio=pca.data_noBS$eig[2]/pca.data_noBS$eig[1])+
  scale_colour_manual(values=c("dodgerblue2","orange2"),name = "Ecotype",labels = c("Offshore","Coastal"))+
  scale_x_continuous(labels = scales::number_format(accuracy = 0.1))+
  scale_y_continuous(labels = scales::number_format(accuracy = 0.1))->pca_2b_noBS

pca.data_noOF <- dudi.pca(tab(data_assigned_eco[loc=filter(loci2b_noninv,Loc %notin% loci2b_OF_outliers$Loc)$Loc],freq=TRUE,NA.method="mean"),center=TRUE,scale=FALSE,scannf=FALSE,nf=15)
eig.perc_noOF <- pca.data_noOF$eig/sum(pca.data_noOF$eig)*100

ggplot() +
  geom_point(data = pca.data_noOF$li,
             mapping = aes(x = Axis1, y = Axis2,
                           colour = filter(metadata_2bRAD,grp.grp!="NA")$grp.grp), size=2.5, alpha=0.7) +
  xlab(paste("PC1 (", round(eig.perc_noOF[1],2)," %)",sep=""))+ ylab(paste("PC2 (", round(eig.perc_noOF[2],2)," %)",sep=""))+
  theme_classic() +
  coord_fixed(ratio=pca.data_noOF$eig[2]/pca.data_noOF$eig[1])+
  scale_colour_manual(values=c("dodgerblue2","orange2"),name = "Ecotype",labels = c("Offshore","Coastal"))+
  scale_x_continuous(labels = scales::number_format(accuracy = 0.1))+
  scale_y_continuous(labels = scales::number_format(accuracy = 0.1)) ->pca_2b_noOF

#merge figs
AB <- ggarrange(dens_dapc,pca_grp,labels = c("A", "B"),
          ncol = 1, nrow = 2, align="v", widths=c(1,1))
C <- ggarrange(pca_2b,labels="C",legend="none")
DE <- ggarrange(pca_2b_noBS,pca_2b_noOF,labels=c("D","E"),nrow=2,ncol=1,legend="none")  
CDE <- ggarrange(C,DE,nrow=1,ncol=2,legend = "right",common.legend = T,legend.grob = get_legend(pca_2b))
ggarrange(AB,CDE,align="h",nrow=2,ncol=1)

# add scree plots
add.scatter.eig(pca.comb_sub$eig,3,1,2, ratio=.08,inset=c(0.1,0.55),sub=NULL)
add.scatter.eig(eig.perc[1:30],3,1,2, ratio=.08,inset=c(0.1,0.14),sub=NULL)
add.scatter.eig(eig.perc_noBS[1:30],3,1,2, ratio=.05,inset=c(0.5,0.3),sub=NULL)
add.scatter.eig(eig.perc_noOF[1:30],3,1,2, ratio=.05,inset=c(0.5,0.1),sub=NULL)
